@@ -12,7 +12,7 @@ if [ ! -f /usr/share/mingw/toolchain-mingw64.meson ]; then
 fi
 
 # try to keep this and ../contrib/ci/build_windows.sh in sync as much as makes sense
-meson .. \
+meson setup .. \
     --cross-file=/usr/share/mingw/toolchain-mingw64.meson \
     --cross-file=../contrib/mingw64.cross \
     --prefix=/ \
