@@ -3,7 +3,7 @@ set -e
 set -x
 
 mkdir -p build-macos && cd build-macos
-meson .. \
+meson setup .. \
     -Dbuild=standalone \
     -Dsoup_session_compat=false \
     -Dgusb:docs=false \
