@@ -16,7 +16,16 @@ if [ "$QUBES" = "true" ]; then
     QUBES_MACRO=(--define "qubes_packages 1")
 fi
 
-meson .. \
+# smoke test something small with no auto-deps
+meson setup .. \
+    -Dbuild=library \
+    -Dauto_features=disabled \
+    -Dtests=false
+ninja-build
+rm -rf *
+
+# do the full-fat build
+meson setup \
     -Ddocs=disabled \
     -Dman=true \
     -Dtests=true \
@@ -65,6 +74,7 @@ cp $HOME/rpmbuild/RPMS/*/*.rpm dist
 
 if [ "$CI" = "true" ]; then
 	sed "s,^DisabledPlugins=.*,DisabledPlugins=," -i /etc/fwupd/daemon.conf
+	sed "s,^AllowEmulation=false,AllowEmulation=true," -i /etc/fwupd/daemon.conf
 
 	# set up enough PolicyKit and D-Bus to run the daemon
 	mkdir -p /run/dbus
