@@ -11,7 +11,7 @@ import subprocess
 import os
 import shutil
 import xml.etree.ElementTree as ET
-from distutils.version import LooseVersion as l_ver
+from packaging.version import Version
 
 FWUPDTOOL = "/bin/fwupdtool"
 
@@ -33,14 +33,12 @@ class FwupdHeads:
         """
         Checks if Qubes works under heads
         """
-        if "heads" in self.dom0_hwids_info:
+        if "Heads" in self.dom0_hwids_info:
             self.heads_version = None
             hwids = self.dom0_hwids_info.split("\n")
             for line in hwids:
-                if line.startswith("BiosVersion: CBET4000 "):
-                    self.heads_version = line.replace(
-                        "BiosVersion: CBET4000 ", ""
-                    ).replace(" heads", "")
+                if "Heads" in line:
+                    self.heads_version = line.split("Heads-v")[1]
         else:
             print("Device is not running under the heads firmware!!")
             print("Exiting...")
@@ -76,10 +74,10 @@ class FwupdHeads:
             return EXIT_CODES["NOTHING_TO_DO"]
         for release in heads_metadata_info.find("releases").findall("release"):
             release_ver = release.get("version")
-            if self.heads_version == "heads" or l_ver(release_ver) > l_ver(
+            if self.heads_version == "heads" or Version(release_ver) > Version(
                 self.heads_version
             ):
-                if not self.heads_update_version or l_ver(release_ver) > l_ver(
+                if not self.heads_update_version or Version(release_ver) > Version(
                     self.heads_update_version
                 ):
                     self.heads_update_url = release.find("location").text
