@@ -7,7 +7,6 @@
 #pragma once
 
 #include <gio/gio.h>
-#include <glib-object.h>
 
 #include "fwupd-device.h"
 #include "fwupd-enums.h"
@@ -80,6 +79,17 @@ gboolean
 fwupd_client_connect_finish(FwupdClient *self,
 			    GAsyncResult *res,
 			    GError **error) G_GNUC_WARN_UNUSED_RESULT;
+gboolean
+fwupd_client_disconnect(FwupdClient *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
+void
+fwupd_client_quit_async(FwupdClient *self,
+			GCancellable *cancellable,
+			GAsyncReadyCallback callback,
+			gpointer callback_data);
+gboolean
+fwupd_client_quit_finish(FwupdClient *self,
+			 GAsyncResult *res,
+			 GError **error) G_GNUC_WARN_UNUSED_RESULT;
 void
 fwupd_client_get_devices_async(FwupdClient *self,
 			       GCancellable *cancellable,
@@ -219,6 +229,23 @@ fwupd_client_get_results_finish(FwupdClient *self,
 				GAsyncResult *res,
 				GError **error) G_GNUC_WARN_UNUSED_RESULT;
 void
+fwupd_client_modify_bios_setting_async(FwupdClient *self,
+				       GHashTable *settings,
+				       GCancellable *cancellable,
+				       GAsyncReadyCallback callback,
+				       gpointer callback_data);
+gboolean
+fwupd_client_modify_bios_setting_finish(FwupdClient *self, GAsyncResult *res, GError **error);
+void
+fwupd_client_get_bios_settings_async(FwupdClient *self,
+				     GCancellable *cancellable,
+				     GAsyncReadyCallback callback,
+				     gpointer callback_data);
+GPtrArray *
+fwupd_client_get_bios_settings_finish(FwupdClient *self,
+				      GAsyncResult *res,
+				      GError **error) G_GNUC_WARN_UNUSED_RESULT;
+void
 fwupd_client_get_host_security_attrs_async(FwupdClient *self,
 					   GCancellable *cancellable,
 					   GAsyncReadyCallback callback,
@@ -358,25 +385,72 @@ GHashTable *
 fwupd_client_get_report_metadata_finish(FwupdClient *self,
 					GAsyncResult *res,
 					GError **error) G_GNUC_WARN_UNUSED_RESULT;
+void
+fwupd_client_inhibit_async(FwupdClient *self,
+			   const gchar *reason,
+			   GCancellable *cancellable,
+			   GAsyncReadyCallback callback,
+			   gpointer callback_data);
+gchar *
+fwupd_client_inhibit_finish(FwupdClient *self,
+			    GAsyncResult *res,
+			    GError **error) G_GNUC_WARN_UNUSED_RESULT;
+void
+fwupd_client_uninhibit_async(FwupdClient *self,
+			     const gchar *inhibit_id,
+			     GCancellable *cancellable,
+			     GAsyncReadyCallback callback,
+			     gpointer callback_data);
+gboolean
+fwupd_client_uninhibit_finish(FwupdClient *self,
+			      GAsyncResult *res,
+			      GError **error) G_GNUC_WARN_UNUSED_RESULT;
+void
+fwupd_client_emulation_load_async(FwupdClient *self,
+				  GBytes *data,
+				  GCancellable *cancellable,
+				  GAsyncReadyCallback callback,
+				  gpointer callback_data);
+gboolean
+fwupd_client_emulation_load_finish(FwupdClient *self, GAsyncResult *res, GError **error);
+void
+fwupd_client_emulation_save_async(FwupdClient *self,
+				  GCancellable *cancellable,
+				  GAsyncReadyCallback callback,
+				  gpointer callback_data);
+GBytes *
+fwupd_client_emulation_save_finish(FwupdClient *self,
+				   GAsyncResult *res,
+				   GError **error) G_GNUC_WARN_UNUSED_RESULT;
 
 FwupdStatus
 fwupd_client_get_status(FwupdClient *self);
 gboolean
 fwupd_client_get_tainted(FwupdClient *self);
 gboolean
+fwupd_client_get_only_trusted(FwupdClient *self);
+gboolean
 fwupd_client_get_daemon_interactive(FwupdClient *self);
 guint
 fwupd_client_get_percentage(FwupdClient *self);
 const gchar *
 fwupd_client_get_daemon_version(FwupdClient *self);
+void
+fwupd_client_set_daemon_version(FwupdClient *self, const gchar *daemon_version);
 const gchar *
 fwupd_client_get_host_bkc(FwupdClient *self);
 const gchar *
+fwupd_client_get_host_vendor(FwupdClient *self);
+const gchar *
 fwupd_client_get_host_product(FwupdClient *self);
 const gchar *
 fwupd_client_get_host_machine_id(FwupdClient *self);
 const gchar *
 fwupd_client_get_host_security_id(FwupdClient *self);
+guint32
+fwupd_client_get_battery_level(FwupdClient *self);
+guint32
+fwupd_client_get_battery_threshold(FwupdClient *self);
 
 void
 fwupd_client_get_remotes_async(FwupdClient *self,
