@@ -28,6 +28,12 @@ G_BEGIN_DECLS
  * The dbus interface
  **/
 #define FWUPD_DBUS_INTERFACE "org.freedesktop.fwupd"
+/**
+ * FWUPD_DBUS_P2P_SOCKET_ADDRESS:
+ *
+ * The D-Bus socket address when using point-to-point connections.
+ **/
+#define FWUPD_DBUS_P2P_SOCKET_ADDRESS "tcp:host=localhost,port=1341"
 
 /**
  * FWUPD_DEVICE_ID_ANY:
@@ -72,6 +78,8 @@ gchar *
 fwupd_build_machine_id(const gchar *salt, GError **error);
 GHashTable *
 fwupd_get_os_release(GError **error);
+GHashTable *
+fwupd_get_os_release_full(const gchar *filename, GError **error);
 gchar *
 fwupd_build_history_report_json(GPtrArray *devices, GError **error);
 gboolean
