@@ -6,7 +6,6 @@
 
 #pragma once
 
-#include <glib-object.h>
 #include <json-glib/json-glib.h>
 
 #include "fwupd-device.h"
@@ -21,5 +20,9 @@ void
 fwupd_device_incorporate(FwupdDevice *self, FwupdDevice *donor);
 void
 fwupd_device_to_json(FwupdDevice *self, JsonBuilder *builder);
+void
+fwupd_device_to_json_full(FwupdDevice *self, JsonBuilder *builder, FwupdDeviceFlags flags);
+gboolean
+fwupd_device_from_json(FwupdDevice *self, JsonNode *json_node, GError **error);
 
 G_END_DECLS
