@@ -114,6 +114,14 @@ fwupd_device_get_flashes_left(FwupdDevice *self);
 void
 fwupd_device_set_flashes_left(FwupdDevice *self, guint32 flashes_left);
 guint32
+fwupd_device_get_battery_level(FwupdDevice *self);
+void
+fwupd_device_set_battery_level(FwupdDevice *self, guint32 battery_level);
+guint32
+fwupd_device_get_battery_threshold(FwupdDevice *self);
+void
+fwupd_device_set_battery_threshold(FwupdDevice *self, guint32 battery_threshold);
+guint32
 fwupd_device_get_install_duration(FwupdDevice *self);
 void
 fwupd_device_set_install_duration(FwupdDevice *self, guint32 duration);
@@ -128,6 +136,16 @@ fwupd_device_remove_flag(FwupdDevice *self, FwupdDeviceFlags flag);
 gboolean
 fwupd_device_has_flag(FwupdDevice *self, FwupdDeviceFlags flag);
 guint64
+fwupd_device_get_problems(FwupdDevice *self);
+void
+fwupd_device_set_problems(FwupdDevice *self, guint64 problems);
+void
+fwupd_device_add_problem(FwupdDevice *self, FwupdDeviceProblem problem);
+void
+fwupd_device_remove_problem(FwupdDevice *self, FwupdDeviceProblem problem);
+gboolean
+fwupd_device_has_problem(FwupdDevice *self, FwupdDeviceProblem problem);
+guint64
 fwupd_device_get_created(FwupdDevice *self);
 void
 fwupd_device_set_created(FwupdDevice *self, guint64 created);
@@ -139,6 +157,8 @@ GPtrArray *
 fwupd_device_get_checksums(FwupdDevice *self);
 void
 fwupd_device_add_checksum(FwupdDevice *self, const gchar *checksum);
+gboolean
+fwupd_device_has_checksum(FwupdDevice *self, const gchar *checksum);
 const gchar *
 fwupd_device_get_plugin(FwupdDevice *self);
 void
@@ -216,6 +236,10 @@ FwupdStatus
 fwupd_device_get_status(FwupdDevice *self);
 void
 fwupd_device_set_status(FwupdDevice *self, FwupdStatus status);
+guint
+fwupd_device_get_percentage(FwupdDevice *self);
+void
+fwupd_device_set_percentage(FwupdDevice *self, guint percentage);
 void
 fwupd_device_add_release(FwupdDevice *self, FwupdRelease *release);
 GPtrArray *
