@@ -209,6 +209,10 @@ fwupd_device_flag_to_string(FwupdDeviceFlags device_flag)
 		return "signed-payload";
 	if (device_flag == FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD)
 		return "unsigned-payload";
+	if (device_flag == FWUPD_DEVICE_FLAG_EMULATED)
+		return "emulated";
+	if (device_flag == FWUPD_DEVICE_FLAG_EMULATION_TAG)
+		return "emulation-tag";
 	if (device_flag == FWUPD_DEVICE_FLAG_UNKNOWN)
 		return "unknown";
 	return NULL;
@@ -328,6 +332,10 @@ fwupd_device_flag_from_string(const gchar *device_flag)
 		return FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD;
 	if (g_strcmp0(device_flag, "unsigned-payload") == 0)
 		return FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD;
+	if (g_strcmp0(device_flag, "emulated") == 0)
+		return FWUPD_DEVICE_FLAG_EMULATED;
+	if (g_strcmp0(device_flag, "emulation-tag") == 0)
+		return FWUPD_DEVICE_FLAG_EMULATION_TAG;
 	return FWUPD_DEVICE_FLAG_UNKNOWN;
 }
 
@@ -362,6 +370,10 @@ fwupd_device_problem_to_string(FwupdDeviceProblem device_problem)
 		return "is-emulated";
 	if (device_problem == FWUPD_DEVICE_PROBLEM_MISSING_LICENSE)
 		return "missing-license";
+	if (device_problem == FWUPD_DEVICE_PROBLEM_SYSTEM_INHIBIT)
+		return "system-inhibit";
+	if (device_problem == FWUPD_DEVICE_PROBLEM_UPDATE_IN_PROGRESS)
+		return "update-in-process";
 	if (device_problem == FWUPD_DEVICE_PROBLEM_UNKNOWN)
 		return "unknown";
 	return NULL;
@@ -398,6 +410,10 @@ fwupd_device_problem_from_string(const gchar *device_problem)
 		return FWUPD_DEVICE_PROBLEM_IS_EMULATED;
 	if (g_strcmp0(device_problem, "missing-license") == 0)
 		return FWUPD_DEVICE_PROBLEM_MISSING_LICENSE;
+	if (g_strcmp0(device_problem, "system-inhibit") == 0)
+		return FWUPD_DEVICE_PROBLEM_SYSTEM_INHIBIT;
+	if (g_strcmp0(device_problem, "update-in-process") == 0)
+		return FWUPD_DEVICE_PROBLEM_UPDATE_IN_PROGRESS;
 	return FWUPD_DEVICE_PROBLEM_UNKNOWN;
 }
 
