@@ -101,7 +101,7 @@ typedef enum {
  *
  * Since 0.1.3
  */
-#define FWUPD_DEVICE_FLAG_NONE (0u)
+#define FWUPD_DEVICE_FLAG_NONE (0ull)
 /**
  * FWUPD_DEVICE_FLAG_INTERNAL:
  *
@@ -109,7 +109,7 @@ typedef enum {
  *
  * Since 0.1.3
  */
-#define FWUPD_DEVICE_FLAG_INTERNAL (1u << 0)
+#define FWUPD_DEVICE_FLAG_INTERNAL (1llu << 0)
 /**
  * FWUPD_DEVICE_FLAG_UPDATABLE:
  *
@@ -117,7 +117,7 @@ typedef enum {
  *
  * Since 0.9.7
  */
-#define FWUPD_DEVICE_FLAG_UPDATABLE (1u << 1)
+#define FWUPD_DEVICE_FLAG_UPDATABLE (1llu << 1)
 /**
  * FWUPD_DEVICE_FLAG_ONLY_OFFLINE:
  *
@@ -125,7 +125,7 @@ typedef enum {
  *
  * Since 0.9.7
  */
-#define FWUPD_DEVICE_FLAG_ONLY_OFFLINE (1u << 2)
+#define FWUPD_DEVICE_FLAG_ONLY_OFFLINE (1llu << 2)
 /**
  * FWUPD_DEVICE_FLAG_REQUIRE_AC:
  *
@@ -134,7 +134,7 @@ typedef enum {
  *
  * Since 0.6.3
  */
-#define FWUPD_DEVICE_FLAG_REQUIRE_AC (1u << 3)
+#define FWUPD_DEVICE_FLAG_REQUIRE_AC (1llu << 3)
 /**
  * FWUPD_DEVICE_FLAG_LOCKED:
  *
@@ -142,7 +142,7 @@ typedef enum {
  *
  * Since 0.6.3
  */
-#define FWUPD_DEVICE_FLAG_LOCKED (1u << 4)
+#define FWUPD_DEVICE_FLAG_LOCKED (1llu << 4)
 /**
  * FWUPD_DEVICE_FLAG_SUPPORTED:
  *
@@ -150,7 +150,7 @@ typedef enum {
  *
  * Since 0.7.1
  */
-#define FWUPD_DEVICE_FLAG_SUPPORTED (1u << 5)
+#define FWUPD_DEVICE_FLAG_SUPPORTED (1llu << 5)
 /**
  * FWUPD_DEVICE_FLAG_NEEDS_BOOTLOADER:
  *
@@ -158,7 +158,7 @@ typedef enum {
  *
  * Since 0.7.3
  */
-#define FWUPD_DEVICE_FLAG_NEEDS_BOOTLOADER (1u << 6)
+#define FWUPD_DEVICE_FLAG_NEEDS_BOOTLOADER (1llu << 6)
 /**
  * FWUPD_DEVICE_FLAG_REGISTERED:
  *
@@ -166,7 +166,7 @@ typedef enum {
  *
  * Since 0.9.7
  */
-#define FWUPD_DEVICE_FLAG_REGISTERED (1u << 7)
+#define FWUPD_DEVICE_FLAG_REGISTERED (1llu << 7)
 /**
  * FWUPD_DEVICE_FLAG_NEEDS_REBOOT:
  *
@@ -174,7 +174,7 @@ typedef enum {
  *
  * Since 0.9.7
  */
-#define FWUPD_DEVICE_FLAG_NEEDS_REBOOT (1u << 8)
+#define FWUPD_DEVICE_FLAG_NEEDS_REBOOT (1llu << 8)
 /**
  * FWUPD_DEVICE_FLAG_REPORTED:
  *
@@ -182,7 +182,7 @@ typedef enum {
  *
  * Since: 1.0.4
  */
-#define FWUPD_DEVICE_FLAG_REPORTED (1u << 9)
+#define FWUPD_DEVICE_FLAG_REPORTED (1llu << 9)
 /**
  * FWUPD_DEVICE_FLAG_NOTIFIED:
  *
@@ -190,7 +190,7 @@ typedef enum {
  *
  * Since: 1.0.5
  */
-#define FWUPD_DEVICE_FLAG_NOTIFIED (1u << 10)
+#define FWUPD_DEVICE_FLAG_NOTIFIED (1llu << 10)
 /**
  * FWUPD_DEVICE_FLAG_USE_RUNTIME_VERSION:
  *
@@ -198,7 +198,7 @@ typedef enum {
  *
  * Since: 1.0.6
  */
-#define FWUPD_DEVICE_FLAG_USE_RUNTIME_VERSION (1u << 11)
+#define FWUPD_DEVICE_FLAG_USE_RUNTIME_VERSION (1llu << 11)
 /**
  * FWUPD_DEVICE_FLAG_INSTALL_PARENT_FIRST:
  *
@@ -207,7 +207,7 @@ typedef enum {
  *
  * Since: 1.0.8
  */
-#define FWUPD_DEVICE_FLAG_INSTALL_PARENT_FIRST (1u << 12)
+#define FWUPD_DEVICE_FLAG_INSTALL_PARENT_FIRST (1llu << 12)
 /**
  * FWUPD_DEVICE_FLAG_IS_BOOTLOADER:
  *
@@ -215,7 +215,7 @@ typedef enum {
  *
  * Since: 1.0.8
  */
-#define FWUPD_DEVICE_FLAG_IS_BOOTLOADER (1u << 13)
+#define FWUPD_DEVICE_FLAG_IS_BOOTLOADER (1llu << 13)
 /**
  * FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG:
  *
@@ -223,7 +223,7 @@ typedef enum {
  *
  * Since: 1.1.2
  */
-#define FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG (1u << 14)
+#define FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG (1llu << 14)
 /**
  * FWUPD_DEVICE_FLAG_IGNORE_VALIDATION:
  *
@@ -231,7 +231,7 @@ typedef enum {
  *
  * Since: 1.1.2
  */
-#define FWUPD_DEVICE_FLAG_IGNORE_VALIDATION (1u << 15)
+#define FWUPD_DEVICE_FLAG_IGNORE_VALIDATION (1llu << 15)
 /**
  * FWUPD_DEVICE_FLAG_TRUSTED:
  *
@@ -240,7 +240,7 @@ typedef enum {
  *
  * Since: 1.1.2
  */
-#define FWUPD_DEVICE_FLAG_TRUSTED (1u << 16)
+#define FWUPD_DEVICE_FLAG_TRUSTED (1llu << 16)
 /**
  * FWUPD_DEVICE_FLAG_NEEDS_SHUTDOWN:
  *
@@ -248,7 +248,7 @@ typedef enum {
  *
  * Since: 1.2.4
  */
-#define FWUPD_DEVICE_FLAG_NEEDS_SHUTDOWN (1u << 17)
+#define FWUPD_DEVICE_FLAG_NEEDS_SHUTDOWN (1llu << 17)
 /**
  * FWUPD_DEVICE_FLAG_ANOTHER_WRITE_REQUIRED:
  *
@@ -256,7 +256,7 @@ typedef enum {
  *
  * Since: 1.2.5
  */
-#define FWUPD_DEVICE_FLAG_ANOTHER_WRITE_REQUIRED (1u << 18)
+#define FWUPD_DEVICE_FLAG_ANOTHER_WRITE_REQUIRED (1llu << 18)
 /**
  * FWUPD_DEVICE_FLAG_NO_AUTO_INSTANCE_IDS:
  *
@@ -265,7 +265,7 @@ typedef enum {
  * Since: 1.2.5
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_NO_AUTO_INSTANCE_IDS (1u << 19)
+#define FWUPD_DEVICE_FLAG_NO_AUTO_INSTANCE_IDS (1llu << 19)
 /**
  * FWUPD_DEVICE_FLAG_NEEDS_ACTIVATION:
  *
@@ -275,7 +275,7 @@ typedef enum {
  *
  * Since: 1.2.6
  */
-#define FWUPD_DEVICE_FLAG_NEEDS_ACTIVATION (1u << 20)
+#define FWUPD_DEVICE_FLAG_NEEDS_ACTIVATION (1llu << 20)
 /**
  * FWUPD_DEVICE_FLAG_ENSURE_SEMVER:
  *
@@ -284,7 +284,7 @@ typedef enum {
  * Since: 1.2.9
  * Deprecate: 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_ENSURE_SEMVER (1u << 21)
+#define FWUPD_DEVICE_FLAG_ENSURE_SEMVER (1llu << 21)
 /**
  * FWUPD_DEVICE_FLAG_HISTORICAL:
  *
@@ -292,7 +292,7 @@ typedef enum {
  *
  * Since: 1.3.2
  */
-#define FWUPD_DEVICE_FLAG_HISTORICAL (1u << 22)
+#define FWUPD_DEVICE_FLAG_HISTORICAL (1llu << 22)
 /**
  * FWUPD_DEVICE_FLAG_ONLY_SUPPORTED:
  *
@@ -301,7 +301,7 @@ typedef enum {
  * Since: 1.3.3
  * Deprecated 1.5.5
  */
-#define FWUPD_DEVICE_FLAG_ONLY_SUPPORTED (1u << 23)
+#define FWUPD_DEVICE_FLAG_ONLY_SUPPORTED (1llu << 23)
 /**
  * FWUPD_DEVICE_FLAG_WILL_DISAPPEAR:
  *
@@ -310,7 +310,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_WILL_DISAPPEAR (1u << 24)
+#define FWUPD_DEVICE_FLAG_WILL_DISAPPEAR (1llu << 24)
 /**
  * FWUPD_DEVICE_FLAG_CAN_VERIFY:
  *
@@ -318,7 +318,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_CAN_VERIFY (1u << 25)
+#define FWUPD_DEVICE_FLAG_CAN_VERIFY (1llu << 25)
 /**
  * FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE:
  *
@@ -326,7 +326,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE (1u << 26)
+#define FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE (1llu << 26)
 /**
  * FWUPD_DEVICE_FLAG_DUAL_IMAGE:
  *
@@ -335,7 +335,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_DUAL_IMAGE (1u << 27)
+#define FWUPD_DEVICE_FLAG_DUAL_IMAGE (1llu << 27)
 /**
  * FWUPD_DEVICE_FLAG_SELF_RECOVERY:
  *
@@ -344,7 +344,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_SELF_RECOVERY (1u << 28)
+#define FWUPD_DEVICE_FLAG_SELF_RECOVERY (1llu << 28)
 /**
  * FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE:
  *
@@ -353,7 +353,7 @@ typedef enum {
  *
  * Since: 1.3.3
  */
-#define FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE (1u << 29)
+#define FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE (1llu << 29)
 /**
  * FWUPD_DEVICE_FLAG_VERSION_CHECK_REQUIRED:
  *
@@ -361,7 +361,7 @@ typedef enum {
  *
  * Since: 1.3.7
  */
-#define FWUPD_DEVICE_FLAG_VERSION_CHECK_REQUIRED (1u << 30)
+#define FWUPD_DEVICE_FLAG_VERSION_CHECK_REQUIRED (1llu << 30)
 /**
  * FWUPD_DEVICE_FLAG_INSTALL_ALL_RELEASES:
  *
@@ -369,7 +369,7 @@ typedef enum {
  *
  * Since: 1.3.7
  */
-#define FWUPD_DEVICE_FLAG_INSTALL_ALL_RELEASES (1u << 31)
+#define FWUPD_DEVICE_FLAG_INSTALL_ALL_RELEASES (1llu << 31)
 /**
  * FWUPD_DEVICE_FLAG_MD_SET_NAME:
  *
@@ -418,7 +418,7 @@ typedef enum {
 /**
  * FWUPD_DEVICE_FLAG_UPDATABLE_HIDDEN:
  *
- * The device is updatable but is currently inhbitied from updates in the client.
+ * The device is updatable but is currently inhibited from updates in the client.
  * Reasons include but are not limited to low power or requiring reboot from a previous update.
  *
  * Since: 1.4.1
@@ -527,6 +527,22 @@ typedef enum {
  * Since: 1.7.6
  */
 #define FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD (1llu << 48)
+/**
+ * FWUPD_DEVICE_FLAG_EMULATED:
+ *
+ * The device is emulated and should not be recorded by the backend.
+ *
+ * Since: 1.8.11
+ */
+#define FWUPD_DEVICE_FLAG_EMULATED (1llu << 49)
+/**
+ * FWUPD_DEVICE_FLAG_EMULATION_TAG:
+ *
+ * The device should be recorded by the backend, allowing emulation.
+ *
+ * Since: 1.8.11
+ */
+#define FWUPD_DEVICE_FLAG_EMULATION_TAG (1llu << 50)
 /**
  * FWUPD_DEVICE_FLAG_UNKNOWN:
  *
@@ -558,7 +574,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.1
  */
-#define FWUPD_DEVICE_PROBLEM_SYSTEM_POWER_TOO_LOW (1u << 0)
+#define FWUPD_DEVICE_PROBLEM_SYSTEM_POWER_TOO_LOW (1llu << 0)
 /**
  * FWUPD_DEVICE_PROBLEM_UNREACHABLE:
  *
@@ -566,7 +582,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.1
  */
-#define FWUPD_DEVICE_PROBLEM_UNREACHABLE (1u << 1)
+#define FWUPD_DEVICE_PROBLEM_UNREACHABLE (1llu << 1)
 /**
  * FWUPD_DEVICE_PROBLEM_POWER_TOO_LOW:
  *
@@ -574,7 +590,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.1
  */
-#define FWUPD_DEVICE_PROBLEM_POWER_TOO_LOW (1u << 2)
+#define FWUPD_DEVICE_PROBLEM_POWER_TOO_LOW (1llu << 2)
 /**
  * FWUPD_DEVICE_PROBLEM_UPDATE_PENDING:
  *
@@ -582,7 +598,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.1
  */
-#define FWUPD_DEVICE_PROBLEM_UPDATE_PENDING (1u << 3)
+#define FWUPD_DEVICE_PROBLEM_UPDATE_PENDING (1llu << 3)
 /**
  * FWUPD_DEVICE_PROBLEM_REQUIRE_AC_POWER:
  *
@@ -590,7 +606,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.1
  */
-#define FWUPD_DEVICE_PROBLEM_REQUIRE_AC_POWER (1u << 4)
+#define FWUPD_DEVICE_PROBLEM_REQUIRE_AC_POWER (1llu << 4)
 /**
  * FWUPD_DEVICE_PROBLEM_LID_IS_CLOSED:
  *
@@ -598,7 +614,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.1
  */
-#define FWUPD_DEVICE_PROBLEM_LID_IS_CLOSED (1u << 5)
+#define FWUPD_DEVICE_PROBLEM_LID_IS_CLOSED (1llu << 5)
 /**
  * FWUPD_DEVICE_PROBLEM_IS_EMULATED:
  *
@@ -606,7 +622,7 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.3
  */
-#define FWUPD_DEVICE_PROBLEM_IS_EMULATED (1u << 6)
+#define FWUPD_DEVICE_PROBLEM_IS_EMULATED (1llu << 6)
 /**
  * FWUPD_DEVICE_PROBLEM_MISSING_LICENSE:
  *
@@ -614,7 +630,23 @@ typedef guint64 FwupdDeviceFlags;
  *
  * Since 1.8.6
  */
-#define FWUPD_DEVICE_PROBLEM_MISSING_LICENSE (1u << 7)
+#define FWUPD_DEVICE_PROBLEM_MISSING_LICENSE (1llu << 7)
+/**
+ * FWUPD_DEVICE_PROBLEM_SYSTEM_INHIBIT:
+ *
+ * The device cannot be updated due to a system-wide inhibit.
+ *
+ * Since 1.8.10
+ */
+#define FWUPD_DEVICE_PROBLEM_SYSTEM_INHIBIT (1llu << 8)
+/**
+ * FWUPD_DEVICE_PROBLEM_UPDATE_IN_PROGRESS:
+ *
+ * The device cannot be updated as it is already being updated.
+ *
+ * Since 1.8.11
+ */
+#define FWUPD_DEVICE_PROBLEM_UPDATE_IN_PROGRESS (1llu << 9)
 /**
  * FWUPD_DEVICE_PROBLEM_UNKNOWN:
  *
@@ -648,7 +680,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_TRUSTED_PAYLOAD (1u << 0)
+#define FWUPD_RELEASE_FLAG_TRUSTED_PAYLOAD (1llu << 0)
 /**
  * FWUPD_RELEASE_FLAG_TRUSTED_METADATA:
  *
@@ -656,7 +688,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_TRUSTED_METADATA (1u << 1)
+#define FWUPD_RELEASE_FLAG_TRUSTED_METADATA (1llu << 1)
 /**
  * FWUPD_RELEASE_FLAG_IS_UPGRADE:
  *
@@ -664,7 +696,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_IS_UPGRADE (1u << 2)
+#define FWUPD_RELEASE_FLAG_IS_UPGRADE (1llu << 2)
 /**
  * FWUPD_RELEASE_FLAG_IS_DOWNGRADE:
  *
@@ -672,7 +704,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_IS_DOWNGRADE (1u << 3)
+#define FWUPD_RELEASE_FLAG_IS_DOWNGRADE (1llu << 3)
 /**
  * FWUPD_RELEASE_FLAG_BLOCKED_VERSION:
  *
@@ -680,7 +712,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_BLOCKED_VERSION (1u << 4)
+#define FWUPD_RELEASE_FLAG_BLOCKED_VERSION (1llu << 4)
 /**
  * FWUPD_RELEASE_FLAG_BLOCKED_APPROVAL:
  *
@@ -688,7 +720,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.2.6
  */
-#define FWUPD_RELEASE_FLAG_BLOCKED_APPROVAL (1u << 5)
+#define FWUPD_RELEASE_FLAG_BLOCKED_APPROVAL (1llu << 5)
 /**
  * FWUPD_RELEASE_FLAG_IS_ALTERNATE_BRANCH:
  *
@@ -696,7 +728,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.5.0
  */
-#define FWUPD_RELEASE_FLAG_IS_ALTERNATE_BRANCH (1u << 6)
+#define FWUPD_RELEASE_FLAG_IS_ALTERNATE_BRANCH (1llu << 6)
 /**
  * FWUPD_RELEASE_FLAG_IS_COMMUNITY:
  *
@@ -704,7 +736,7 @@ typedef guint64 FwupdDeviceProblem;
  *
  * Since: 1.7.5
  */
-#define FWUPD_RELEASE_FLAG_IS_COMMUNITY (1u << 7)
+#define FWUPD_RELEASE_FLAG_IS_COMMUNITY (1llu << 7)
 /**
  * FWUPD_RELEASE_FLAG_UNKNOWN:
  *
@@ -755,7 +787,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_DISABLED (1u << 0)
+#define FWUPD_PLUGIN_FLAG_DISABLED (1llu << 0)
 /**
  * FWUPD_PLUGIN_FLAG_USER_WARNING:
  *
@@ -763,7 +795,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_USER_WARNING (1u << 1)
+#define FWUPD_PLUGIN_FLAG_USER_WARNING (1llu << 1)
 /**
  * FWUPD_PLUGIN_FLAG_CLEAR_UPDATABLE:
  *
@@ -772,7 +804,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_CLEAR_UPDATABLE (1u << 2)
+#define FWUPD_PLUGIN_FLAG_CLEAR_UPDATABLE (1llu << 2)
 /**
  * FWUPD_PLUGIN_FLAG_NO_HARDWARE:
  *
@@ -782,7 +814,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_NO_HARDWARE (1u << 3)
+#define FWUPD_PLUGIN_FLAG_NO_HARDWARE (1llu << 3)
 /**
  * FWUPD_PLUGIN_FLAG_CAPSULES_UNSUPPORTED:
  *
@@ -791,7 +823,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_CAPSULES_UNSUPPORTED (1u << 4)
+#define FWUPD_PLUGIN_FLAG_CAPSULES_UNSUPPORTED (1llu << 4)
 /**
  * FWUPD_PLUGIN_FLAG_UNLOCK_REQUIRED:
  *
@@ -800,7 +832,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_UNLOCK_REQUIRED (1u << 5)
+#define FWUPD_PLUGIN_FLAG_UNLOCK_REQUIRED (1llu << 5)
 /**
  * FWUPD_PLUGIN_FLAG_EFIVAR_NOT_MOUNTED:
  *
@@ -809,7 +841,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_EFIVAR_NOT_MOUNTED (1u << 6)
+#define FWUPD_PLUGIN_FLAG_EFIVAR_NOT_MOUNTED (1llu << 6)
 /**
  * FWUPD_PLUGIN_FLAG_ESP_NOT_FOUND:
  *
@@ -818,7 +850,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_ESP_NOT_FOUND (1u << 7)
+#define FWUPD_PLUGIN_FLAG_ESP_NOT_FOUND (1llu << 7)
 /**
  * FWUPD_PLUGIN_FLAG_LEGACY_BIOS:
  *
@@ -827,7 +859,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_LEGACY_BIOS (1u << 8)
+#define FWUPD_PLUGIN_FLAG_LEGACY_BIOS (1llu << 8)
 /**
  * FWUPD_PLUGIN_FLAG_FAILED_OPEN:
  *
@@ -836,7 +868,7 @@ typedef enum {
  *
  * Since: 1.5.0
  */
-#define FWUPD_PLUGIN_FLAG_FAILED_OPEN (1u << 9)
+#define FWUPD_PLUGIN_FLAG_FAILED_OPEN (1llu << 9)
 /**
  * FWUPD_PLUGIN_FLAG_REQUIRE_HWID:
  *
@@ -844,7 +876,7 @@ typedef enum {
  *
  * Since: 1.5.8
  */
-#define FWUPD_PLUGIN_FLAG_REQUIRE_HWID (1u << 10)
+#define FWUPD_PLUGIN_FLAG_REQUIRE_HWID (1llu << 10)
 /**
  * FWUPD_PLUGIN_FLAG_KERNEL_TOO_OLD:
  *
@@ -852,7 +884,7 @@ typedef enum {
  *
  * Since: 1.6.2
  */
-#define FWUPD_PLUGIN_FLAG_KERNEL_TOO_OLD (1u << 11)
+#define FWUPD_PLUGIN_FLAG_KERNEL_TOO_OLD (1llu << 11)
 /**
  * FWUPD_PLUGIN_FLAG_AUTH_REQUIRED:
  *
@@ -861,7 +893,7 @@ typedef enum {
  *
  * Since: 1.6.2
  */
-#define FWUPD_PLUGIN_FLAG_AUTH_REQUIRED (1u << 12)
+#define FWUPD_PLUGIN_FLAG_AUTH_REQUIRED (1llu << 12)
 /**
  * FWUPD_PLUGIN_FLAG_SECURE_CONFIG:
  *
@@ -870,7 +902,7 @@ typedef enum {
  *
  * Since: 1.8.5
  */
-#define FWUPD_PLUGIN_FLAG_SECURE_CONFIG (1u << 13)
+#define FWUPD_PLUGIN_FLAG_SECURE_CONFIG (1llu << 13)
 /**
  * FWUPD_PLUGIN_FLAG_MODULAR:
  *
@@ -878,7 +910,7 @@ typedef enum {
  *
  * Since: 1.8.6
  */
-#define FWUPD_PLUGIN_FLAG_MODULAR (1u << 14)
+#define FWUPD_PLUGIN_FLAG_MODULAR (1llu << 14)
 /**
  * FWUPD_PLUGIN_FLAG_MEASURE_SYSTEM_INTEGRITY:
  *
@@ -886,7 +918,7 @@ typedef enum {
  *
  * Since: 1.8.7
  */
-#define FWUPD_PLUGIN_FLAG_MEASURE_SYSTEM_INTEGRITY (1u << 15)
+#define FWUPD_PLUGIN_FLAG_MEASURE_SYSTEM_INTEGRITY (1llu << 15)
 /**
  * FWUPD_PLUGIN_FLAG_UNKNOWN:
  *
