@@ -6,7 +6,6 @@
 
 #pragma once
 
-#include <glib-object.h>
 #include <json-glib/json-glib.h>
 
 #include "fwupd-release.h"
@@ -17,5 +16,7 @@ GVariant *
 fwupd_release_to_variant(FwupdRelease *self);
 void
 fwupd_release_to_json(FwupdRelease *self, JsonBuilder *builder);
+void
+fwupd_release_incorporate(FwupdRelease *self, FwupdRelease *donor);
 
 G_END_DECLS
