@@ -32,9 +32,13 @@ struct _FwupdSecurityAttrClass {
  * @FWUPD_SECURITY_ATTR_FLAG_NONE:			No flags set
  * @FWUPD_SECURITY_ATTR_FLAG_SUCCESS:			Success
  * @FWUPD_SECURITY_ATTR_FLAG_OBSOLETED:			Obsoleted by another attribute
+ * @FWUPD_SECURITY_ATTR_FLAG_MISSING_DATA:		Missing data
  * @FWUPD_SECURITY_ATTR_FLAG_RUNTIME_UPDATES:		Suffix `U`
  * @FWUPD_SECURITY_ATTR_FLAG_RUNTIME_ATTESTATION:	Suffix `A`
  * @FWUPD_SECURITY_ATTR_FLAG_RUNTIME_ISSUE:		Suffix `!`
+ * @FWUPD_SECURITY_ATTR_FLAG_ACTION_CONTACT_OEM:	Contact the firmware vendor for a update
+ * @FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_FW:		Failure may be fixed by changing FW config
+ * @FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_OS:		Failure may be fixed by changing OS config
  *
  * The flags available for HSI attributes.
  **/
@@ -42,9 +46,13 @@ typedef enum {
 	FWUPD_SECURITY_ATTR_FLAG_NONE = 0,
 	FWUPD_SECURITY_ATTR_FLAG_SUCCESS = 1 << 0,
 	FWUPD_SECURITY_ATTR_FLAG_OBSOLETED = 1 << 1,
+	FWUPD_SECURITY_ATTR_FLAG_MISSING_DATA = 1 << 2,
 	FWUPD_SECURITY_ATTR_FLAG_RUNTIME_UPDATES = 1 << 8,
 	FWUPD_SECURITY_ATTR_FLAG_RUNTIME_ATTESTATION = 1 << 9,
 	FWUPD_SECURITY_ATTR_FLAG_RUNTIME_ISSUE = 1 << 10,
+	FWUPD_SECURITY_ATTR_FLAG_ACTION_CONTACT_OEM = 1 << 11,
+	FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_FW = 1 << 12,
+	FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_OS = 1 << 13,
 } FwupdSecurityAttrFlags;
 
 /**
@@ -118,6 +126,19 @@ fwupd_security_attr_new(const gchar *appstream_id);
 gchar *
 fwupd_security_attr_to_string(FwupdSecurityAttr *self);
 
+const gchar *
+fwupd_security_attr_get_bios_setting_id(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_bios_setting_id(FwupdSecurityAttr *self, const gchar *id);
+const gchar *
+fwupd_security_attr_get_bios_setting_target_value(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_bios_setting_target_value(FwupdSecurityAttr *self, const gchar *value);
+const gchar *
+fwupd_security_attr_get_bios_setting_current_value(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_bios_setting_current_value(FwupdSecurityAttr *self, const gchar *value);
+
 const gchar *
 fwupd_security_attr_get_appstream_id(FwupdSecurityAttr *self);
 void
@@ -130,11 +151,23 @@ FwupdSecurityAttrResult
 fwupd_security_attr_get_result(FwupdSecurityAttr *self);
 void
 fwupd_security_attr_set_result(FwupdSecurityAttr *self, FwupdSecurityAttrResult result);
+FwupdSecurityAttrResult
+fwupd_security_attr_get_result_fallback(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_result_fallback(FwupdSecurityAttr *self, FwupdSecurityAttrResult result);
 const gchar *
 fwupd_security_attr_get_name(FwupdSecurityAttr *self);
 void
 fwupd_security_attr_set_name(FwupdSecurityAttr *self, const gchar *name);
 const gchar *
+fwupd_security_attr_get_title(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_title(FwupdSecurityAttr *self, const gchar *title);
+const gchar *
+fwupd_security_attr_get_description(FwupdSecurityAttr *self);
+void
+fwupd_security_attr_set_description(FwupdSecurityAttr *self, const gchar *description);
+const gchar *
 fwupd_security_attr_get_plugin(FwupdSecurityAttr *self);
 void
 fwupd_security_attr_set_plugin(FwupdSecurityAttr *self, const gchar *plugin);
@@ -170,6 +203,8 @@ void
 fwupd_security_attr_set_flags(FwupdSecurityAttr *self, FwupdSecurityAttrFlags flags);
 void
 fwupd_security_attr_add_flag(FwupdSecurityAttr *self, FwupdSecurityAttrFlags flag);
+void
+fwupd_security_attr_remove_flag(FwupdSecurityAttr *self, FwupdSecurityAttrFlags flag);
 gboolean
 fwupd_security_attr_has_flag(FwupdSecurityAttr *self, FwupdSecurityAttrFlags flag);
 const gchar *
