@@ -290,7 +290,7 @@ fu_archive_lookup_by_fn(FuArchive *self, const gchar *fn, GError **error)
 /**
  * fu_archive_iterate:
  * @self: a #FuArchive
- * @callback: (scope call): a #FuArchiveIterateFunc.
+ * @callback: (scope call) (closure user_data): a #FuArchiveIterateFunc.
  * @user_data: user data
  * @error: (nullable): optional return location for an error
  *
@@ -611,8 +611,13 @@ fu_archive_write(FuArchive *self,
 				    "libarchive startup failed");
 		return NULL;
 	}
-	fu_archive_set_compression(arch, compression);
 	fu_archive_set_format(arch, format);
+	if (format == FU_ARCHIVE_FORMAT_ZIP) {
+		if (compression != FU_ARCHIVE_COMPRESSION_NONE)
+			archive_write_set_options(arch, "zip:compression=deflate");
+	} else {
+		fu_archive_set_compression(arch, compression);
+	}
 	r = archive_write_open(arch, blob, NULL, fu_archive_write_cb, NULL);
 	if (r != 0) {
 		g_set_error(error,
