@@ -8,7 +8,7 @@
 
 #include "config.h"
 
-#include "fu-backend.h"
+#include "fu-backend-private.h"
 #include "fu-string.h"
 
 /**
@@ -55,10 +55,14 @@ fu_backend_device_added(FuBackend *self, FuDevice *device)
 	g_return_if_fail(FU_IS_DEVICE(device));
 	g_return_if_fail(priv->thread_init == g_thread_self());
 
-	/* assign context if unset */
-	if (fu_device_get_context(device) == NULL)
+	/* assign context if set */
+	if (priv->ctx != NULL)
 		fu_device_set_context(device, priv->ctx);
 
+	/* set backend ID if required */
+	if (fu_device_get_backend_id(device) == NULL)
+		fu_device_set_backend_id(device, priv->name);
+
 	/* add */
 	g_hash_table_insert(priv->devices,
 			    g_strdup(fu_device_get_backend_id(device)),
@@ -220,6 +224,74 @@ fu_backend_setup(FuBackend *self, FuProgress *progress, GError **error)
 	return TRUE;
 }
 
+/**
+ * fu_backend_load:
+ * @self: a #FuBackend
+ * @json_object: a #JsonObject
+ * @tag: a string backend tag, or %NULL
+ * @flags: %FuBackendLoadFlags, typically `FU_BACKEND_LOAD_FLAG_NONE`
+ * @error: (nullable): optional return location for an error
+ *
+ * Loads the backend from a JSON object.
+ *
+ * Returns: %TRUE for success
+ *
+ * Since: 1.8.5
+ **/
+gboolean
+fu_backend_load(FuBackend *self,
+		JsonObject *json_object,
+		const gchar *tag,
+		FuBackendLoadFlags flags,
+		GError **error)
+{
+	FuBackendClass *klass = FU_BACKEND_GET_CLASS(self);
+
+	g_return_val_if_fail(FU_IS_BACKEND(self), FALSE);
+	g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
+
+	/* optional */
+	if (klass->load != NULL) {
+		if (!klass->load(self, json_object, tag, flags, error))
+			return FALSE;
+	}
+	return TRUE;
+}
+
+/**
+ * fu_backend_save:
+ * @self: a #FuBackend
+ * @json_builder: a #JsonBuilder
+ * @tag: a string backend tag, or %NULL
+ * @flags: %FuBackendSaveFlags, typically `FU_BACKEND_SAVE_FLAG_NONE`
+ * @error: (nullable): optional return location for an error
+ *
+ * Saves the backend to a JSON builder.
+ *
+ * Returns: %TRUE for success
+ *
+ * Since: 1.8.5
+ **/
+gboolean
+fu_backend_save(FuBackend *self,
+		JsonBuilder *json_builder,
+		const gchar *tag,
+		FuBackendSaveFlags flags,
+		GError **error)
+{
+	FuBackendClass *klass = FU_BACKEND_GET_CLASS(self);
+
+	g_return_val_if_fail(FU_IS_BACKEND(self), FALSE);
+	g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
+
+	/* optional */
+	if (klass->save != NULL) {
+		if (!klass->save(self, json_builder, tag, flags, error))
+			return FALSE;
+	}
+	return TRUE;
+}
+
 /**
  * fu_backend_coldplug:
  * @self: a #FuBackend
