@@ -17,6 +17,7 @@
 
 #include "fu-cabinet.h"
 #include "fu-common.h"
+#include "fu-string.h"
 
 /**
  * FuCabinet:
@@ -68,9 +69,19 @@ fu_cabinet_init(FuCabinet *self)
 {
 	self->size_max = 1024 * 1024 * 100;
 	self->gcab_cabinet = gcab_cabinet_new();
+#ifdef HAVE_GCAB_CABINET_ADD_ALLOWED_COMPRESSION
+	gcab_cabinet_add_allowed_compression(self->gcab_cabinet, GCAB_COMPRESSION_NONE);
+	gcab_cabinet_add_allowed_compression(self->gcab_cabinet, GCAB_COMPRESSION_MSZIP);
+#endif
 	self->builder = xb_builder_new();
 	self->jcat_file = jcat_file_new();
 	self->jcat_context = jcat_context_new();
+#if LIBJCAT_CHECK_VERSION(0, 1, 13)
+	jcat_context_blob_kind_allow(self->jcat_context, JCAT_BLOB_KIND_SHA256);
+	jcat_context_blob_kind_allow(self->jcat_context, JCAT_BLOB_KIND_SHA512);
+	jcat_context_blob_kind_allow(self->jcat_context, JCAT_BLOB_KIND_PKCS7);
+	jcat_context_blob_kind_allow(self->jcat_context, JCAT_BLOB_KIND_GPG);
+#endif
 }
 
 /**
@@ -248,7 +259,7 @@ fu_cabinet_parse_release(FuCabinet *self, XbNode *release, GError **error)
 		release_flags |= FWUPD_RELEASE_FLAG_TRUSTED_METADATA;
 
 	/* look for source artifact first */
-	artifact = xb_node_query_first(release, "artifacts/artifact[@type='binary']", NULL);
+	artifact = xb_node_query_first(release, "artifacts/artifact[@type='source']", NULL);
 	if (artifact != NULL) {
 		csum_filename = xb_node_query_text(artifact, "filename", NULL);
 		csum_tmp = xb_node_query_first(artifact, "checksum[@type='sha256']", NULL);
@@ -291,7 +302,9 @@ fu_cabinet_parse_release(FuCabinet *self, XbNode *release, GError **error)
 	/* set as metadata if unset, but error if specified and incorrect */
 	nsize = xb_node_query_first(release, "size[@type='installed']", NULL);
 	if (nsize != NULL) {
-		guint64 size = fu_common_strtoull(xb_node_get_text(nsize));
+		guint64 size = 0;
+		if (!fu_strtoull(xb_node_get_text(nsize), &size, 0, G_MAXSIZE, error))
+			return FALSE;
 		if (size != g_bytes_get_size(blob)) {
 			g_set_error(error,
 				    FWUPD_ERROR,
