@@ -6,8 +6,6 @@
 
 #pragma once
 
-#include <glib-object.h>
-
 #include "fu-device.h"
 
 #define FU_TYPE_CFI_DEVICE (fu_cfi_device_get_type())
@@ -15,7 +13,7 @@ G_DECLARE_DERIVABLE_TYPE(FuCfiDevice, fu_cfi_device, FU, CFI_DEVICE, FuDevice)
 
 struct _FuCfiDeviceClass {
 	FuDeviceClass parent_class;
-	gpointer __reserved[31];
+	gboolean (*chip_select)(FuCfiDevice *self, gboolean value, GError **error);
 };
 
 /**
@@ -70,3 +68,8 @@ void
 fu_cfi_device_set_block_size(FuCfiDevice *self, guint32 block_size);
 gboolean
 fu_cfi_device_get_cmd(FuCfiDevice *self, FuCfiDeviceCmd cmd, guint8 *value, GError **error);
+
+gboolean
+fu_cfi_device_chip_select(FuCfiDevice *self, gboolean value, GError **error);
+FuDeviceLocker *
+fu_cfi_device_chip_select_locker_new(FuCfiDevice *self, GError **error);
