@@ -30,12 +30,16 @@ gint
 fu_device_get_order(FuDevice *self);
 void
 fu_device_set_order(FuDevice *self, gint order);
+const gchar *
+fu_device_get_update_request_id(FuDevice *self);
+void
+fu_device_set_update_request_id(FuDevice *self, const gchar *update_request_id);
 void
 fu_device_set_alternate(FuDevice *self, FuDevice *alternate);
 gboolean
 fu_device_ensure_id(FuDevice *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 void
-fu_device_incorporate_from_component(FuDevice *device, XbNode *component);
+fu_device_incorporate_from_component(FuDevice *self, XbNode *component);
 void
 fu_device_convert_instance_ids(FuDevice *self);
 gchar *
@@ -56,3 +60,5 @@ FuDeviceInternalFlags
 fu_device_get_internal_flags(FuDevice *self);
 void
 fu_device_set_internal_flags(FuDevice *self, FuDeviceInternalFlags flags);
+gboolean
+fu_device_set_quirk_kv(FuDevice *self, const gchar *key, const gchar *value, GError **error);
