@@ -50,6 +50,7 @@ struct _FuDeviceClass {
 				 GError **error) G_GNUC_WARN_UNUSED_RESULT;
 	gboolean (*setup)(FuDevice *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 	void (*incorporate)(FuDevice *self, FuDevice *donor);
+	void (*probe_complete)(FuDevice *self);
 	gboolean (*poll)(FuDevice *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 	gboolean (*activate)(FuDevice *self,
 			     FuProgress *progress,
@@ -123,7 +124,7 @@ typedef enum {
 /**
  * FuDeviceRetryFunc:
  * @self: a #FuDevice
- * @user_data: user data
+ * @user_data: (closure): user data
  * @error: (nullable): optional return location for an error
  *
  * The device retry iteration callback.
@@ -205,6 +206,10 @@ fu_device_new(FuContext *ctx);
 #define fu_device_get_flashes_left(d)	    fwupd_device_get_flashes_left(FWUPD_DEVICE(d))
 #define fu_device_get_install_duration(d)   fwupd_device_get_install_duration(FWUPD_DEVICE(d))
 #define fu_device_get_release_default(d)    fwupd_device_get_release_default(FWUPD_DEVICE(d))
+#define fu_device_get_status(d)		    fwupd_device_get_status(FWUPD_DEVICE(d))
+#define fu_device_set_status(d, v)	    fwupd_device_set_status(FWUPD_DEVICE(d), v)
+#define fu_device_get_percentage(d)	    fwupd_device_get_percentage(FWUPD_DEVICE(d))
+#define fu_device_set_percentage(d, v)	    fwupd_device_set_percentage(FWUPD_DEVICE(d), v)
 
 /**
  * FuDeviceInternalFlags:
@@ -369,7 +374,7 @@ typedef guint64 FuDeviceInternalFlags;
 /**
  * FU_DEVICE_INTERNAL_FLAG_NO_AUTO_REMOVE_CHILDREN:
  *
- * Do not auto-remove clildren in the device list.
+ * Do not auto-remove children in the device list.
  *
  * Since: 1.6.2
  */
@@ -466,6 +471,28 @@ typedef guint64 FuDeviceInternalFlags;
  */
 #define FU_DEVICE_INTERNAL_FLAG_ONLY_WAIT_FOR_REPLUG (1ull << 25)
 
+/**
+ * FU_DEVICE_INTERNAL_FLAG_IGNORE_SYSTEM_POWER:
+ *
+ * Allow updating firmware when the system power is otherwise too low.
+ * This is only really useful when updating the system battery firmware.
+ *
+ * Since: 1.8.11
+ */
+#define FU_DEVICE_INTERNAL_FLAG_IGNORE_SYSTEM_POWER (1ull << 26)
+
+/**
+ * FU_DEVICE_INTERNAL_FLAG_NO_PROBE_COMPLETE:
+ *
+ * Do not deallocate resources typically only required during `->probe`.
+ *
+ * Note: the daemon will not actually free or unref device resources, but the plugin should
+ * still use this flag. After a a few releases and a lot of testing we'll actually flip the switch.
+ *
+ * Since: 1.8.12
+ */
+#define FU_DEVICE_INTERNAL_FLAG_NO_PROBE_COMPLETE (1ull << 27)
+
 /* accessors */
 gchar *
 fu_device_to_string(FuDevice *self);
@@ -540,11 +567,11 @@ fu_device_set_version_lowest(FuDevice *self, const gchar *version);
 void
 fu_device_set_version_bootloader(FuDevice *self, const gchar *version);
 void
-fu_device_add_backend_tag(FuDevice *self, const gchar *backend_tag);
-gboolean
-fu_device_has_backend_tag(FuDevice *self, const gchar *backend_tag);
-GPtrArray *
-fu_device_get_backend_tags(FuDevice *self);
+fu_device_set_version_from_uint16(FuDevice *self, guint16 version_raw);
+void
+fu_device_set_version_from_uint32(FuDevice *self, guint32 version_raw);
+void
+fu_device_set_version_from_uint64(FuDevice *self, guint64 version_raw);
 void
 fu_device_inhibit(FuDevice *self, const gchar *inhibit_id, const gchar *reason);
 void
@@ -554,6 +581,8 @@ fu_device_add_problem(FuDevice *self, FwupdDeviceProblem problem);
 void
 fu_device_remove_problem(FuDevice *self, FwupdDeviceProblem problem);
 gboolean
+fu_device_has_problem(FuDevice *self, FwupdDeviceProblem problem);
+gboolean
 fu_device_has_inhibit(FuDevice *self, const gchar *inhibit_id);
 const gchar *
 fu_device_get_physical_id(FuDevice *self);
@@ -688,6 +717,8 @@ gboolean
 fu_device_activate(FuDevice *self, FuProgress *progress, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 void
 fu_device_probe_invalidate(FuDevice *self);
+void
+fu_device_probe_complete(FuDevice *self);
 gboolean
 fu_device_poll(FuDevice *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 void
@@ -709,6 +740,10 @@ fu_device_retry_full(FuDevice *self,
 		     guint delay,
 		     gpointer user_data,
 		     GError **error) G_GNUC_WARN_UNUSED_RESULT;
+void
+fu_device_sleep(FuDevice *self, guint delay_ms);
+void
+fu_device_sleep_full(FuDevice *self, guint delay_ms, FuProgress *progress);
 gboolean
 fu_device_bind_driver(FuDevice *self, const gchar *subsystem, const gchar *driver, GError **error)
     G_GNUC_WARN_UNUSED_RESULT;
@@ -748,8 +783,10 @@ fu_device_add_instance_u16(FuDevice *self, const gchar *key, guint16 value);
 void
 fu_device_add_instance_u32(FuDevice *self, const gchar *key, guint32 value);
 gboolean
-fu_device_build_instance_id(FuDevice *self, GError **error, const gchar *subsystem, ...);
+fu_device_build_instance_id(FuDevice *self, GError **error, const gchar *subsystem, ...)
+    G_GNUC_NULL_TERMINATED;
 gboolean
-fu_device_build_instance_id_quirk(FuDevice *self, GError **error, const gchar *subsystem, ...);
+fu_device_build_instance_id_quirk(FuDevice *self, GError **error, const gchar *subsystem, ...)
+    G_GNUC_NULL_TERMINATED;
 FuDeviceLocker *
 fu_device_poll_locker_new(FuDevice *self, GError **error);
