@@ -76,6 +76,8 @@ fu_firmware_flag_to_string(FuFirmwareFlags flag)
 		return "done-parse";
 	if (flag == FU_FIRMWARE_FLAG_HAS_STORED_SIZE)
 		return "has-stored-size";
+	if (flag == FU_FIRMWARE_FLAG_ALWAYS_SEARCH)
+		return "always-search";
 	return NULL;
 }
 
@@ -104,6 +106,8 @@ fu_firmware_flag_from_string(const gchar *flag)
 		return FU_FIRMWARE_FLAG_DONE_PARSE;
 	if (g_strcmp0(flag, "has-stored-size") == 0)
 		return FU_FIRMWARE_FLAG_HAS_STORED_SIZE;
+	if (g_strcmp0(flag, "always-search") == 0)
+		return FU_FIRMWARE_FLAG_ALWAYS_SEARCH;
 	return FU_FIRMWARE_FLAG_NONE;
 }
 
@@ -519,7 +523,6 @@ fu_firmware_set_bytes(FuFirmware *self, GBytes *bytes)
 	FuFirmwarePrivate *priv = GET_PRIVATE(self);
 	g_return_if_fail(FU_IS_FIRMWARE(self));
 	g_return_if_fail(bytes != NULL);
-	g_return_if_fail(priv->bytes == NULL);
 	if (priv->bytes != NULL)
 		g_bytes_unref(priv->bytes);
 	priv->bytes = g_bytes_ref(bytes);
@@ -817,7 +820,8 @@ fu_firmware_check_magic_for_offset(FuFirmware *self,
 		return TRUE;
 
 	/* fuzzing */
-	if ((flags & FWUPD_INSTALL_FLAG_NO_SEARCH) > 0) {
+	if (!fu_firmware_has_flag(self, FU_FIRMWARE_FLAG_ALWAYS_SEARCH) &&
+	    (flags & FWUPD_INSTALL_FLAG_NO_SEARCH) > 0) {
 		if (!klass->check_magic(self, fw, *offset, error)) {
 			g_prefix_error(error, "not searching magic due to install flags: ");
 			return FALSE;
@@ -907,6 +911,11 @@ fu_firmware_parse_full(FuFirmware *self,
 	}
 	if (!fu_firmware_check_magic_for_offset(self, fw, &offset, flags, error))
 		return FALSE;
+
+	/* always set by default */
+	fu_firmware_set_bytes(self, fw);
+
+	/* handled by the subclass */
 	if (klass->parse != NULL)
 		return klass->parse(self, fw, offset, flags, error);
 
@@ -923,9 +932,7 @@ fu_firmware_parse_full(FuFirmware *self,
 		return FALSE;
 	}
 
-	/* just add entire blob */
-	fu_firmware_set_bytes(self, fw);
-	fu_firmware_set_size(self, g_bytes_get_size(fw));
+	/* success */
 	return TRUE;
 }
 
@@ -1032,6 +1039,9 @@ fu_firmware_build(FuFirmware *self, XbNode *n, GError **error)
 	tmpval = xb_node_query_text_as_uint(n, "offset", NULL);
 	if (tmpval != G_MAXUINT64)
 		fu_firmware_set_offset(self, tmpval);
+	tmpval = xb_node_query_text_as_uint(n, "size", NULL);
+	if (tmpval != G_MAXUINT64)
+		fu_firmware_set_size(self, tmpval);
 	tmpval = xb_node_query_text_as_uint(n, "alignment", NULL);
 	if (tmpval != G_MAXUINT64) {
 		if (tmpval > FU_FIRMWARE_ALIGNMENT_2G) {
@@ -1382,6 +1392,7 @@ gboolean
 fu_firmware_write_file(FuFirmware *self, GFile *file, GError **error)
 {
 	g_autoptr(GBytes) blob = NULL;
+	g_autoptr(GFile) parent = NULL;
 
 	g_return_val_if_fail(FU_IS_FIRMWARE(self), FALSE);
 	g_return_val_if_fail(G_IS_FILE(file), FALSE);
@@ -1390,6 +1401,11 @@ fu_firmware_write_file(FuFirmware *self, GFile *file, GError **error)
 	blob = fu_firmware_write(self, error);
 	if (blob == NULL)
 		return FALSE;
+	parent = g_file_get_parent(file);
+	if (!g_file_query_exists(parent, NULL)) {
+		if (!g_file_make_directory_with_parents(parent, NULL, error))
+			return FALSE;
+	}
 	return g_file_replace_contents(file,
 				       g_bytes_get_data(blob, NULL),
 				       g_bytes_get_size(blob),
@@ -1996,7 +2012,7 @@ fu_firmware_new_from_gtypes(GBytes *fw, FwupdInstallFlags flags, GError **error,
 
 	/* create array of GTypes */
 	va_start(args, error);
-	for (guint i = 0;; i++) {
+	while (TRUE) {
 		GType gtype = va_arg(args, GType);
 		if (gtype == G_TYPE_INVALID)
 			break;
