@@ -67,8 +67,6 @@ struct _FuFirmwareClass {
 				     FuFirmware *other,
 				     FwupdInstallFlags flags,
 				     GError **error);
-	/*< private >*/
-	gpointer padding[24];
 };
 
 /**
@@ -82,7 +80,7 @@ struct _FuFirmwareClass {
 /**
  * FU_FIRMWARE_FLAG_DEDUPE_ID:
  *
- * Dedupe imges by ID.
+ * Dedupe images by ID.
  *
  * Since: 1.5.0
  **/
@@ -90,7 +88,7 @@ struct _FuFirmwareClass {
 /**
  * FU_FIRMWARE_FLAG_DEDUPE_IDX:
  *
- * Dedupe imges by IDX.
+ * Dedupe images by IDX.
  *
  * Since: 1.5.0
  **/
@@ -127,6 +125,16 @@ struct _FuFirmwareClass {
  * Since: 1.8.2
  **/
 #define FU_FIRMWARE_FLAG_HAS_STORED_SIZE (1u << 5)
+/**
+ * FU_FIRMWARE_FLAG_ALWAYS_SEARCH:
+ *
+ * Always searches for magic regardless of the install flags.
+ * This is useful for firmware that always has an *unparsed* variable-length
+ * header.
+ *
+ * Since: 1.8.6
+ **/
+#define FU_FIRMWARE_FLAG_ALWAYS_SEARCH (1u << 6)
 
 /**
  * FuFirmwareFlags:
