@@ -6,8 +6,11 @@
 
 #include "config.h"
 
+#include "fu-byte-array.h"
+#include "fu-bytes.h"
 #include "fu-common.h"
 #include "fu-fmap-firmware.h"
+#include "fu-mem.h"
 
 /**
  * FuFmapFirmware:
@@ -22,18 +25,44 @@
 
 G_DEFINE_TYPE(FuFmapFirmware, fu_fmap_firmware, FU_TYPE_FIRMWARE)
 
+static gboolean
+fu_fmap_firmware_check_magic(FuFirmware *firmware, GBytes *fw, gsize offset, GError **error)
+{
+	guint8 magic[8] = {0x0};
+
+	if (!fu_memcpy_safe(magic,
+			    sizeof(magic),
+			    0, /* dst */
+			    g_bytes_get_data(fw, NULL),
+			    g_bytes_get_size(fw),
+			    offset,
+			    sizeof(magic),
+			    error)) {
+		g_prefix_error(error, "failed to read magic: ");
+		return FALSE;
+	}
+	if (memcmp(magic, FMAP_SIGNATURE, sizeof(magic)) != 0) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_INVALID_FILE,
+				    "invalid magic for file");
+		return FALSE;
+	}
+
+	/* success */
+	return TRUE;
+}
+
 static gboolean
 fu_fmap_firmware_parse(FuFirmware *firmware,
 		       GBytes *fw,
-		       guint64 addr_start,
-		       guint64 addr_end,
+		       gsize offset,
 		       FwupdInstallFlags flags,
 		       GError **error)
 {
 	FuFmapFirmwareClass *klass_firmware = FU_FMAP_FIRMWARE_GET_CLASS(firmware);
 	gsize bufsz;
 	const guint8 *buf = g_bytes_get_data(fw, &bufsz);
-	gsize offset = 0;
 	FuFmap fmap;
 
 	/* corrupt */
@@ -45,13 +74,6 @@ fu_fmap_firmware_parse(FuFirmware *firmware,
 		return FALSE;
 	}
 
-	/* only search for the fmap signature if not fuzzing */
-	if ((flags & FWUPD_INSTALL_FLAG_NO_SEARCH) == 0) {
-		if (!fu_memmem_safe(buf, bufsz, (const guint8 *)FMAP_SIGNATURE, 8, &offset, error))
-			return FALSE;
-		fu_firmware_set_offset(firmware, offset);
-	}
-
 	/* load header */
 	if (!fu_memcpy_safe((guint8 *)&fmap,
 			    sizeof(fmap),
@@ -104,10 +126,10 @@ fu_fmap_firmware_parse(FuFirmware *firmware,
 		if (area.size == 0)
 			continue;
 
-		bytes = fu_common_bytes_new_offset(fw,
-						   (gsize)GUINT32_FROM_LE(area.offset),
-						   (gsize)GUINT32_FROM_LE(area.size),
-						   error);
+		bytes = fu_bytes_new_offset(fw,
+					    (gsize)GUINT32_FROM_LE(area.offset),
+					    (gsize)GUINT32_FROM_LE(area.size),
+					    error);
 		if (bytes == NULL)
 			return FALSE;
 		area_name = g_strndup((const gchar *)area.name, FU_FMAP_FIRMWARE_STRLEN);
@@ -127,7 +149,7 @@ fu_fmap_firmware_parse(FuFirmware *firmware,
 
 	/* subclassed */
 	if (klass_firmware->parse != NULL) {
-		if (!klass_firmware->parse(firmware, fw, addr_start, addr_end, flags, error))
+		if (!klass_firmware->parse(firmware, fw, offset, flags, error))
 			return FALSE;
 	}
 
@@ -154,7 +176,7 @@ fu_fmap_firmware_write(FuFirmware *firmware, GError **error)
 
 	/* pad to offset */
 	if (fu_firmware_get_offset(firmware) > 0)
-		fu_byte_array_set_size(buf, fu_firmware_get_offset(firmware));
+		fu_byte_array_set_size(buf, fu_firmware_get_offset(firmware), 0x00);
 
 	/* add header */
 	total_sz = offset = sizeof(hdr) + (sizeof(FuFmapArea) * images->len);
@@ -205,6 +227,7 @@ static void
 fu_fmap_firmware_class_init(FuFmapFirmwareClass *klass)
 {
 	FuFirmwareClass *klass_firmware = FU_FIRMWARE_CLASS(klass);
+	klass_firmware->check_magic = fu_fmap_firmware_check_magic;
 	klass_firmware->parse = fu_fmap_firmware_parse;
 	klass_firmware->write = fu_fmap_firmware_write;
 }
