@@ -6,8 +6,7 @@
 
 #pragma once
 
-#include <fwupdplugin.h>
-
+#include "fu-firmware.h"
 #include "fu-ifd-common.h"
 
 #define FU_TYPE_IFD_IMAGE (fu_ifd_image_get_type())
