@@ -49,7 +49,6 @@ typedef struct {
 	FuContext *ctx;
 	GArray *device_gtypes; /* (nullable): of #GType */
 	GHashTable *cache;     /* (nullable): platform_id:GObject */
-	GRWLock cache_mutex;
 	GHashTable *report_metadata; /* (nullable): key:value */
 	GFileMonitor *config_monitor;
 	FuPluginData *data;
@@ -163,10 +162,8 @@ gpointer
 fu_plugin_cache_lookup(FuPlugin *self, const gchar *id)
 {
 	FuPluginPrivate *priv = GET_PRIVATE(self);
-	g_autoptr(GRWLockReaderLocker) locker = g_rw_lock_reader_locker_new(&priv->cache_mutex);
 	g_return_val_if_fail(FU_IS_PLUGIN(self), NULL);
 	g_return_val_if_fail(id != NULL, NULL);
-	g_return_val_if_fail(locker != NULL, NULL);
 	if (priv->cache == NULL)
 		return NULL;
 	return g_hash_table_lookup(priv->cache, id);
@@ -186,11 +183,9 @@ void
 fu_plugin_cache_add(FuPlugin *self, const gchar *id, gpointer dev)
 {
 	FuPluginPrivate *priv = GET_PRIVATE(self);
-	g_autoptr(GRWLockWriterLocker) locker = g_rw_lock_writer_locker_new(&priv->cache_mutex);
 	g_return_if_fail(FU_IS_PLUGIN(self));
 	g_return_if_fail(id != NULL);
 	g_return_if_fail(G_IS_OBJECT(dev));
-	g_return_if_fail(locker != NULL);
 	if (priv->cache == NULL) {
 		priv->cache = g_hash_table_new_full(g_str_hash,
 						    g_str_equal,
@@ -213,10 +208,8 @@ void
 fu_plugin_cache_remove(FuPlugin *self, const gchar *id)
 {
 	FuPluginPrivate *priv = GET_PRIVATE(self);
-	g_autoptr(GRWLockWriterLocker) locker = g_rw_lock_writer_locker_new(&priv->cache_mutex);
 	g_return_if_fail(FU_IS_PLUGIN(self));
 	g_return_if_fail(id != NULL);
-	g_return_if_fail(locker != NULL);
 	if (priv->cache == NULL)
 		return;
 	g_hash_table_remove(priv->cache, id);
@@ -898,16 +891,33 @@ fu_plugin_runner_startup(FuPlugin *self, FuProgress *progress, GError **error)
 	/* ensure the configure file is set to the correct permission */
 	if (fu_plugin_has_flag(self, FWUPD_PLUGIN_FLAG_SECURE_CONFIG)) {
 		if (g_file_test(config_filename, G_FILE_TEST_EXISTS)) {
-			gint rc = g_chmod(config_filename, FU_PLUGIN_FILE_MODE_SECURE);
+			GStatBuf st = {0x0};
+			gint rc = g_stat(config_filename, &st);
 			if (rc != 0) {
 				g_set_error(error,
 					    G_IO_ERROR,
 					    G_IO_ERROR_FAILED,
-					    "failed to change permission of %s",
+					    "failed to get permission of %s",
 					    config_filename);
 				fu_plugin_add_flag(self, FWUPD_PLUGIN_FLAG_FAILED_OPEN);
 				return FALSE;
 			}
+			st.st_mode &= 0777;
+			if (st.st_mode != FU_PLUGIN_FILE_MODE_SECURE) {
+				g_debug("mode was 0%o, and needs to be 0%o",
+					st.st_mode,
+					(guint)FU_PLUGIN_FILE_MODE_SECURE);
+				rc = g_chmod(config_filename, FU_PLUGIN_FILE_MODE_SECURE);
+				if (rc != 0) {
+					g_set_error(error,
+						    G_IO_ERROR,
+						    G_IO_ERROR_FAILED,
+						    "failed to change permission of %s",
+						    config_filename);
+					fu_plugin_add_flag(self, FWUPD_PLUGIN_FLAG_FAILED_OPEN);
+					return FALSE;
+				}
+			}
 		}
 	}
 
@@ -1257,7 +1267,6 @@ fu_plugin_runner_prepare(FuPlugin *self,
 			 GError **error)
 {
 	FuPluginVfuncs *vfuncs = fu_plugin_get_vfuncs(self);
-	fu_device_add_backend_tag(device, "prepare");
 	return fu_plugin_runner_flagged_device_generic(self,
 						       device,
 						       progress,
@@ -1289,7 +1298,6 @@ fu_plugin_runner_cleanup(FuPlugin *self,
 			 GError **error)
 {
 	FuPluginVfuncs *vfuncs = fu_plugin_get_vfuncs(self);
-	fu_device_add_backend_tag(device, "cleanup");
 	return fu_plugin_runner_flagged_device_generic(self,
 						       device,
 						       progress,
@@ -1316,7 +1324,6 @@ gboolean
 fu_plugin_runner_attach(FuPlugin *self, FuDevice *device, FuProgress *progress, GError **error)
 {
 	FuPluginVfuncs *vfuncs = fu_plugin_get_vfuncs(self);
-	fu_device_add_backend_tag(device, "attach");
 	return fu_plugin_runner_device_generic_progress(
 	    self,
 	    device,
@@ -1343,7 +1350,6 @@ gboolean
 fu_plugin_runner_detach(FuPlugin *self, FuDevice *device, FuProgress *progress, GError **error)
 {
 	FuPluginVfuncs *vfuncs = fu_plugin_get_vfuncs(self);
-	fu_device_add_backend_tag(device, "detach");
 	return fu_plugin_runner_device_generic_progress(
 	    self,
 	    device,
@@ -1379,7 +1385,6 @@ fu_plugin_runner_reload(FuPlugin *self, FuDevice *device, GError **error)
 	locker = fu_device_locker_new(proxy, error);
 	if (locker == NULL)
 		return FALSE;
-	fu_device_add_backend_tag(device, "reload");
 	return fu_device_reload(device, error);
 }
 
@@ -1663,7 +1668,7 @@ fu_plugin_runner_backend_device_added(FuPlugin *self,
 		return FALSE;
 	}
 	g_debug("backend_device_added(%s)", fu_plugin_get_name(self));
-	if (!vfuncs->backend_device_added(self, device, &error_local)) {
+	if (!vfuncs->backend_device_added(self, device, progress, &error_local)) {
 		if (error_local == NULL) {
 			g_critical("unset plugin error in backend_device_added(%s)",
 				   fu_plugin_get_name(self));
@@ -1974,7 +1979,6 @@ fu_plugin_runner_activate(FuPlugin *self, FuDevice *device, FuProgress *progress
 	}
 
 	/* run vfunc */
-	fu_device_add_backend_tag(device, "activate");
 	if (!fu_plugin_runner_device_generic_progress(
 		self,
 		device,
@@ -2024,7 +2028,6 @@ fu_plugin_runner_unlock(FuPlugin *self, FuDevice *device, GError **error)
 	}
 
 	/* run vfunc */
-	fu_device_add_backend_tag(device, "unlock");
 	if (!fu_plugin_runner_device_generic(self,
 					     device,
 					     "fu_plugin_unlock",
@@ -2074,7 +2077,6 @@ fu_plugin_runner_write_firmware(FuPlugin *self,
 		g_debug("plugin not enabled, skipping");
 		return TRUE;
 	}
-	fu_device_add_backend_tag(device, "write-firmware");
 
 	/* optional */
 	if (vfuncs->write_firmware == NULL) {
@@ -2804,8 +2806,6 @@ fu_plugin_class_init(FuPluginClass *klass)
 static void
 fu_plugin_init(FuPlugin *self)
 {
-	FuPluginPrivate *priv = GET_PRIVATE(self);
-	g_rw_lock_init(&priv->cache_mutex);
 }
 
 static void
@@ -2815,8 +2815,6 @@ fu_plugin_finalize(GObject *object)
 	FuPluginPrivate *priv = GET_PRIVATE(self);
 	FuPluginVfuncs *vfuncs = fu_plugin_get_vfuncs(self);
 
-	g_rw_lock_clear(&priv->cache_mutex);
-
 	/* optional */
 	if (priv->done_init && vfuncs->finalize != NULL) {
 		g_debug("finalize(%s)", fu_plugin_get_name(self));
