@@ -89,8 +89,7 @@ fu_quirks_build_group_key(const gchar *group)
 static gboolean
 fu_quirks_validate_flags(const gchar *value, GError **error)
 {
-	if (value == NULL)
-		return FALSE;
+	g_return_val_if_fail(value != NULL, FALSE);
 	for (gsize i = 0; value[i] != '\0'; i++) {
 		gchar tmp = value[i];
 
@@ -428,6 +427,10 @@ fu_quirks_check_silo(FuQuirks *self, GError **error)
 		g_prefix_error(error, "failed to prepare query: ");
 		return FALSE;
 	}
+	if (!xb_silo_query_build_index(self->silo, "quirk/device", "id", error))
+		return FALSE;
+	if (!xb_silo_query_build_index(self->silo, "quirk/device/value", "key", error))
+		return FALSE;
 
 	/* success */
 	return TRUE;
@@ -503,7 +506,7 @@ fu_quirks_lookup_by_id(FuQuirks *self, const gchar *guid, const gchar *key)
  * fu_quirks_lookup_by_id_iter:
  * @self: a #FuQuirks
  * @guid: GUID to lookup
- * @iter_cb: (scope async): a function to call for each result
+ * @iter_cb: (scope call) (closure user_data): a function to call for each result
  * @user_data: user data passed to @iter_cb
  *
  * Looks up all entries in the hardware database using a GUID value.
