@@ -6,8 +6,6 @@
 
 #pragma once
 
-#include <glib-object.h>
-
 #include "fu-smbios.h"
 
 gboolean
@@ -20,7 +18,3 @@ gboolean
 fu_smbios_setup_from_file(FuSmbios *self,
 			  const gchar *filename,
 			  GError **error) G_GNUC_WARN_UNUSED_RESULT;
-gboolean
-fu_smbios_setup_from_kernel(FuSmbios *self,
-			    const gchar *path,
-			    GError **error) G_GNUC_WARN_UNUSED_RESULT;
