@@ -33,12 +33,14 @@ gchar **
 fu_strsplit(const gchar *str, gsize sz, const gchar *delimiter, gint max_tokens);
 gchar *
 fu_strjoin(const gchar *separator, GPtrArray *array);
+GString *
+fu_strdup(const gchar *str, gsize bufsz, gsize offset);
 
 /**
  * FuStrsplitFunc:
  * @token: a #GString
  * @token_idx: the token number
- * @user_data: user data
+ * @user_data: (closure): user data
  * @error: a #GError or NULL
  *
  * The fu_strsplit_full() iteration callback.
