@@ -36,6 +36,8 @@
 
 typedef struct {
 	GUdevDevice *udev_device;
+	gboolean udev_device_cleared;
+	guint32 class;
 	guint16 vendor;
 	guint16 model;
 	guint16 subsystem_vendor;
@@ -87,6 +89,23 @@ fu_udev_device_emit_changed(FuUdevDevice *self)
 }
 
 #ifdef HAVE_GUDEV
+static guint32
+fu_udev_device_get_sysfs_attr_as_uint32(GUdevDevice *udev_device, const gchar *name)
+{
+	const gchar *tmp;
+	guint64 tmp64 = 0;
+	g_autoptr(GError) error_local = NULL;
+
+	tmp = g_udev_device_get_sysfs_attr(udev_device, name);
+	if (tmp == NULL)
+		return 0x0;
+	if (!fu_strtoull(tmp, &tmp64, 0, G_MAXUINT32 - 1, &error_local)) {
+		g_warning("reading %s for %s was invalid: %s", name, tmp, error_local->message);
+		return 0x0;
+	}
+	return tmp64;
+}
+
 static guint16
 fu_udev_device_get_sysfs_attr_as_uint16(GUdevDevice *udev_device, const gchar *name)
 {
@@ -161,6 +180,8 @@ fu_udev_device_to_string(FuDevice *device, guint idt, GString *str)
 		fu_string_append_kx(str, idt, "SubsystemVendor", priv->subsystem_vendor);
 		fu_string_append_kx(str, idt, "SubsystemModel", priv->subsystem_model);
 	}
+	if (priv->class != 0x0)
+		fu_string_append_kx(str, idt, "Class", priv->class);
 	if (priv->revision != 0x0)
 		fu_string_append_kx(str, idt, "Revision", priv->revision);
 	if (priv->subsystem != NULL)
@@ -356,6 +377,7 @@ fu_udev_device_set_vendor_from_udev_device(FuUdevDevice *self, GUdevDevice *udev
 	priv->vendor = fu_udev_device_get_sysfs_attr_as_uint16(udev_device, "vendor");
 	priv->model = fu_udev_device_get_sysfs_attr_as_uint16(udev_device, "device");
 	priv->revision = fu_udev_device_get_sysfs_attr_as_uint8(udev_device, "revision");
+	priv->class = fu_udev_device_get_sysfs_attr_as_uint32(udev_device, "class");
 	priv->subsystem_vendor =
 	    fu_udev_device_get_sysfs_attr_as_uint16(udev_device, "subsystem_vendor");
 	priv->subsystem_model =
@@ -442,6 +464,20 @@ fu_udev_device_probe(FuDevice *device, GError **error)
 		}
 	}
 
+	/* if the device is a GPU try to fetch it from vbios_version */
+	if (g_strcmp0(priv->subsystem, "pci") == 0 &&
+	    fu_udev_device_is_pci_base_cls(FU_UDEV_DEVICE(device), FU_PCI_BASE_CLS_DISPLAY) &&
+	    fu_device_get_version(device) == NULL) {
+		const gchar *version;
+
+		version = g_udev_device_get_sysfs_attr(priv->udev_device, "vbios_version");
+		if (version != NULL) {
+			fu_device_set_version(device, version);
+			fu_device_set_version_format(device, FWUPD_VERSION_FORMAT_PLAIN);
+			fu_device_add_icon(FU_DEVICE(self), "video-display");
+		}
+	}
+
 	/* set the version if the revision has been set */
 	if (fu_device_get_version(device) == NULL &&
 	    fu_device_get_version_format(device) == FWUPD_VERSION_FORMAT_UNKNOWN) {
@@ -697,6 +733,17 @@ fu_udev_device_get_slot_depth(FuUdevDevice *self, const gchar *subsystem)
 	return 0;
 }
 
+static void
+fu_udev_device_probe_complete(FuDevice *device)
+{
+	FuUdevDevice *self = FU_UDEV_DEVICE(device);
+	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
+
+	/* this is where we would call g_clear_object(&priv->udev_device) in the future, but for
+	 * now just set the flag so we get the warning in non-supported builds */
+	priv->udev_device_cleared = TRUE;
+}
+
 static gboolean
 fu_udev_device_unbind_driver(FuDevice *device, GError **error)
 {
@@ -837,6 +884,9 @@ fu_udev_device_incorporate(FuDevice *self, FuDevice *donor)
  *
  * Gets the #GUdevDevice.
  *
+ * NOTE: If a plugin calls this after the `->probe()` and `->setup()` phases then the
+ * %FU_DEVICE_INTERNAL_FLAG_NO_PROBE_COMPLETE flag should be set on the device to avoid a warning.
+ *
  * Returns: (transfer none): a #GUdevDevice, or %NULL
  *
  * Since: 1.1.2
@@ -846,6 +896,14 @@ fu_udev_device_get_dev(FuUdevDevice *self)
 {
 	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
 	g_return_val_if_fail(FU_IS_UDEV_DEVICE(self), NULL);
+#ifdef SUPPORTED_BUILD
+	if (priv->udev_device_cleared) {
+		g_warning("soon the GUdevDevice will not be available post-probe, use "
+			  "FU_DEVICE_INTERNAL_FLAG_NO_PROBE_COMPLETE in %s plugin to opt-out %s",
+			  fu_device_get_plugin(FU_DEVICE(self)),
+			  fu_device_get_id(FU_DEVICE(self)));
+	}
+#endif
 	return priv->udev_device;
 }
 
@@ -978,6 +1036,43 @@ fu_udev_device_get_number(FuUdevDevice *self)
 	return G_MAXUINT64;
 }
 
+/**
+ * fu_udev_device_is_pci_base_cls:
+ * @self: a #FuUdevDevice
+ * @cls: #FuPciBaseCls type
+ *
+ * Determines whether the device matches a given pci base class type
+ *
+ * Since: 1.8.11
+ **/
+gboolean
+fu_udev_device_is_pci_base_cls(FuUdevDevice *self, FuPciBaseCls cls)
+{
+	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
+	g_return_val_if_fail(FU_IS_UDEV_DEVICE(self), FALSE);
+	return (priv->class >> 16) == cls;
+}
+
+/**
+ * fu_udev_device_get_cls:
+ * @self: a #FuUdevDevice
+ *
+ * Gets the PCI class for a device.
+ *
+ * The class consists of a base class and subclass.
+ *
+ * Returns: a PCI class
+ *
+ * Since: 1.8.11
+ **/
+guint32
+fu_udev_device_get_cls(FuUdevDevice *self)
+{
+	FuUdevDevicePrivate *priv = GET_PRIVATE(self);
+	g_return_val_if_fail(FU_IS_UDEV_DEVICE(self), 0x0000);
+	return priv->class;
+}
+
 /**
  * fu_udev_device_get_vendor:
  * @self: a #FuUdevDevice
@@ -1000,7 +1095,7 @@ fu_udev_device_get_vendor(FuUdevDevice *self)
  * fu_udev_device_get_model:
  * @self: a #FuUdevDevice
  *
- * Gets the device device code.
+ * Gets the device model code.
  *
  * Returns: a vendor code, or 0 if unset or invalid
  *
@@ -2250,6 +2345,7 @@ fu_udev_device_class_init(FuUdevDeviceClass *klass)
 	device_class->to_string = fu_udev_device_to_string;
 	device_class->bind_driver = fu_udev_device_bind_driver;
 	device_class->unbind_driver = fu_udev_device_unbind_driver;
+	device_class->probe_complete = fu_udev_device_probe_complete;
 
 	/**
 	 * FuUdevDevice::changed:
