@@ -86,16 +86,15 @@ fu_usb_device_finalize(GObject *object)
 	G_OBJECT_CLASS(fu_usb_device_parent_class)->finalize(object);
 }
 
-#if G_USB_CHECK_VERSION(0, 4, 1)
+#if G_USB_CHECK_VERSION(0, 4, 5)
 static void
-fu_usb_device_backend_tags_notify_cb(GObject *object, GParamSpec *pspec, FuUsbDevice *device)
+fu_usb_device_flags_notify_cb(FuDevice *device, GParamSpec *pspec, gpointer user_data)
 {
-	FuUsbDevicePrivate *priv = GET_PRIVATE(device);
-	GPtrArray *backend_tags = fu_device_get_backend_tags(FU_DEVICE(device));
-	for (guint i = 0; i < backend_tags->len; i++) {
-		const gchar *backend_tag = g_ptr_array_index(backend_tags, i);
-		g_usb_device_add_tag(priv->usb_device, backend_tag);
-	}
+	GUsbDevice *usb_device = fu_usb_device_get_dev(FU_USB_DEVICE(device));
+	if (usb_device == NULL)
+		return;
+	if (fu_device_has_flag(device, FWUPD_DEVICE_FLAG_EMULATION_TAG))
+		g_usb_device_add_tag(usb_device, FU_USB_DEVICE_EMULATION_TAG);
 }
 #endif
 
@@ -115,13 +114,18 @@ fu_usb_device_init(FuUsbDevice *device)
 				     G_USB_DEVICE_ERROR_PERMISSION_DENIED,
 				     NULL);
 #endif
+}
 
-#if G_USB_CHECK_VERSION(0, 4, 1)
+static void
+fu_usb_device_constructed(GObject *obj)
+{
+#if G_USB_CHECK_VERSION(0, 4, 5)
+	FuUsbDevice *self = FU_USB_DEVICE(obj);
 	/* copy this to the GUsbDevice */
-	g_signal_connect(FU_DEVICE(device),
-			 "notify::backend-tags",
-			 G_CALLBACK(fu_usb_device_backend_tags_notify_cb),
-			 device);
+	g_signal_connect(FU_DEVICE(self),
+			 "notify::flags",
+			 G_CALLBACK(fu_usb_device_flags_notify_cb),
+			 NULL);
 #endif
 }
 
@@ -523,10 +527,8 @@ fu_usb_device_probe(FuDevice *device, GError **error)
 	release = g_usb_device_get_release(priv->usb_device);
 	if (release != 0x0 &&
 	    fu_device_get_version_format(device) == FWUPD_VERSION_FORMAT_UNKNOWN) {
-		g_autofree gchar *version = NULL;
-		version = fu_version_from_uint16(release, FWUPD_VERSION_FORMAT_BCD);
 		fu_device_set_version_format(device, FWUPD_VERSION_FORMAT_BCD);
-		fu_device_set_version(device, version);
+		fu_device_set_version_from_uint16(device, release);
 	}
 
 	/* add GUIDs in order of priority */
@@ -687,7 +689,8 @@ fu_usb_device_set_dev(FuUsbDevice *device, GUsbDevice *usb_device)
 	g_return_if_fail(FU_IS_USB_DEVICE(device));
 
 	/* need to re-probe hardware */
-	fu_device_probe_invalidate(FU_DEVICE(device));
+	if (!fu_device_has_flag(FU_DEVICE(device), FWUPD_DEVICE_FLAG_EMULATED))
+		fu_device_probe_invalidate(FU_DEVICE(device));
 
 	/* allow replacement */
 	g_set_object(&priv->usb_device, usb_device);
@@ -697,6 +700,12 @@ fu_usb_device_set_dev(FuUsbDevice *device, GUsbDevice *usb_device)
 	}
 
 #ifdef HAVE_GUSB
+#if G_USB_CHECK_VERSION(0, 4, 5)
+	/* propagate emulated flag */
+	if (usb_device != NULL && g_usb_device_is_emulated(usb_device))
+		fu_device_add_flag(FU_DEVICE(device), FWUPD_DEVICE_FLAG_EMULATED);
+#endif
+
 	/* set device ID automatically */
 	fu_device_set_physical_id(FU_DEVICE(device), g_usb_device_get_platform_id(usb_device));
 #endif
@@ -929,6 +938,7 @@ fu_usb_device_class_init(FuUsbDeviceClass *klass)
 	object_class->finalize = fu_usb_device_finalize;
 	object_class->get_property = fu_usb_device_get_property;
 	object_class->set_property = fu_usb_device_set_property;
+	object_class->constructed = fu_usb_device_constructed;
 	device_class->open = fu_usb_device_open;
 	device_class->setup = fu_usb_device_setup;
 	device_class->ready = fu_usb_device_ready;
