@@ -24,7 +24,7 @@ fu_acpi_facp_s2i_disabled_func(void)
 		g_test_skip("Missing FACP");
 		return;
 	}
-	blob = fu_common_get_contents_bytes(fn, &error);
+	blob = fu_bytes_get_contents(fn, &error);
 	g_assert_no_error(error);
 	g_assert_nonnull(blob);
 	facp = fu_acpi_facp_new(blob, &error);
@@ -47,7 +47,7 @@ fu_acpi_facp_s2i_enabled_func(void)
 		g_test_skip("Missing FACP-S2I");
 		return;
 	}
-	blob = fu_common_get_contents_bytes(fn, &error);
+	blob = fu_bytes_get_contents(fn, &error);
 	g_assert_no_error(error);
 	g_assert_nonnull(blob);
 	facp = fu_acpi_facp_new(blob, &error);
@@ -63,7 +63,7 @@ main(int argc, char **argv)
 
 	/* only critical and error are fatal */
 	g_log_set_fatal_mask(NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
-	g_setenv("G_MESSAGES_DEBUG", "all", TRUE);
+	(void)g_setenv("G_MESSAGES_DEBUG", "all", TRUE);
 
 	/* tests go here */
 	g_test_add_func("/acpi-facp/s2i{disabled}", fu_acpi_facp_s2i_disabled_func);
