@@ -136,9 +136,9 @@ fu_ata_device_pad_string_for_id(const gchar *name)
 static gchar *
 fu_ata_device_get_guid_safe(const guint16 *buf, guint16 addr_start)
 {
-	if (!fu_common_guid_is_plausible((guint8 *)(buf + addr_start)))
+	if (!fu_common_guid_is_plausible((((guint8 *)buf) + addr_start)))
 		return NULL;
-	return fwupd_guid_to_string((const fwupd_guid_t *)(buf + addr_start),
+	return fwupd_guid_to_string((const fwupd_guid_t *)(((guint8 *)buf) + addr_start),
 				    FWUPD_GUID_FLAG_MIXED_ENDIAN);
 }
 
@@ -405,7 +405,7 @@ fu_ata_device_parse_id(FuAtaDevice *self, const guint8 *buf, gsize sz, GError **
 	if (self->oui > 0x0) {
 		g_autofree gchar *tmp = NULL;
 		tmp = g_strdup_printf("OUI\\%06x", self->oui);
-		fu_device_add_instance_id_full(device, tmp, FU_DEVICE_INSTANCE_FLAG_ONLY_QUIRKS);
+		fu_device_add_instance_id_full(device, tmp, FU_DEVICE_INSTANCE_FLAG_QUIRKS);
 		has_oui_quirk = fu_device_get_vendor(FU_DEVICE(self)) != NULL;
 	}
 	if (self->oui > 0x0) {
