@@ -77,7 +77,7 @@ fu_bcm57xx_device_probe(FuDevice *device, GError **error)
 	fn = g_build_filename(fu_udev_device_get_sysfs_path(FU_UDEV_DEVICE(device)), "net", NULL);
 	if (!g_file_test(fn, G_FILE_TEST_EXISTS)) {
 		g_debug("waiting for net devices to appear");
-		g_usleep(50 * 1000);
+		fu_device_sleep(device, 50); /* ms */
 	}
 	ifaces = fu_path_glob(fn, "en*", NULL);
 	if (ifaces == NULL || ifaces->len == 0) {
@@ -325,7 +325,7 @@ fu_bcm57xx_device_activate(FuDevice *device, FuProgress *progress, GError **erro
 
 	/* wait for the device to restart before calling reload() */
 	fu_progress_set_status(progress, FWUPD_STATUS_DEVICE_BUSY);
-	fu_progress_sleep(progress, 5000);
+	fu_device_sleep_full(device, 5000, progress); /* ms */
 	return TRUE;
 }
 
@@ -562,14 +562,9 @@ fu_bcm57xx_device_setup(FuDevice *device, GError **error)
 					  error))
 		return FALSE;
 	if (fwversion != 0x0) {
-		g_autofree gchar *fwversion_str = NULL;
-
 		/* this is only set on the OSS firmware */
-		fwversion_str = fu_version_from_uint32(GUINT32_FROM_BE(fwversion),
-						       FWUPD_VERSION_FORMAT_TRIPLET);
 		fu_device_set_version_format(device, FWUPD_VERSION_FORMAT_TRIPLET);
-		fu_device_set_version(device, fwversion_str);
-		fu_device_set_version_raw(device, fwversion);
+		fu_device_set_version_from_uint32(device, GUINT32_FROM_BE(fwversion));
 		fu_device_set_branch(device, BCM_FW_BRANCH_OSS_FIRMWARE);
 	} else {
 		guint8 bufver[16] = {0x0};
