@@ -344,6 +344,8 @@ fu_bcm57xx_recovery_device_nvram_read(FuBcm57xxRecoveryDevice *self,
 				      FuProgress *progress,
 				      GError **error)
 {
+	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_set_steps(progress, bufsz);
 	for (guint i = 0; i < bufsz; i++) {
 		BcmRegNVMCommand tmp = {0};
 		guint32 val32 = 0;
@@ -377,7 +379,7 @@ fu_bcm57xx_recovery_device_nvram_read(FuBcm57xxRecoveryDevice *self,
 			return FALSE;
 		buf[i] = GUINT32_FROM_BE(val32);
 		address += sizeof(guint32);
-		fu_progress_set_percentage_full(progress, i + 1, bufsz);
+		fu_progress_step_done(progress);
 	}
 
 	/* success */
@@ -405,6 +407,8 @@ fu_bcm57xx_recovery_device_nvram_write(FuBcm57xxRecoveryDevice *self,
 		return FALSE;
 	}
 
+	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_set_steps(progress, bufsz_dwrds);
 	for (guint i = 0; i < bufsz_dwrds; i++) {
 		BcmRegNVMCommand tmp = {0};
 		if (!fu_bcm57xx_recovery_device_nvram_clear_done(self, error))
@@ -436,7 +440,7 @@ fu_bcm57xx_recovery_device_nvram_write(FuBcm57xxRecoveryDevice *self,
 			return FALSE;
 		}
 		address += sizeof(guint32);
-		fu_progress_set_percentage_full(progress, i + 1, bufsz_dwrds);
+		fu_progress_step_done(progress);
 	}
 
 	/* success */
@@ -580,9 +584,9 @@ fu_bcm57xx_recovery_device_write_firmware(FuDevice *device,
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 1);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 95);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 5);
+	fu_progress_add_step(progress, FWUPD_STATUS_DECOMPRESSING, 1, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 95, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 5, NULL);
 
 	/* build the images into one linear blob of the correct size */
 	blob = fu_firmware_write(firmware, error);
@@ -653,10 +657,10 @@ fu_bcm57xx_recovery_device_setup(FuDevice *device, GError **error)
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 10); /* enable */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 80); /* nvram */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 10); /* veraddr */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 10); /* version */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 10, "enable");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 80, "nvram");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 10, "veraddr");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 10, "version");
 
 	locker = fu_device_locker_new_full(
 	    self,
@@ -684,14 +688,9 @@ fu_bcm57xx_recovery_device_setup(FuDevice *device, GError **error)
 		return FALSE;
 	fu_progress_step_done(progress);
 	if (fwversion != 0x0) {
-		g_autofree gchar *fwversion_str = NULL;
-
 		/* this is only set on the OSS firmware */
-		fwversion_str = fu_common_version_from_uint32(GUINT32_FROM_BE(fwversion),
-							      FWUPD_VERSION_FORMAT_TRIPLET);
 		fu_device_set_version_format(device, FWUPD_VERSION_FORMAT_TRIPLET);
-		fu_device_set_version(device, fwversion_str);
-		fu_device_set_version_raw(device, fwversion);
+		fu_device_set_version_from_uint32(device, GUINT32_FROM_BE(fwversion));
 		fu_device_set_branch(device, BCM_FW_BRANCH_OSS_FIRMWARE);
 		fu_progress_step_done(progress);
 		fu_progress_step_done(progress);
@@ -844,10 +843,10 @@ fu_bcm57xx_recovery_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94);	/* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2);	/* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2, "reload");
 }
 
 static void
@@ -876,9 +875,6 @@ fu_bcm57xx_recovery_device_init(FuBcm57xxRecoveryDevice *self)
 static gboolean
 fu_bcm57xx_recovery_device_probe(FuDevice *device, GError **error)
 {
-	/* FuUdevDevice->probe */
-	if (!FU_DEVICE_CLASS(fu_bcm57xx_recovery_device_parent_class)->probe(device, error))
-		return FALSE;
 	return fu_udev_device_set_physical_id(FU_UDEV_DEVICE(device), "pci", error);
 }
 
