@@ -110,21 +110,21 @@ fu_ccgx_dmc_firmware_parse_segment(FuFirmware *firmware,
 
 		/* read segment info  */
 		seg_rcd = g_new0(FuCcgxDmcFirmwareSegmentRecord, 1);
-		if (!fu_common_read_uint16_safe(
-			buf,
-			bufsz,
-			*seg_off + G_STRUCT_OFFSET(FwctSegmentationInfo, start_row),
-			&seg_rcd->start_row,
-			G_LITTLE_ENDIAN,
-			error))
+		if (!fu_memread_uint16_safe(buf,
+					    bufsz,
+					    *seg_off +
+						G_STRUCT_OFFSET(FwctSegmentationInfo, start_row),
+					    &seg_rcd->start_row,
+					    G_LITTLE_ENDIAN,
+					    error))
 			return FALSE;
-		if (!fu_common_read_uint16_safe(buf,
-						bufsz,
-						*seg_off +
-						    G_STRUCT_OFFSET(FwctSegmentationInfo, num_rows),
-						&seg_rcd->num_rows,
-						G_LITTLE_ENDIAN,
-						error))
+		if (!fu_memread_uint16_safe(buf,
+					    bufsz,
+					    *seg_off +
+						G_STRUCT_OFFSET(FwctSegmentationInfo, num_rows),
+					    &seg_rcd->num_rows,
+					    G_LITTLE_ENDIAN,
+					    error))
 			return FALSE;
 
 		/* calculate actual row size */
@@ -206,11 +206,11 @@ fu_ccgx_dmc_firmware_parse_image(FuFirmware *firmware,
 
 		/* read image info */
 		img_rcd = g_new0(FuCcgxDmcFirmwareRecord, 1);
-		if (!fu_common_read_uint8_safe(buf,
-					       bufsz,
-					       img_off + G_STRUCT_OFFSET(FwctImageInfo, row_size),
-					       &img_rcd->row_size,
-					       error))
+		if (!fu_memread_uint8_safe(buf,
+					   bufsz,
+					   img_off + G_STRUCT_OFFSET(FwctImageInfo, row_size),
+					   &img_rcd->row_size,
+					   error))
 			return FALSE;
 		if (img_rcd->row_size == 0) {
 			g_set_error(error,
@@ -220,20 +220,19 @@ fu_ccgx_dmc_firmware_parse_image(FuFirmware *firmware,
 				    img_rcd->row_size);
 			return FALSE;
 		}
-		if (!fu_common_read_uint32_safe(buf,
-						bufsz,
-						img_off +
-						    G_STRUCT_OFFSET(FwctImageInfo, img_offset),
-						&img_rcd->img_offset,
-						G_LITTLE_ENDIAN,
-						error))
+		if (!fu_memread_uint32_safe(buf,
+					    bufsz,
+					    img_off + G_STRUCT_OFFSET(FwctImageInfo, img_offset),
+					    &img_rcd->img_offset,
+					    G_LITTLE_ENDIAN,
+					    error))
 			return FALSE;
-		if (!fu_common_read_uint8_safe(buf,
-					       bufsz,
-					       img_off +
-						   G_STRUCT_OFFSET(FwctImageInfo, num_img_segments),
-					       &img_rcd->num_img_segments,
-					       error))
+		if (!fu_memread_uint8_safe(buf,
+					   bufsz,
+					   img_off +
+					       G_STRUCT_OFFSET(FwctImageInfo, num_img_segments),
+					   &img_rcd->num_img_segments,
+					   error))
 			return FALSE;
 		if (img_rcd->num_img_segments == 0) {
 			g_set_error(error,
@@ -273,11 +272,38 @@ fu_ccgx_dmc_firmware_parse_image(FuFirmware *firmware,
 	return TRUE;
 }
 
+static gboolean
+fu_ccgx_dmc_firmware_check_magic(FuFirmware *firmware, GBytes *fw, gsize offset, GError **error)
+{
+	guint32 magic = 0;
+
+	if (!fu_memread_uint32_safe(g_bytes_get_data(fw, NULL),
+				    g_bytes_get_size(fw),
+				    offset,
+				    &magic,
+				    G_LITTLE_ENDIAN,
+				    error)) {
+		g_prefix_error(error, "failed to read magic: ");
+		return FALSE;
+	}
+	if (magic != DMC_FWCT_SIGN) {
+		g_set_error(error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_INVALID_FILE,
+			    "invalid signature, expected 0x%04X got 0x%04X",
+			    (guint32)DMC_FWCT_SIGN,
+			    (guint32)magic);
+		return FALSE;
+	}
+
+	/* success */
+	return TRUE;
+}
+
 static gboolean
 fu_ccgx_dmc_firmware_parse(FuFirmware *firmware,
 			   GBytes *fw,
-			   guint64 addr_start,
-			   guint64 addr_end,
+			   gsize offset,
 			   FwupdInstallFlags flags,
 			   GError **error)
 {
@@ -286,31 +312,17 @@ fu_ccgx_dmc_firmware_parse(FuFirmware *firmware,
 	guint16 hdr_size = 0;
 	guint16 mdbufsz = 0;
 	guint32 hdr_composite_version = 0;
-	guint32 hdr_signature = 0;
 	guint8 hdr_image_count = 0;
 	const guint8 *buf = g_bytes_get_data(fw, &bufsz);
 	g_autoptr(FuFirmware) img = fu_firmware_new_from_bytes(fw);
 
-	/* check for 'F' 'W' 'C' 'T' in signature */
-	if (!fu_common_read_uint32_safe(buf, bufsz, 0x0, &hdr_signature, G_LITTLE_ENDIAN, error))
-		return FALSE;
-	if (hdr_signature != DMC_FWCT_SIGN) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_NOT_SUPPORTED,
-			    "invalid dmc signature, expected 0x%04X got 0x%04X",
-			    (guint32)DMC_FWCT_SIGN,
-			    (guint32)hdr_signature);
-		return FALSE;
-	}
-
 	/* check fwct size */
-	if (!fu_common_read_uint16_safe(buf,
-					bufsz,
-					G_STRUCT_OFFSET(FwctInfo, size),
-					&hdr_size,
-					G_LITTLE_ENDIAN,
-					error))
+	if (!fu_memread_uint16_safe(buf,
+				    bufsz,
+				    offset + G_STRUCT_OFFSET(FwctInfo, size),
+				    &hdr_size,
+				    G_LITTLE_ENDIAN,
+				    error))
 		return FALSE;
 	if (hdr_size > DMC_FWCT_MAX_SIZE || hdr_size == 0) {
 		g_set_error(error,
@@ -323,34 +335,38 @@ fu_ccgx_dmc_firmware_parse(FuFirmware *firmware,
 	}
 
 	/* set version */
-	if (!fu_common_read_uint32_safe(buf,
-					bufsz,
-					G_STRUCT_OFFSET(FwctInfo, composite_version),
-					&hdr_composite_version,
-					G_LITTLE_ENDIAN,
-					error))
+	if (!fu_memread_uint32_safe(buf,
+				    bufsz,
+				    offset + G_STRUCT_OFFSET(FwctInfo, composite_version),
+				    &hdr_composite_version,
+				    G_LITTLE_ENDIAN,
+				    error))
 		return FALSE;
 	if (hdr_composite_version != 0) {
 		g_autofree gchar *ver = NULL;
-		ver =
-		    fu_common_version_from_uint32(hdr_composite_version, FWUPD_VERSION_FORMAT_QUAD);
+		ver = fu_version_from_uint32(hdr_composite_version, FWUPD_VERSION_FORMAT_QUAD);
 		fu_firmware_set_version(firmware, ver);
 		fu_firmware_set_version_raw(firmware, hdr_composite_version);
 	}
 
 	/* read fwct data */
-	self->fwct_blob = fu_common_bytes_new_offset(fw, 0x0, hdr_size, error);
+	self->fwct_blob = fu_bytes_new_offset(fw, offset, hdr_size, error);
 	if (self->fwct_blob == NULL)
 		return FALSE;
 
 	/* create custom meta binary */
-	if (!fu_common_read_uint16_safe(buf, bufsz, hdr_size, &mdbufsz, G_LITTLE_ENDIAN, error)) {
+	if (!fu_memread_uint16_safe(buf,
+				    bufsz,
+				    offset + hdr_size,
+				    &mdbufsz,
+				    G_LITTLE_ENDIAN,
+				    error)) {
 		g_prefix_error(error, "failed to read metadata size: ");
 		return FALSE;
 	}
 	if (mdbufsz > 0) {
 		self->custom_meta_blob =
-		    fu_common_bytes_new_offset(fw, hdr_size + 2, mdbufsz, error);
+		    fu_bytes_new_offset(fw, offset + hdr_size + 2, mdbufsz, error);
 		if (self->custom_meta_blob == NULL)
 			return FALSE;
 	}
@@ -360,11 +376,11 @@ fu_ccgx_dmc_firmware_parse(FuFirmware *firmware,
 	self->fw_data_size = bufsz - self->row_data_offset_start;
 
 	/* parse image */
-	if (!fu_common_read_uint8_safe(buf,
-				       bufsz,
-				       G_STRUCT_OFFSET(FwctInfo, image_count),
-				       &hdr_image_count,
-				       error))
+	if (!fu_memread_uint8_safe(buf,
+				   bufsz,
+				   offset + G_STRUCT_OFFSET(FwctInfo, image_count),
+				   &hdr_image_count,
+				   error))
 		return FALSE;
 	if (!fu_ccgx_dmc_firmware_parse_image(firmware, hdr_image_count, buf, bufsz, flags, error))
 		return FALSE;
@@ -462,7 +478,7 @@ fu_ccgx_dmc_firmware_write(FuFirmware *firmware, GError **error)
 		if (img_bytes == NULL)
 			return NULL;
 		chunks = fu_chunk_array_new_from_bytes(img_bytes, 0x0, 0x0, 64);
-		img_padded = fu_common_bytes_pad(img_bytes, MAX(chunks->len, 1) * 64);
+		img_padded = fu_bytes_pad(img_bytes, MAX(chunks->len, 1) * 64);
 		fu_byte_array_append_bytes(buf, img_padded);
 		g_checksum_update(csum,
 				  (const guchar *)g_bytes_get_data(img_padded, NULL),
@@ -513,6 +529,7 @@ fu_ccgx_dmc_firmware_class_init(FuCcgxDmcFirmwareClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS(klass);
 	FuFirmwareClass *klass_firmware = FU_FIRMWARE_CLASS(klass);
 	object_class->finalize = fu_ccgx_dmc_firmware_finalize;
+	klass_firmware->check_magic = fu_ccgx_dmc_firmware_check_magic;
 	klass_firmware->parse = fu_ccgx_dmc_firmware_parse;
 	klass_firmware->write = fu_ccgx_dmc_firmware_write;
 	klass_firmware->export = fu_ccgx_dmc_firmware_export;
