@@ -22,8 +22,8 @@ static void
 fu_cfu_module_to_string(FuDevice *device, guint idt, GString *str)
 {
 	FuCfuModule *self = FU_CFU_MODULE(device);
-	fu_common_string_append_kx(str, idt, "ComponentId", self->component_id);
-	fu_common_string_append_kx(str, idt, "Bank", self->bank);
+	fu_string_append_kx(str, idt, "ComponentId", self->component_id);
+	fu_string_append_kx(str, idt, "Bank", self->bank);
 }
 
 guint8
@@ -41,62 +41,56 @@ fu_cfu_module_get_bank(FuCfuModule *self)
 gboolean
 fu_cfu_module_setup(FuCfuModule *self, const guint8 *buf, gsize bufsz, gsize offset, GError **error)
 {
-	FuDevice *parent = fu_device_get_proxy(FU_DEVICE(self));
+	FuDevice *device = FU_DEVICE(self);
+	FuDevice *parent = fu_device_get_proxy(device);
 	guint32 version_raw = 0;
 	guint8 tmp = 0;
-	g_autofree gchar *instance_id0 = NULL;
-	g_autofree gchar *instance_id1 = NULL;
-	g_autofree gchar *instance_id2 = NULL;
 	g_autofree gchar *logical_id = NULL;
-	g_autofree gchar *version = NULL;
 
 	/* component ID */
-	if (!fu_common_read_uint8_safe(buf, bufsz, offset + 0x5, &self->component_id, error))
+	if (!fu_memread_uint8_safe(buf, bufsz, offset + 0x5, &self->component_id, error))
 		return FALSE;
 
 	/* these GUIDs may cause the name or version-format to be overwritten */
-	instance_id0 = g_strdup_printf("HIDRAW\\VEN_%04X&DEV_%04X",
-				       fu_udev_device_get_vendor(FU_UDEV_DEVICE(parent)),
-				       fu_udev_device_get_model(FU_UDEV_DEVICE(parent)));
-	fu_device_add_instance_id(FU_DEVICE(self), instance_id0);
-	instance_id1 = g_strdup_printf("HIDRAW\\VEN_%04X&DEV_%04X&CID_%02X",
-				       fu_udev_device_get_vendor(FU_UDEV_DEVICE(parent)),
-				       fu_udev_device_get_model(FU_UDEV_DEVICE(parent)),
-				       self->component_id);
-	fu_device_add_instance_id(FU_DEVICE(self), instance_id1);
+	fu_device_add_instance_u8(device, "CID", self->component_id);
+	if (!fu_device_build_instance_id(device, error, "HIDRAW", "VEN", "DEV", NULL))
+		return FALSE;
+	if (!fu_device_build_instance_id(device, error, "HIDRAW", "VEN", "DEV", "CID", NULL))
+		return FALSE;
 
 	/* bank */
-	if (!fu_common_read_uint8_safe(buf, bufsz, offset + 0x4, &tmp, error))
+	if (!fu_memread_uint8_safe(buf, bufsz, offset + 0x4, &tmp, error))
 		return FALSE;
 	self->bank = tmp & 0b11;
-	instance_id2 = g_strdup_printf("HIDRAW\\VEN_%04X&DEV_%04X&CID_%02X&BANK_%01X",
-				       fu_udev_device_get_vendor(FU_UDEV_DEVICE(parent)),
-				       fu_udev_device_get_model(FU_UDEV_DEVICE(parent)),
-				       self->component_id,
-				       self->bank);
-	fu_device_add_instance_id(FU_DEVICE(self), instance_id2);
+	fu_device_add_instance_u4(device, "BANK", self->bank);
+	if (!fu_device_build_instance_id(device,
+					 error,
+					 "HIDRAW",
+					 "VEN",
+					 "DEV",
+					 "CID",
+					 "BANK",
+					 NULL))
+		return FALSE;
 
 	/* set name, if not already set using a quirk */
-	if (fu_device_get_name(FU_DEVICE(self)) == NULL) {
+	if (fu_device_get_name(device) == NULL) {
 		g_autofree gchar *name = NULL;
 		name = g_strdup_printf("%s (0x%02X:0x%02x)",
 				       fu_device_get_name(parent),
 				       self->component_id,
 				       self->bank);
-		fu_device_set_name(FU_DEVICE(self), name);
+		fu_device_set_name(device, name);
 	}
 
 	/* version */
-	if (!fu_common_read_uint32_safe(buf, bufsz, offset, &version_raw, G_LITTLE_ENDIAN, error))
+	if (!fu_memread_uint32_safe(buf, bufsz, offset, &version_raw, G_LITTLE_ENDIAN, error))
 		return FALSE;
-	fu_device_set_version_raw(FU_DEVICE(self), version_raw);
-	version = fu_common_version_from_uint32(version_raw,
-						fu_device_get_version_format(FU_DEVICE(self)));
-	fu_device_set_version(FU_DEVICE(self), version);
+	fu_device_set_version_from_uint32(device, version_raw);
 
 	/* logical ID */
 	logical_id = g_strdup_printf("CID:0x%02x,BANK:0x%02x", self->component_id, self->bank);
-	fu_device_set_logical_id(FU_DEVICE(self), logical_id);
+	fu_device_set_logical_id(device, logical_id);
 
 	/* success */
 	return TRUE;
@@ -120,7 +114,7 @@ fu_cfu_module_prepare_firmware(FuDevice *device,
 	fu_firmware_add_image(firmware, offer);
 
 	/* payload */
-	fw_offset = fu_common_bytes_new_offset(fw, 0x10, g_bytes_get_size(fw) - 0x10, error);
+	fw_offset = fu_bytes_new_offset(fw, 0x10, g_bytes_get_size(fw) - 0x10, error);
 	if (fw_offset == NULL)
 		return NULL;
 	if (!fu_firmware_parse(payload, fw_offset, flags, error))
@@ -164,10 +158,10 @@ fu_cfu_module_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 96);	/* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2);	/* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 96, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2, "reload");
 }
 
 static void
