@@ -348,10 +348,9 @@ fu_cros_ec_usb_device_start_request(FuDevice *device, gpointer user_data, GError
 {
 	FuCrosEcUsbDevice *self = FU_CROS_EC_USB_DEVICE(device);
 	guint8 *start_resp = (guint8 *)user_data;
-	struct update_frame_header ufh;
+	struct update_frame_header ufh = {0x0};
 	gsize rxed_size = 0;
 
-	memset(&ufh, 0, sizeof(ufh));
 	ufh.block_size = GUINT32_TO_BE(sizeof(ufh));
 	if (!fu_cros_ec_usb_device_do_xfer(self,
 					   (const guint8 *)&ufh,
@@ -382,7 +381,7 @@ fu_cros_ec_usb_device_setup(FuDevice *device, GError **error)
 {
 	FuCrosEcUsbDevice *self = FU_CROS_EC_USB_DEVICE(device);
 	guint32 error_code;
-	START_RESP start_resp;
+	START_RESP start_resp = {0x0};
 	g_auto(GStrv) config_split = NULL;
 
 	/* FuUsbDevice->setup */
@@ -621,7 +620,7 @@ fu_cros_ec_usb_device_transfer_section(FuDevice *device,
 	while (data_len != 0 && (data_ptr[data_len - 1] == 0xff))
 		data_len--;
 	g_debug("trimmed %" G_GSIZE_FORMAT " trailing bytes", section->size - data_len);
-	g_debug("sending 0x%zx bytes to %#x", data_len, section->offset);
+	g_debug("sending 0x%x bytes to 0x%x", (guint)data_len, section->offset);
 
 	/* send in chunks of PDU size */
 	blocks = fu_chunk_array_new(data_ptr,
@@ -703,9 +702,9 @@ fu_cros_ec_usb_device_send_subcommand(FuDevice *device,
 static gboolean
 fu_cros_ec_usb_device_reset_to_ro(FuDevice *device, GError **error)
 {
-	guint8 response;
+	guint8 response = 0x0;
 	guint16 subcommand = UPDATE_EXTRA_CMD_IMMEDIATE_RESET;
-	guint8 command_body[2]; /* Max command body size. */
+	guint8 command_body[2] = {0x0}; /* max command body size */
 	gsize command_body_size = 0;
 	gsize response_size = 1;
 	g_autoptr(GError) error_local = NULL;
@@ -730,9 +729,9 @@ fu_cros_ec_usb_device_reset_to_ro(FuDevice *device, GError **error)
 static gboolean
 fu_cros_ec_usb_device_jump_to_rw(FuDevice *device)
 {
-	guint8 response;
+	guint8 response = 0x0;
 	guint16 subcommand = UPDATE_EXTRA_CMD_JUMP_TO_RW;
-	guint8 command_body[2]; /* Max command body size. */
+	guint8 command_body[2] = {0x0}; /* max command body size */
 	gsize command_body_size = 0;
 	gsize response_size = 1;
 
@@ -768,9 +767,9 @@ static gboolean
 fu_cros_ec_usb_device_stay_in_ro(FuDevice *device, GError **error)
 {
 	gsize response_size = 1;
-	guint8 response;
+	guint8 response = 0x0;
 	guint16 subcommand = UPDATE_EXTRA_CMD_STAY_IN_RO;
-	guint8 command_body[2]; /* Max command body size. */
+	guint8 command_body[2] = {0x0}; /* max command body size */
 	gsize command_body_size = 0;
 
 	if (!fu_cros_ec_usb_device_send_subcommand(device,
@@ -801,7 +800,7 @@ fu_cros_ec_usb_device_write_firmware(FuDevice *device,
 	fu_device_remove_private_flag(device, FU_CROS_EC_USB_DEVICE_FLAG_SPECIAL);
 
 	if (fu_device_has_private_flag(device, FU_CROS_EC_USB_DEVICE_FLAG_REBOOTING_TO_RO)) {
-		START_RESP start_resp;
+		START_RESP start_resp = {0x0};
 
 		fu_device_remove_private_flag(device, FU_CROS_EC_USB_DEVICE_FLAG_REBOOTING_TO_RO);
 		if (!fu_cros_ec_usb_device_stay_in_ro(device, error)) {
@@ -976,7 +975,9 @@ fu_cros_ec_usb_device_detach(FuDevice *device, FuProgress *progress, GError **er
 		g_debug("skipping immediate reboot in case of already in bootloader");
 		/* in RO so skip reboot */
 		return TRUE;
-	} else if (self->targ.common.flash_protection != 0x0) {
+	}
+
+	if (self->targ.common.flash_protection != 0x0) {
 		/* in RW, and RO region is write protected, so jump to RO */
 		fu_device_add_private_flag(device, FU_CROS_EC_USB_DEVICE_FLAG_RO_WRITTEN);
 		fu_device_set_remove_delay(device, CROS_EC_REMOVE_DELAY_RE_ENUMERATE);
@@ -1035,11 +1036,10 @@ static void
 fu_cros_ec_usb_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "detach");
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94, "write");
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "attach");
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2, "reload");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 1, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 76, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 1, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 22, "reload");
 }
 
 static void
