@@ -32,4 +32,4 @@ G_DECLARE_FINAL_TYPE(FuDellDockHub, fu_dell_dock_hub, FU, DELL_DOCK_HUB, FuHidDe
 FuDellDockHub *
 fu_dell_dock_hub_new(FuUsbDevice *device);
 void
-fu_dell_dock_hub_add_instance(FuDevice *device, guint8 ec_type);
+fu_dell_dock_hub_add_instance(FuDevice *device, guint8 dock_type);
