@@ -350,7 +350,8 @@ fu_dell_dock_is_valid_dock(FuDevice *device, GError **error)
 	if (self->base_type == DOCK_BASE_TYPE_SALOMON) {
 		fu_device_add_instance_id(device, DELL_DOCK_EC_INSTANCE_ID);
 		return TRUE;
-	} else if (self->base_type == DOCK_BASE_TYPE_ATOMIC) {
+	}
+	if (self->base_type == DOCK_BASE_TYPE_ATOMIC) {
 		fu_device_add_instance_id(device, DELL_DOCK_ATOMIC_EC_INSTANCE_ID);
 		return TRUE;
 	}
@@ -575,7 +576,7 @@ fu_dell_dock_ec_get_dock_data(FuDevice *device, GError **error)
 	if (!fu_dell_dock_get_ec_status(device, &status, error))
 		return FALSE;
 
-	/* make sure this hardware spin matches our expecations */
+	/* make sure this hardware spin matches our expectations */
 	if (self->data->board_id >= self->board_min) {
 		if (status != FW_UPDATE_IN_PROGRESS) {
 			fu_dell_dock_ec_set_board(device);
@@ -932,7 +933,7 @@ fu_dell_dock_ec_setup(FuDevice *device, GError **error)
 	if (!fu_dell_dock_ec_query(device, &error_local)) {
 		if (g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_SIGNATURE_INVALID)) {
 			g_warning("%s", error_local->message);
-			g_usleep(2 * G_USEC_PER_SEC);
+			fu_device_sleep(device, 2000); /* ms */
 			if (!fu_dell_dock_ec_query(device, error))
 				return FALSE;
 		} else {
