@@ -32,7 +32,7 @@ fu_dell_dock_ec_needs_tbt(FuDevice *device);
 gboolean
 fu_dell_dock_ec_tbt_passive(FuDevice *device);
 gboolean
-fu_dell_dock_ec_modify_lock(FuDevice *self, guint8 target, gboolean unlocked, GError **error);
+fu_dell_dock_ec_modify_lock(FuDevice *device, guint8 target, gboolean unlocked, GError **error);
 
 gboolean
 fu_dell_dock_ec_reboot_dock(FuDevice *device, GError **error);
