@@ -326,7 +326,7 @@ fu_dell_dock_trigger_rc_command(FuDevice *device, GError **error)
 			tmp = result[3];
 			break;
 		}
-		g_usleep(2000);
+		fu_device_sleep(FU_DEVICE(self), 2); /* ms */
 	}
 	switch (tmp) {
 	/* need to enable remote control */
@@ -406,7 +406,7 @@ fu_dell_dock_mst_check_type(FuDevice *device)
 		tmp = g_ptr_array_index(instance_ids, i);
 		if (g_strcmp0(tmp, DELL_DOCK_VMM6210_INSTANCE_ID) == 0)
 			return Cayenne_mst;
-		else if (g_strcmp0(tmp, DELL_DOCK_VM5331_INSTANCE_ID) == 0)
+		if (g_strcmp0(tmp, DELL_DOCK_VM5331_INSTANCE_ID) == 0)
 			return Panamera_mst;
 	}
 	return Unknown;
@@ -611,7 +611,7 @@ fu_dell_dock_mst_erase_panamera_bank(FuDevice *device, MSTBank bank, GError **er
 		}
 	}
 	g_debug("MST: Waiting for flash clear to settle");
-	g_usleep(5000000);
+	fu_device_sleep(device, 5000); /* ms */
 
 	return TRUE;
 }
@@ -634,7 +634,7 @@ fu_dell_dock_mst_erase_cayenne(FuDevice *device, GError **error)
 		}
 	}
 	g_debug("MST: Waiting for flash clear to settle");
-	g_usleep(5000000);
+	fu_device_sleep(device, 5000);
 
 	return TRUE;
 }
@@ -697,7 +697,7 @@ fu_dell_dock_mst_stop_esm(FuDevice *device, GError **error)
 		return FALSE;
 
 	/* waiting for ESM exit */
-	g_usleep(200);
+	fu_device_sleep(device, 1);
 
 	/* disable QUAD mode */
 	if (!fu_dell_dock_mst_rc_command(device,
@@ -1121,7 +1121,8 @@ fu_dell_dock_mst_set_quirk_kv(FuDevice *device,
 			return FALSE;
 		self->blob_build_offset = tmp;
 		return TRUE;
-	} else if (g_strcmp0(key, "DellDockInstallDurationI2C") == 0) {
+	}
+	if (g_strcmp0(key, "DellDockInstallDurationI2C") == 0) {
 		if (!fu_strtoull(value, &tmp, 0, 60 * 60 * 24, error))
 			return FALSE;
 		fu_device_set_install_duration(device, tmp);
