@@ -105,7 +105,7 @@ fu_dell_dock_tbt_write_fw(FuDevice *device,
 	g_debug("waking Thunderbolt controller");
 	if (!fu_dell_dock_hid_tbt_wake(fu_device_get_proxy(device), &tbt_base_settings, error))
 		return FALSE;
-	g_usleep(2000000);
+	fu_device_sleep(device, 2000);
 
 	fu_progress_set_status(progress, FWUPD_STATUS_DEVICE_WRITE);
 	for (guint i = 0; i < image_size; i += HIDI2C_MAX_WRITE, buffer += HIDI2C_MAX_WRITE) {
@@ -156,25 +156,30 @@ fu_dell_dock_tbt_set_quirk_kv(FuDevice *device,
 			return FALSE;
 		self->unlock_target = tmp;
 		return TRUE;
-	} else if (g_strcmp0(key, "DellDockInstallDurationI2C") == 0) {
+	}
+	if (g_strcmp0(key, "DellDockInstallDurationI2C") == 0) {
 		if (!fu_strtoull(value, &tmp, 0, 60 * 60 * 24, error))
 			return FALSE;
 		fu_device_set_install_duration(device, tmp);
 		return TRUE;
-	} else if (g_strcmp0(key, "DellDockHubVersionLowest") == 0) {
+	}
+	if (g_strcmp0(key, "DellDockHubVersionLowest") == 0) {
 		self->hub_minimum_version = g_strdup(value);
 		return TRUE;
-	} else if (g_strcmp0(key, "DellDockBlobMajorOffset") == 0) {
+	}
+	if (g_strcmp0(key, "DellDockBlobMajorOffset") == 0) {
 		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT32, error))
 			return FALSE;
 		self->blob_major_offset = tmp;
 		return TRUE;
-	} else if (g_strcmp0(key, "DellDockBlobMinorOffset") == 0) {
+	}
+	if (g_strcmp0(key, "DellDockBlobMinorOffset") == 0) {
 		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT32, error))
 			return FALSE;
 		self->blob_minor_offset = tmp;
 		return TRUE;
 	}
+
 	/* failed */
 	g_set_error_literal(error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "quirk key not supported");
 	return FALSE;
@@ -201,7 +206,7 @@ fu_dell_dock_tbt_setup(FuDevice *device, GError **error)
 	    fu_version_compare(version, MIN_NVM, FWUPD_VERSION_FORMAT_PAIR) < 0) {
 		fu_device_set_update_error(
 		    device,
-		    "Updates over I2C are disabled due to insuffient NVM version");
+		    "Updates over I2C are disabled due to insufficient NVM version");
 		return TRUE;
 	}
 	/* minimum Hub2 version that supports this feature */
