@@ -126,7 +126,7 @@ fu_dell_dock_status_set_quirk_kv(FuDevice *device,
 	FuDellDockStatus *self = FU_DELL_DOCK_STATUS(device);
 	if (g_strcmp0(key, "DellDockBlobVersionOffset") == 0) {
 		guint64 tmp = 0;
-		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT32, error))
+		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT32, error))
 			return FALSE;
 		self->blob_version_offset = tmp;
 		return TRUE;
@@ -147,10 +147,10 @@ static void
 fu_dell_dock_status_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 13); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 72);	 /* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 9);	 /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 7);	 /* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 13, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 72, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 9, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 7, "reload");
 }
 
 static void
@@ -158,6 +158,7 @@ fu_dell_dock_status_init(FuDellDockStatus *self)
 {
 	fu_device_add_protocol(FU_DEVICE(self), "com.dell.dock");
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
+	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
 }
 
 static void
@@ -175,9 +176,9 @@ fu_dell_dock_status_class_init(FuDellDockStatusClass *klass)
 }
 
 FuDellDockStatus *
-fu_dell_dock_status_new(void)
+fu_dell_dock_status_new(FuContext *ctx)
 {
 	FuDellDockStatus *self = NULL;
-	self = g_object_new(FU_TYPE_DELL_DOCK_STATUS, NULL);
+	self = g_object_new(FU_TYPE_DELL_DOCK_STATUS, "context", ctx, NULL);
 	return self;
 }
