@@ -147,9 +147,9 @@ static gboolean
 fu_dell_supported(FuPlugin *plugin, GError **error)
 {
 	FuContext *ctx = fu_plugin_get_context(plugin);
+	FuSmbiosChassisKind chassis_kind = fu_context_get_chassis_kind(ctx);
 	g_autoptr(GBytes) de_table = NULL;
 	g_autoptr(GBytes) da_table = NULL;
-	g_autoptr(GBytes) enclosure = NULL;
 	guint8 value = 0;
 	struct da_structure da_values = {0x0};
 
@@ -194,19 +194,8 @@ fu_dell_supported(FuPlugin *plugin, GError **error)
 	}
 
 	/* only run on intended Dell hw types */
-	enclosure = fu_context_get_smbios_data(ctx, FU_SMBIOS_STRUCTURE_TYPE_CHASSIS, error);
-	if (enclosure == NULL)
-		return FALSE;
-	if (!fu_memread_uint8_safe(g_bytes_get_data(enclosure, NULL),
-				   g_bytes_get_size(enclosure),
-				   0x0,
-				   &value,
-				   error)) {
-		g_prefix_error(error, "invalid enclosure data: ");
-		return FALSE;
-	}
 	for (guint i = 0; i < G_N_ELEMENTS(enclosure_allowlist); i++) {
-		if (enclosure_allowlist[i] == value)
+		if (enclosure_allowlist[i] == chassis_kind)
 			return TRUE;
 	}
 
@@ -324,7 +313,10 @@ fu_plugin_dock_node(FuPlugin *plugin,
 }
 
 gboolean
-fu_dell_plugin_backend_device_added(FuPlugin *plugin, FuDevice *device, GError **error)
+fu_dell_plugin_backend_device_added(FuPlugin *plugin,
+				    FuDevice *device,
+				    FuProgress *progress,
+				    GError **error)
 {
 	FuDellPlugin *self = FU_DELL_PLUGIN(plugin);
 	FwupdVersionFormat version_format = FWUPD_VERSION_FORMAT_DELL_BIOS;
@@ -438,9 +430,10 @@ fu_dell_plugin_backend_device_added(FuPlugin *plugin, FuDevice *device, GError *
 			dock_info->flash_pkg_version = 0;
 			continue;
 		}
+
 		/* if invalid version, don't mark device for updates */
-		else if (dock_info->components[i].fw_version == 0 ||
-			 dock_info->components[i].fw_version == 0xffffffff) {
+		if (dock_info->components[i].fw_version == 0 ||
+		    dock_info->components[i].fw_version == 0xffffffff) {
 			old_ec = TRUE;
 			continue;
 		}
@@ -921,7 +914,7 @@ fu_dell_plugin_startup(FuPlugin *plugin, FuProgress *progress, GError **error)
 
 	if (self->smi_obj->fake_smbios) {
 		g_debug("Called with fake SMBIOS implementation. "
-			"We're ignoring test for SBMIOS table and ESRT. "
+			"We're ignoring test for SMBIOS table and ESRT. "
 			"Individual calls will need to be properly staged.");
 		return TRUE;
 	}
