@@ -26,7 +26,7 @@
  *
  * Forces a specific DFU version for the hardware device. This is required
  * if the device does not set, or sets incorrectly, items in the DFU functional
- * descriptor.
+ * descriptor. If zero, then DFU functionality is disabled.
  *
  * Since: 1.0.1
  */
@@ -38,8 +38,6 @@
 
 #include <fwupdplugin.h>
 
-#include <string.h>
-
 #include "fu-dfu-common.h"
 #include "fu-dfu-device.h"
 #include "fu-dfu-target-avr.h"
@@ -86,7 +84,8 @@ fu_dfu_device_to_string(FuDevice *device, guint idt, GString *str)
 	if (priv->chip_id != NULL)
 		fu_string_append(str, idt, "ChipId", priv->chip_id);
 	fu_string_append_kx(str, idt, "Version", priv->version);
-	fu_string_append_kx(str, idt, "ForceVersion", priv->force_version);
+	if (priv->force_version != G_MAXUINT16)
+		fu_string_append_kx(str, idt, "ForceVersion", priv->force_version);
 	if (priv->force_transfer_size != 0x0) {
 		fu_string_append_kx(str, idt, "ForceTransferSize", priv->force_transfer_size);
 	}
@@ -258,6 +257,15 @@ fu_dfu_device_add_targets(FuDfuDevice *self, GError **error)
 	GUsbDevice *usb_device = fu_usb_device_get_dev(FU_USB_DEVICE(self));
 	g_autoptr(GPtrArray) ifaces = NULL;
 
+	/* disabled using quirk */
+	if (priv->force_version == 0x0) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "ignoring device as DFU version set to 0x0");
+		return FALSE;
+	}
+
 	/* add all DFU-capable targets */
 	ifaces = g_usb_device_get_interfaces(usb_device, error);
 	if (ifaces == NULL)
@@ -281,7 +289,7 @@ fu_dfu_device_add_targets(FuDfuDevice *self, GError **error)
 		}
 		/* parse any interface data */
 		iface_data = g_usb_interface_get_extra(iface);
-		if (g_bytes_get_size(iface_data) > 0) {
+		if (iface_data != NULL && g_bytes_get_size(iface_data) > 0) {
 			if (!fu_dfu_device_parse_iface_data(self, iface_data, &error_local)) {
 				g_warning("failed to parse interface data for %04x:%04x: %s",
 					  g_usb_device_get_vid(usb_device),
@@ -296,7 +304,7 @@ fu_dfu_device_add_targets(FuDfuDevice *self, GError **error)
 		}
 
 		/* fix up the version */
-		if (priv->force_version > 0)
+		if (priv->force_version != G_MAXUINT16)
 			priv->version = priv->force_version;
 		if (priv->version == FU_DFU_FIRMARE_VERSION_DFU_1_0 ||
 		    priv->version == FU_DFU_FIRMARE_VERSION_DFU_1_1) {
@@ -671,7 +679,7 @@ fu_dfu_device_ensure_interface(FuDfuDevice *self, GError **error)
  * @self: a #FuDfuDevice
  * @error: (nullable): optional return location for an error
  *
- * Refreshes the cached properties on the DFU device. If there are any transers
+ * Refreshes the cached properties on the DFU device. If there are any transfers
  * in progress they are cancelled, and if there are any pending errors they are
  * cancelled.
  *
@@ -717,7 +725,7 @@ fu_dfu_device_refresh(FuDfuDevice *self, GError **error)
 	FuDfuDevicePrivate *priv = GET_PRIVATE(self);
 	GUsbDevice *usb_device = fu_usb_device_get_dev(FU_USB_DEVICE(self));
 	gsize actual_length = 0;
-	guint8 buf[6];
+	guint8 buf[6] = {0x0};
 	g_autoptr(GError) error_local = NULL;
 
 	g_return_val_if_fail(FU_IS_DFU_DEVICE(self), FALSE);
@@ -886,7 +894,7 @@ fu_dfu_device_detach(FuDevice *device, FuProgress *progress, GError **error)
 	}
 
 	/* success */
-	priv->force_version = 0x0;
+	priv->force_version = G_MAXUINT16;
 	fu_device_add_flag(device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
 	return TRUE;
 }
@@ -1166,10 +1174,8 @@ fu_dfu_device_probe(FuDevice *device, GError **error)
 
 	/* hardware from Jabra literally reboots if you try to retry a failed
 	 * write -- there's no way to avoid blocking the daemon like this... */
-	if (fu_device_has_private_flag(FU_DEVICE(self), FU_DFU_DEVICE_FLAG_ATTACH_EXTRA_RESET)) {
-		g_autoptr(FuProgress) progress = fu_progress_new(G_STRLOC);
-		fu_progress_sleep(progress, 10000);
-	}
+	if (fu_device_has_private_flag(FU_DEVICE(self), FU_DFU_DEVICE_FLAG_ATTACH_EXTRA_RESET))
+		fu_device_sleep(device, 10000);
 
 	/* success */
 	return TRUE;
@@ -1597,19 +1603,10 @@ fu_dfu_device_set_quirk_kv(FuDevice *device, const gchar *key, const gchar *valu
 	guint64 tmp = 0;
 
 	if (g_strcmp0(key, FU_QUIRKS_DFU_FORCE_VERSION) == 0) {
-		if (value != NULL) {
-			gsize valuesz = strlen(value);
-			return fu_firmware_strparse_uint16_safe(value,
-								valuesz,
-								0,
-								&priv->force_version,
-								error);
-		}
-		g_set_error_literal(error,
-				    G_IO_ERROR,
-				    G_IO_ERROR_INVALID_DATA,
-				    "invalid DFU version");
-		return FALSE;
+		if (!fu_strtoull(value, &tmp, 0x0, G_MAXUINT16, error))
+			return FALSE;
+		priv->force_version = tmp;
+		return TRUE;
 	}
 	if (g_strcmp0(key, "DfuForceTimeout") == 0) {
 		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT, error))
@@ -1688,9 +1685,11 @@ fu_dfu_device_init(FuDfuDevice *self)
 	priv->targets = g_ptr_array_new_with_free_func((GDestroyNotify)g_object_unref);
 	priv->timeout_ms = 1500;
 	priv->transfer_size = 64;
+	priv->force_version = G_MAXUINT16;
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_ADD_COUNTERPART_GUIDS);
 	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID);
+	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_MD_SET_SIGNED);
 	fu_device_set_remove_delay(FU_DEVICE(self), FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE);
 
 	fu_device_register_private_flag(FU_DEVICE(self),
