@@ -10,6 +10,7 @@
 
 #include <string.h>
 
+#include "fu-context-private.h"
 #include "fu-dfu-device.h"
 #include "fu-dfu-sector.h"
 #include "fu-dfu-target-private.h"
@@ -29,7 +30,7 @@ fu_test_compare_lines(const gchar *txt1, const gchar *txt2, GError **error)
 	g_autofree gchar *output = NULL;
 	if (g_strcmp0(txt1, txt2) == 0)
 		return TRUE;
-	if (fu_common_fnmatch(txt2, txt1))
+	if (fu_path_fnmatch(txt2, txt1))
 		return TRUE;
 	if (!g_file_set_contents("/tmp/a", txt1, -1, error))
 		return FALSE;
@@ -64,13 +65,14 @@ fu_dfu_target_dfuse_func(void)
 {
 	gboolean ret;
 	gchar *tmp;
-	g_autoptr(FuDfuDevice) device = fu_dfu_device_new(NULL);
+	g_autoptr(FuContext) ctx = fu_context_new();
+	g_autoptr(FuDfuDevice) device = fu_dfu_device_new(ctx, NULL);
 	g_autoptr(FuDfuTarget) target = NULL;
 	g_autoptr(GError) error = NULL;
 
 	/* NULL */
 	target = g_object_new(FU_TYPE_DFU_TARGET, NULL);
-	fu_dfu_target_set_device(target, device);
+	fu_device_set_proxy(FU_DEVICE(target), FU_DEVICE(device));
 	ret = fu_dfu_target_parse_sectors(target, NULL, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
@@ -150,13 +152,17 @@ fu_dfu_target_dfuse_func(void)
 int
 main(int argc, char **argv)
 {
+	g_autofree gchar *testdatadir = NULL;
+
 	g_test_init(&argc, &argv, NULL);
 
 	/* only critical and error are fatal */
 	g_log_set_fatal_mask(NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
+	(void)g_setenv("G_MESSAGES_DEBUG", "all", FALSE);
 
-	/* log everything */
-	g_setenv("G_MESSAGES_DEBUG", "all", FALSE);
+	/* environment */
+	testdatadir = g_test_build_filename(G_TEST_DIST, "tests", NULL);
+	(void)g_setenv("FWUPD_SYSFSFWATTRIBDIR", testdatadir, TRUE);
 
 	/* tests go here */
 	g_test_add_func("/dfu/enums", fu_dfu_enums_func);
