@@ -180,7 +180,6 @@ fu_dfu_tool_get_default_device(FuDfuTool *self, GError **error)
 		gchar *tmp;
 		guint64 pid;
 		guint64 vid;
-		g_autoptr(FuDfuDevice) device = NULL;
 		g_autoptr(GUsbDevice) usb_device = NULL;
 
 		/* parse */
@@ -220,17 +219,14 @@ fu_dfu_tool_get_default_device(FuDfuTool *self, GError **error)
 				       (guint)pid);
 			return NULL;
 		}
-		device = fu_dfu_device_new(usb_device);
-		fu_device_set_context(FU_DEVICE(device), self->ctx);
-		return g_steal_pointer(&device);
+		return fu_dfu_device_new(self->ctx, usb_device);
 	}
 
 	/* auto-detect first device */
 	devices = g_usb_context_get_devices(self->usb_context);
 	for (guint i = 0; i < devices->len; i++) {
 		GUsbDevice *usb_device = g_ptr_array_index(devices, i);
-		g_autoptr(FuDfuDevice) device = fu_dfu_device_new(usb_device);
-		fu_device_set_context(FU_DEVICE(device), self->ctx);
+		g_autoptr(FuDfuDevice) device = fu_dfu_device_new(self->ctx, usb_device);
 		if (fu_device_probe(FU_DEVICE(device), NULL))
 			return g_steal_pointer(&device);
 	}
@@ -631,7 +627,7 @@ fu_dfu_tool_write_alt(FuDfuTool *self, gchar **values, GError **error)
 static gboolean
 fu_dfu_tool_write(FuDfuTool *self, gchar **values, GError **error)
 {
-	FwupdInstallFlags flags = FWUPD_INSTALL_FLAG_NONE;
+	FwupdInstallFlags flags = FWUPD_INSTALL_FLAG_NO_SEARCH;
 	g_autoptr(FuDfuDevice) device = NULL;
 	g_autoptr(GBytes) fw = NULL;
 	g_autoptr(FuDeviceLocker) locker = NULL;
@@ -647,7 +643,7 @@ fu_dfu_tool_write(FuDfuTool *self, gchar **values, GError **error)
 	}
 
 	/* open file */
-	fw = fu_common_get_contents_bytes(values[0], error);
+	fw = fu_bytes_get_contents(values[0], error);
 	if (fw == NULL)
 		return FALSE;
 
@@ -694,7 +690,7 @@ fu_dfu_tool_write(FuDfuTool *self, gchar **values, GError **error)
 	if (!fu_device_attach_full(FU_DEVICE(device), progress, error))
 		return FALSE;
 
-	if (fu_dfu_device_has_attribute(device, FU_DFU_DEVICE_ATTR_MANIFEST_TOL)) {
+	if (fu_device_has_private_flag(FU_DEVICE(device), FU_DFU_DEVICE_FLAG_MANIFEST_TOL)) {
 		if (!fu_dfu_device_wait_for_replug(self,
 						   device,
 						   fu_device_get_remove_delay(FU_DEVICE(device)),
@@ -836,7 +832,7 @@ main(int argc, char *argv[])
 
 	/* set verbose? */
 	if (verbose)
-		g_setenv("G_MESSAGES_DEBUG", "all", FALSE);
+		(void)g_setenv("G_MESSAGES_DEBUG", "all", FALSE);
 
 	/* version */
 	if (version) {
