@@ -204,7 +204,7 @@ fu_elantp_hid_haptic_device_ensure_eeprom_iap_ctrl(FuDevice *parent,
 }
 
 static gboolean
-fu_elantp_hid_haptic_device_get_hatpic_driver_ic(FuDevice *parent,
+fu_elantp_hid_haptic_device_get_haptic_driver_ic(FuDevice *parent,
 						 FuElantpHidHapticDevice *self,
 						 GError **error)
 {
@@ -259,7 +259,7 @@ fu_elantp_hid_haptic_device_get_version(FuDevice *parent,
 		g_prefix_error(error, "failed to write haptic version cmd: ");
 		return FALSE;
 	}
-	g_usleep(ELANTP_DELAY_RESET * 1000);
+	fu_device_sleep(FU_DEVICE(self), ELANTP_DELAY_RESET);
 
 	if (!fu_elantp_hid_haptic_device_read_cmd(parent, 0x0321, buf, sizeof(buf), error)) {
 		g_prefix_error(error, "failed to read haptic version cmd: ");
@@ -276,7 +276,7 @@ fu_elantp_hid_haptic_device_get_version(FuDevice *parent,
 		g_prefix_error(error, "failed to write haptic iap version cmd: ");
 		return FALSE;
 	}
-	g_usleep(ELANTP_DELAY_RESET * 1000);
+	fu_device_sleep(FU_DEVICE(self), ELANTP_DELAY_RESET);
 
 	if (!fu_elantp_hid_haptic_device_read_cmd(parent, 0x0321, buf, sizeof(buf), error)) {
 		g_prefix_error(error, "failed to read haptic iap version cmd: ");
@@ -351,7 +351,7 @@ fu_elantp_hid_haptic_device_write_checksum_cb(FuDevice *parent, gpointer user_da
 
 	if (!fu_elantp_hid_haptic_device_write_cmd(parent,
 						   ETP_CMD_I2C_EEPROM_SETTING,
-						   ETP_CMD_I2C_EEPROM_WRITE_INFOMATION,
+						   ETP_CMD_I2C_EEPROM_WRITE_INFORMATION,
 						   error)) {
 		g_prefix_error(error, "failed to write haptic info: ");
 		return FALSE;
@@ -366,7 +366,7 @@ fu_elantp_hid_haptic_device_write_checksum_cb(FuDevice *parent, gpointer user_da
 	}
 	value = fu_memread_uint16(buf, G_LITTLE_ENDIAN);
 
-	if ((value & 0xFFFF) != ETP_CMD_I2C_EEPROM_WRITE_INFOMATION) {
+	if ((value & 0xFFFF) != ETP_CMD_I2C_EEPROM_WRITE_INFORMATION) {
 		g_set_error(error,
 			    G_IO_ERROR,
 			    G_IO_ERROR_FAILED,
@@ -512,7 +512,7 @@ fu_elantp_hid_haptic_device_setup(FuDevice *device, GError **error)
 	if (parent == NULL)
 		return FALSE;
 
-	if (!fu_elantp_hid_haptic_device_get_hatpic_driver_ic(FU_DEVICE(parent), self, error)) {
+	if (!fu_elantp_hid_haptic_device_get_haptic_driver_ic(FU_DEVICE(parent), self, error)) {
 		g_prefix_error(error, "this module is not support haptic EEPROM: ");
 		return FALSE;
 	}
@@ -732,8 +732,9 @@ fu_elantp_hid_haptic_device_write_chunks_cb(FuDevice *device, gpointer user_data
 							  error))
 			return FALSE;
 
-		g_usleep(self->fw_page_size == 512 ? ELANTP_DELAY_WRITE_BLOCK_512 * 1000
-						   : ELANTP_DELAY_WRITE_BLOCK * 1000);
+		fu_device_sleep(device,
+				self->fw_page_size == 512 ? ELANTP_DELAY_WRITE_BLOCK_512
+							  : ELANTP_DELAY_WRITE_BLOCK);
 
 		if (!fu_elantp_hid_haptic_device_write_cmd(FU_DEVICE(parent),
 							   ETP_CMD_I2C_SET_EEPROM_CTRL,
@@ -828,7 +829,7 @@ fu_elantp_hid_haptic_device_write_firmware(FuDevice *device,
 		g_prefix_error(error, "cannot leave EEPROM IAP: ");
 		return FALSE;
 	}
-	g_usleep(ELANTP_DELAY_RESET * 1000);
+	fu_device_sleep(device, ELANTP_DELAY_RESET);
 	if (!fu_elantp_hid_haptic_device_get_checksum(FU_DEVICE(parent), &checksum_device, error)) {
 		g_prefix_error(error, "read device checksum fail: ");
 		return FALSE;
@@ -1044,7 +1045,7 @@ fu_elantp_hid_haptic_device_attach(FuDevice *device, FuProgress *progress, GErro
 		g_prefix_error(error, "cannot reset TP: ");
 		return FALSE;
 	}
-	g_usleep(ELANTP_DELAY_RESET * 1000);
+	fu_device_sleep(device, ELANTP_DELAY_RESET);
 	if (!fu_elantp_hid_haptic_device_write_cmd(FU_DEVICE(parent),
 						   ETP_CMD_I2C_IAP_RESET,
 						   ETP_I2C_ENABLE_REPORT,
