@@ -118,12 +118,7 @@ fu_emmc_device_get_sysattr_guint64(GUdevDevice *device,
 
 	sysfs = g_udev_device_get_sysfs_attr(device, name);
 	if (sysfs == NULL) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_INTERNAL,
-			    "failed get %s for %s",
-			    name,
-			    sysfs);
+		g_set_error(error, FWUPD_ERROR, FWUPD_ERROR_INTERNAL, "failed get %s", name);
 		return FALSE;
 	}
 
@@ -141,6 +136,7 @@ fu_emmc_device_probe(FuDevice *device, GError **error)
 	guint64 manfid = 0;
 	const gchar *tmp;
 	g_autoptr(GUdevDevice) udev_parent = NULL;
+	g_autofree gchar *man_oem_name = NULL;
 	g_autofree gchar *vendor_id = NULL;
 	g_autoptr(GRegex) dev_regex = NULL;
 
@@ -226,6 +222,13 @@ fu_emmc_device_probe(FuDevice *device, GError **error)
 	fu_device_build_instance_id(device, NULL, "EMMC", "MAN", "NAME", "REV", NULL);
 	fu_device_build_instance_id(device, NULL, "EMMC", "MAN", "OEM", "NAME", "REV", NULL);
 
+	/* this is a (invalid!) instance ID added for legacy compatibility */
+	man_oem_name = g_strdup_printf("EMMC\\%04" G_GUINT64_FORMAT "&%04" G_GUINT64_FORMAT "&%s",
+				       manfid,
+				       oemid,
+				       fu_device_get_name(device));
+	fu_device_add_instance_id(device, man_oem_name);
+
 	/* set the vendor */
 	tmp = g_udev_device_get_sysfs_attr(udev_parent, "manfid");
 	vendor_id = g_strdup_printf("EMMC:%s", tmp);
@@ -248,13 +251,14 @@ fu_emmc_device_probe(FuDevice *device, GError **error)
 static gboolean
 fu_emmc_read_extcsd(FuEmmcDevice *self, guint8 *ext_csd, gsize ext_csd_sz, GError **error)
 {
-	struct mmc_ioc_cmd idata = {0x0};
-	idata.write_flag = 0;
-	idata.opcode = MMC_SEND_EXT_CSD;
-	idata.arg = 0;
-	idata.flags = MMC_RSP_SPI_R1 | MMC_RSP_R1 | MMC_CMD_ADTC;
-	idata.blksz = 512;
-	idata.blocks = 1;
+	struct mmc_ioc_cmd idata = {
+	    .write_flag = 0,
+	    .opcode = MMC_SEND_EXT_CSD,
+	    .arg = 0,
+	    .flags = MMC_RSP_SPI_R1 | MMC_RSP_R1 | MMC_CMD_ADTC,
+	    .blksz = 512,
+	    .blocks = 1,
+	};
 	mmc_ioc_cmd_set_data(idata, ext_csd);
 	return fu_udev_device_ioctl(FU_UDEV_DEVICE(self),
 				    MMC_IOC_CMD,
