@@ -27,7 +27,7 @@ G_DEFINE_TYPE(FuFocalfpHidDevice, fu_focalfp_hid_device, FU_TYPE_UDEV_DEVICE)
 #define CMD_READY_FOR_UPGRADE	       0x42
 #define CMD_SEND_DATA		       0x43
 #define CMD_UPGRADE_CHECKSUM	       0x44
-#define CMD_EXIT_UPRADE_MODE	       0x45
+#define CMD_EXIT_UPGRADE_MODE	       0x45
 #define CMD_USB_READ_UPGRADE_ID	       0x46
 #define CMD_USB_ERASE_FLASH	       0x47
 #define CMD_USB_BOOT_READ	       0x48
@@ -385,9 +385,7 @@ static gboolean
 fu_focalfp_hid_device_setup(FuDevice *device, GError **error)
 {
 	FuFocalfpHidDevice *self = FU_FOCALFP_HID_DEVICE(device);
-	guint16 fwver;
 	guint8 buf[2] = {0x0};
-	g_autofree gchar *version = NULL;
 
 	/* get current firmware version */
 	if (!fu_focalfp_hid_device_read_reg(self, 0xA6, buf, error)) {
@@ -398,9 +396,7 @@ fu_focalfp_hid_device_setup(FuDevice *device, GError **error)
 		g_prefix_error(error, "failed to read version2: ");
 		return FALSE;
 	}
-	fwver = fu_memread_uint16(buf, G_BIG_ENDIAN);
-	version = fu_version_from_uint16(fwver, FWUPD_VERSION_FORMAT_HEX);
-	fu_device_set_version(device, version);
+	fu_device_set_version_from_uint16(device, fu_memread_uint16(buf, G_BIG_ENDIAN));
 
 	/* success */
 	return TRUE;
@@ -486,7 +482,7 @@ fu_focalfp_hid_device_write_firmware(FuDevice *device,
 	}
 	if (!fu_focalfp_hid_device_erase_flash(self, error))
 		return FALSE;
-	g_usleep(1000 * 1000);
+	fu_device_sleep(device, 1000);
 	if (!fu_focalfp_hid_device_wait_for_upgrade_ready(self, 20, error))
 		return FALSE;
 	fu_progress_step_done(progress);
@@ -501,7 +497,7 @@ fu_focalfp_hid_device_write_firmware(FuDevice *device,
 	fu_progress_step_done(progress);
 
 	/* write flash end and check ready (fw calculate checksum) */
-	g_usleep(50 * 1000);
+	fu_device_sleep(device, 50);
 	if (!fu_focalfp_hid_device_wait_for_upgrade_ready(self, 5, error))
 		return FALSE;
 	fu_progress_step_done(progress);
@@ -510,7 +506,7 @@ fu_focalfp_hid_device_write_firmware(FuDevice *device,
 	if (!fu_focalfp_hid_device_checksum_upgrade(self, &checksum, error))
 		return FALSE;
 	if (checksum != fu_focalfp_firmware_get_checksum(FU_FOCALFP_FIRMWARE(firmware))) {
-		g_usleep(500 * 1000);
+		fu_device_sleep(device, 500);
 		g_set_error(error,
 			    G_IO_ERROR,
 			    G_IO_ERROR_INVALID_DATA,
@@ -532,7 +528,7 @@ fu_focalfp_hid_device_reload(FuDevice *device, GError **error)
 	FuFocalfpHidDevice *self = FU_FOCALFP_HID_DEVICE(device);
 	guint8 idbuf[2] = {0x0};
 
-	g_usleep(500 * 1000);
+	fu_device_sleep(device, 500);
 	if (!fu_focalfp_hid_device_read_reg(self, 0x9F, &idbuf[0], error))
 		return FALSE;
 	if (!fu_focalfp_hid_device_read_reg(self, 0xA3, &idbuf[1], error))
@@ -596,7 +592,7 @@ fu_focalfp_hid_device_detach(FuDevice *device, FuProgress *progress, GError **er
 		g_prefix_error(error, "failed to CMD_ENTER_UPGRADE_MODE: ");
 		return FALSE;
 	}
-	g_usleep(200 * 1000);
+	fu_device_sleep(device, 200);
 
 	/* second command : bootloader normal mode --> bootloader upgrade mode */
 	if (!fu_device_retry_full(device,
@@ -608,7 +604,7 @@ fu_focalfp_hid_device_detach(FuDevice *device, FuProgress *progress, GError **er
 		return FALSE;
 
 	/* success */
-	g_usleep(200 * 1000);
+	fu_device_sleep(device, 200);
 	return TRUE;
 }
 
@@ -617,7 +613,7 @@ static gboolean
 fu_focalfp_hid_device_attach(FuDevice *device, FuProgress *progress, GError **error)
 {
 	FuFocalfpHidDevice *self = FU_FOCALFP_HID_DEVICE(device);
-	guint8 wbuf[64] = {CMD_EXIT_UPRADE_MODE};
+	guint8 wbuf[64] = {CMD_EXIT_UPGRADE_MODE};
 	guint8 rbuf[64] = {0x0};
 
 	if (!fu_focalfp_hid_device_io(self, wbuf, 1, rbuf, 6, error))
@@ -628,7 +624,7 @@ fu_focalfp_hid_device_attach(FuDevice *device, FuProgress *progress, GError **er
 		return FALSE;
 
 	/* success */
-	g_usleep(500 * 1000);
+	fu_device_sleep(device, 500);
 	return TRUE;
 }
 
