@@ -22,7 +22,7 @@ static void
 fu_fresco_pd_device_to_string(FuDevice *device, guint idt, GString *str)
 {
 	FuFrescoPdDevice *self = FU_FRESCO_PD_DEVICE(device);
-	fu_common_string_append_ku(str, idt, "CustomerID", self->customer_id);
+	fu_string_append_ku(str, idt, "CustomerID", self->customer_id);
 }
 
 static gboolean
@@ -40,7 +40,7 @@ fu_fresco_pd_device_transfer_read(FuFrescoPdDevice *self,
 
 	/* to device */
 	if (g_getenv("FWUPD_FRESCO_PD_VERBOSE") != NULL)
-		fu_common_dump_raw(G_LOG_DOMAIN, "read", buf, bufsz);
+		fu_dump_raw(G_LOG_DOMAIN, "read", buf, bufsz);
 	if (!g_usb_device_control_transfer(usb_device,
 					   G_USB_DEVICE_DIRECTION_DEVICE_TO_HOST,
 					   G_USB_DEVICE_REQUEST_TYPE_VENDOR,
@@ -86,7 +86,7 @@ fu_fresco_pd_device_transfer_write(FuFrescoPdDevice *self,
 
 	/* to device */
 	if (g_getenv("FWUPD_FRESCO_PD_VERBOSE") != NULL)
-		fu_common_dump_raw(G_LOG_DOMAIN, "write", buf, bufsz);
+		fu_dump_raw(G_LOG_DOMAIN, "write", buf, bufsz);
 	if (!g_usb_device_control_transfer(usb_device,
 					   G_USB_DEVICE_DIRECTION_HOST_TO_DEVICE,
 					   G_USB_DEVICE_REQUEST_TYPE_VENDOR,
@@ -164,9 +164,7 @@ static gboolean
 fu_fresco_pd_device_setup(FuDevice *device, GError **error)
 {
 	FuFrescoPdDevice *self = FU_FRESCO_PD_DEVICE(device);
-	FuUsbDevice *usb_device = FU_USB_DEVICE(device);
 	guint8 ver[4] = {0x0};
-	g_autofree gchar *instance_id = NULL;
 	g_autofree gchar *version = NULL;
 
 	/* FuUsbDevice->setup */
@@ -185,14 +183,10 @@ fu_fresco_pd_device_setup(FuDevice *device, GError **error)
 
 	/* get customer ID */
 	self->customer_id = ver[1];
-	instance_id = g_strdup_printf("USB\\VID_%04X&PID_%04X&CID_%02X",
-				      fu_usb_device_get_vid(usb_device),
-				      fu_usb_device_get_pid(usb_device),
-				      self->customer_id);
-	fu_device_add_instance_id(device, instance_id);
 
-	/* success */
-	return TRUE;
+	/* add extra instance ID */
+	fu_device_add_instance_u8(device, "CID", self->customer_id);
+	return fu_device_build_instance_id(device, error, "USB", "VID", "PID", "CID", NULL);
 }
 
 static FuFirmware *
@@ -260,11 +254,11 @@ fu_fresco_pd_device_write_firmware(FuDevice *device,
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2);	/* enable mtp write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 50);	/* copy-mmio */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 46); /* customize */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2);	/* boot */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2, "enable-mtp-write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 50, "copy-mmio");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 46, "customize");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2, "boot");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, NULL);
 
 	/* get default blob, which we know is already bigger than FirmwareMin */
 	fw = fu_firmware_get_bytes(firmware, error);
@@ -414,16 +408,16 @@ fu_fresco_pd_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
 	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 100); /* write */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0); /* attach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 0);	/* reload */
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 100, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 0, "reload");
 }
 
 static void
 fu_fresco_pd_device_init(FuFrescoPdDevice *self)
 {
-	fu_device_add_icon(FU_DEVICE(self), "audio-card");
+	fu_device_add_icon(FU_DEVICE(self), "usb-hub");
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_add_protocol(FU_DEVICE(self), "com.frescologic.pd");
