@@ -1,4 +1,5 @@
 /*
+ * Copyright (C) 2022 Gaël PORTAY <gael.portay@collabora.com>
  * Copyright (C) 2021 Ricardo Cañuelo <ricardo.canuelo@collabora.com>
  *
  * SPDX-License-Identifier: LGPL-2.1+
@@ -20,8 +21,18 @@
  * FU_GENESYS_USBHUB_FLAG_HAS_MSTAR_SCALER:
  *
  * Device has a MStar scaler attached via I2C.
+ *
+ * Since 1.7.6
  */
 #define FU_GENESYS_USBHUB_FLAG_HAS_MSTAR_SCALER (1 << 0)
+/**
+ * FU_GENESYS_USBHUB_FLAG_HAS_PUBLIC_KEY:
+ *
+ * Device has a public-key appended to firmware.
+ *
+ * Since 1.8.0
+ */
+#define FU_GENESYS_USBHUB_FLAG_HAS_PUBLIC_KEY (1 << 1)
 
 #define GENESYS_USBHUB_STATIC_TOOL_DESC_IDX_USB_3_0  0x84
 #define GENESYS_USBHUB_DYNAMIC_TOOL_DESC_IDX_USB_3_0 0x85
@@ -30,12 +41,6 @@
 #define GENESYS_USBHUB_FW_INFO_DESC_IDX		     0x83
 #define GENESYS_USBHUB_VENDOR_SUPPORT_DESC_IDX	     0x86
 
-#define GENESYS_USBHUB_FW_SIG_OFFSET   0xFC
-#define GENESYS_USBHUB_FW_SIG_LEN      4
-#define GENESYS_USBHUB_FW_SIG_TEXT_HUB "XROM"
-
-#define GENESYS_USBHUB_CODE_SIZE_OFFSET 0xFB
-
 #define GENESYS_USBHUB_GL_HUB_VERIFY 0x71
 #define GENESYS_USBHUB_GL_HUB_SWITCH 0x81
 #define GENESYS_USBHUB_GL_HUB_READ   0x82
@@ -61,26 +66,68 @@ typedef enum {
 	TOOL_STRING_VERSION_13BYTE_DYNAMIC,
 } FuGenesysToolStringVersion;
 
+typedef struct __attribute__((packed)) {
+	guint8 running_mode; /* 'M' for mask code, the others for bank code */
+
+	guint8 ss_port_number; /* super-speed port number */
+	guint8 hs_port_number; /* high-speed port number */
+
+	guint8 ss_connection_status; /* bit field. ON = DFP is a super-speed device */
+	guint8 hs_connection_status; /* bit field. ON = DFP is a high-speed device */
+	guint8 fs_connection_status; /* bit field. ON = DFP is a full-speed device */
+	guint8 ls_connection_status; /* bit field. ON = DFP is a low-speed device */
+
+	guint8 charging;		  /* bit field. ON = DFP is a charging port */
+	guint8 non_removable_port_status; /* bit field. ON = DFP is a non-removable port */
+
+	/*
+	 * Bonding reports Hardware register status for GL3523:
+	 *   2 / 4 ports         : 1 means 4 ports, 0 means 2 ports
+	 *   MTT / STT           : 1 means Multi Token Transfer, 0 means Single TT
+	 *   Type - C            : 1 means disable, 0 means enable
+	 *   QC                  : 1 means disable, 0 means enable
+	 *   Flash dump location : 1 means 32KB offset bank 1, 0 means 0 offset bank 0.
+	 *
+	 * Tool string Version 1:
+	 *   Bit3 : Flash dump location
+	 *   BIT2 : Type - C
+	 *   BIT1 : MTT / STT
+	 *   BIT0 : 2 / 4 ports
+	 *
+	 * Tool string Version 2 or newer :
+	 *   Bit4 : Flash dump location
+	 *   BIT3 : Type - C
+	 *   BIT2 : MTT / STT
+	 *   BIT1 : 2 / 4 ports
+	 *   BIT0 : QC
+	 *
+	 * Default use '0'~'F', plus Bit4 may over value, should extract that.
+	 *
+	 * Bonding for GL3590:
+	 *   Bit7 : Flash dump location, 0 means bank 0, 1 means bank 1.
+	 */
+	guint8 bonding;
+
+	guint8 reserved[22];
+} FuGenesysDynamicToolString;
+
+typedef enum {
+	BANK_MASK_CODE,
+	BANK_FIRST,
+	BANK_SECOND,
+} FuGenesysRunningBank;
+
+#define GL3523_BONDING_VALID_BIT 0x0F
+#define GL3590_BONDING_VALID_BIT 0x7F
+
+#define GL3523_BONDING_FLASH_DUMP_LOCATION_BIT 1 << 4
+#define GL3590_BONDING_FLASH_DUMP_LOCATION_BIT 1 << 7
+
 typedef enum {
 	ISP_EXIT,
 	ISP_ENTER,
 } FuGenesysIspMode;
 
-typedef enum {
-	ISP_MODEL_UNKNOWN,
-
-	/* hub */
-	ISP_MODEL_HUB_GL3510,
-	ISP_MODEL_HUB_GL3521,
-	ISP_MODEL_HUB_GL3523,
-	ISP_MODEL_HUB_GL3590,
-	ISP_MODEL_HUB_GL7000,
-	ISP_MODEL_HUB_GL3525,
-
-	/* pd */
-	ISP_MODEL_PD_GL9510,
-} FuGenesysModel;
-
 typedef struct __attribute__((packed)) {
 	guint8 tool_version[6]; /* ISP tool defined by itself */
 	guint8 address_mode;
@@ -88,6 +135,11 @@ typedef struct __attribute__((packed)) {
 	guint8 update_fw_time[12]; /* YYYYMMDDhhmm */
 } FuGenesysFirmwareInfoToolString;
 
+typedef struct __attribute__((packed)) {
+	guint8 version[2];
+	guint8 supports[29];
+} FuGenesysVendorSupportToolString;
+
 typedef struct {
 	guint8 req_switch;
 	guint8 req_read;
@@ -97,10 +149,14 @@ typedef struct {
 struct _FuGenesysUsbhubDevice {
 	FuUsbDevice parent_instance;
 	FuGenesysStaticToolString static_ts;
+	FuGenesysDynamicToolString dynamic_ts;
 	FuGenesysFirmwareInfoToolString fwinfo_ts;
+	FuGenesysVendorSupportToolString vs_ts;
 	FuGenesysVendorCommandSetting vcs;
-	guint32 isp_model;
-	guint8 isp_revision;
+	FuGenesysChip chip;
+	guint32 running_bank;
+	guint8 bonding;
+	gboolean flash_dump_location_bit;
 	guint32 flash_erase_delay;
 	guint32 flash_write_delay;
 	guint32 flash_block_size;
@@ -115,6 +171,7 @@ struct _FuGenesysUsbhubDevice {
 	gboolean read_first_bank;
 	gboolean write_recovery_bank;
 
+	FuGenesysPublicKey public_key;
 	FuCfiDevice *cfi_device;
 };
 
@@ -246,7 +303,7 @@ fu_genesys_usbhub_device_cfi_setup(FuGenesysUsbhubDevice *self, GError **error)
 			if (cfi_device == NULL)
 				continue;
 
-			if (!fu_device_probe(FU_DEVICE(cfi_device), &error_local)) {
+			if (!fu_device_setup(FU_DEVICE(cfi_device), &error_local)) {
 				g_debug("ignoring %s: %s", flash_id, error_local->message);
 				continue;
 			}
@@ -268,7 +325,7 @@ fu_genesys_usbhub_device_cfi_setup(FuGenesysUsbhubDevice *self, GError **error)
 				else
 					len = 2;
 
-				fu_common_dump_raw(G_LOG_DOMAIN, "Flash ID", buf, len);
+				fu_dump_raw(G_LOG_DOMAIN, "Flash ID", buf, len);
 				g_debug("CFI: %s", fu_device_get_name(FU_DEVICE(cfi_device)));
 			}
 
@@ -277,7 +334,7 @@ fu_genesys_usbhub_device_cfi_setup(FuGenesysUsbhubDevice *self, GError **error)
 	}
 
 	/* failure */
-	g_set_error_literal(error, FWUPD_ERROR, FWUPD_ERROR_INTERNAL, "no CFI device found");
+	g_set_error_literal(error, FWUPD_ERROR, FWUPD_ERROR_NOT_FOUND, "no CFI device found");
 	return NULL;
 }
 #endif
@@ -351,6 +408,8 @@ fu_genesys_usbhub_device_set_isp_mode(FuGenesysUsbhubDevice *self,
 
 	if (mode == ISP_ENTER) {
 		FuGenesysWaitFlashRegisterHelper helper = {.reg = 5, .expected_val = 0};
+
+		/* 150ms */
 		if (!fu_device_retry(FU_DEVICE(self),
 				     fu_genesys_usbhub_device_wait_flash_status_register_cb,
 				     5,
@@ -414,7 +473,7 @@ fu_genesys_usbhub_device_authentication_request(FuGenesysUsbhubDevice *self,
 	if (buf != 1) {
 		g_set_error_literal(error,
 				    FWUPD_ERROR,
-				    FWUPD_ERROR_INTERNAL,
+				    FWUPD_ERROR_AUTH_FAILED,
 				    "device authentication failed");
 		return FALSE;
 	}
@@ -486,6 +545,15 @@ fu_genesys_usbhub_device_get_descriptor_data(GBytes *desc_bytes,
 	for (gsize i = 0, j = 0; i < bufsz && j < dst_size; i += 2, j++)
 		dst[j] = buf[i];
 
+	/* legacy hub replies "USB2.0 Hub" or "USB3.0 Hub" */
+	if (memcmp(dst, "USB", 3) == 0) {
+		g_set_error_literal(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_NOT_SUPPORTED,
+				    "tool string unsupported");
+		return FALSE;
+	}
+
 	/* success */
 	return TRUE;
 }
@@ -513,7 +581,7 @@ fu_genesys_usbhub_device_check_fw_signature(FuGenesysUsbhubDevice *self,
 	if (memcmp(sig, GENESYS_USBHUB_FW_SIG_TEXT_HUB, GENESYS_USBHUB_FW_SIG_LEN) != 0) {
 		g_set_error_literal(error,
 				    FWUPD_ERROR,
-				    FWUPD_ERROR_INTERNAL,
+				    FWUPD_ERROR_SIGNATURE_INVALID,
 				    "wrong firmware signature");
 		return FALSE;
 	}
@@ -522,19 +590,17 @@ fu_genesys_usbhub_device_check_fw_signature(FuGenesysUsbhubDevice *self,
 	return TRUE;
 }
 
-/* read the firmware size from the firmware stored in the device */
+/* read the code size from the firmware stored in the device */
 static gboolean
-fu_genesys_usbhub_device_get_fw_size(FuGenesysUsbhubDevice *self, int bank_num, GError **error)
+fu_genesys_usbhub_device_get_code_size(FuGenesysUsbhubDevice *self, int bank_num, GError **error)
 {
 	guint8 kbs = 0;
-
 	g_return_val_if_fail(bank_num < 2, FALSE);
-	g_return_val_if_fail(self->code_size == 0, FALSE);
 
 	if (!fu_genesys_usbhub_device_check_fw_signature(self, bank_num, error))
 		return FALSE;
 
-	/* get firmware size from device */
+	/* get code size from device */
 	if (!fu_genesys_usbhub_device_read_flash(self,
 						 self->fw_bank_addr[bank_num] +
 						     GENESYS_USBHUB_CODE_SIZE_OFFSET,
@@ -550,14 +616,69 @@ fu_genesys_usbhub_device_get_fw_size(FuGenesysUsbhubDevice *self, int bank_num,
 	/* success */
 	return TRUE;
 }
+
+static gint
+fu_genesys_tsdigit_value(gchar c)
+{
+	if (c >= 'A' && c <= 'Z')
+		return c - 'A' + 10;
+	if (c >= 'a' && c <= 'z')
+		return c - 'a' + 10;
+	return g_ascii_digit_value(c);
+}
+
+static gboolean
+fu_genesys_usbhub_device_get_bonding_and_flash_dump_location_bit(FuGenesysUsbhubDevice *self,
+								 GError **error)
+{
+	gint bonding;
+
+	/* bonding is not supported */
+	if (fu_genesys_tsdigit_value(self->static_ts.tool_string_version) <
+		TOOL_STRING_VERSION_BONDING ||
+	    self->dynamic_ts.bonding == 0) {
+		/* success */
+		return TRUE;
+	}
+
+	if (self->chip.model == ISP_MODEL_HUB_GL3590) {
+		self->bonding = (self->dynamic_ts.bonding & GL3590_BONDING_VALID_BIT);
+		self->flash_dump_location_bit =
+		    self->dynamic_ts.bonding & GL3590_BONDING_FLASH_DUMP_LOCATION_BIT;
+
+		/* success */
+		return TRUE;
+	}
+
+	bonding = fu_genesys_tsdigit_value((gchar)self->dynamic_ts.bonding);
+	if (bonding == -1) {
+		g_set_error(error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_INTERNAL,
+			    "wrong bonding value 0x%02x",
+			    self->dynamic_ts.bonding);
+		return FALSE;
+	}
+
+	if (fu_genesys_tsdigit_value(self->static_ts.tool_string_version) <
+	    TOOL_STRING_VERSION_BONDING_QC)
+		bonding <<= 1;
+	self->bonding = (bonding & GL3523_BONDING_VALID_BIT);
+	self->flash_dump_location_bit = bonding & GL3523_BONDING_FLASH_DUMP_LOCATION_BIT;
+
+	/* success */
+	return TRUE;
+}
 #endif
 
 static gboolean
 fu_genesys_usbhub_device_detach(FuDevice *device, FuProgress *progress, GError **error)
 {
 	FuGenesysUsbhubDevice *self = FU_GENESYS_USBHUB_DEVICE(device);
-	if (!fu_genesys_usbhub_device_authenticate(self, error))
-		return FALSE;
+	if (fu_device_has_private_flag(device, FU_GENESYS_USBHUB_FLAG_HAS_PUBLIC_KEY)) {
+		if (!fu_genesys_usbhub_device_authenticate(self, error))
+			return FALSE;
+	}
 	if (!fu_genesys_usbhub_device_set_isp_mode(self, ISP_ENTER, error))
 		return FALSE;
 
@@ -581,18 +702,14 @@ static GBytes *
 fu_genesys_usbhub_device_dump_firmware(FuDevice *device, FuProgress *progress, GError **error)
 {
 	FuGenesysUsbhubDevice *self = FU_GENESYS_USBHUB_DEVICE(device);
-	gsize address = self->fw_bank_addr[0];
-	gsize size = self->code_size + self->extend_size;
+	gsize size = fu_cfi_device_get_size(self->cfi_device);
 	g_autoptr(FuDeviceLocker) locker = NULL;
 	g_autofree guint8 *buf = NULL;
 
-	if (self->fw_bank_vers[0] == 0 && fu_device_has_flag(device, FWUPD_DEVICE_FLAG_DUAL_IMAGE))
-		address = self->fw_bank_addr[1];
-
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1); /* detach */
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 99);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 1, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 99, NULL);
 
 	/* require detach -> attach */
 	locker = fu_device_locker_new_full(device,
@@ -605,7 +722,7 @@ fu_genesys_usbhub_device_dump_firmware(FuDevice *device, FuProgress *progress, G
 
 	buf = g_malloc0(size);
 	if (!fu_genesys_usbhub_device_read_flash(self,
-						 address,
+						 0,
 						 buf,
 						 size,
 						 fu_progress_get_child(progress),
@@ -613,6 +730,7 @@ fu_genesys_usbhub_device_dump_firmware(FuDevice *device, FuProgress *progress, G
 		return NULL;
 	fu_progress_step_done(progress);
 
+	/* success */
 	return g_bytes_new_take(g_steal_pointer(&buf), size);
 }
 
@@ -625,9 +743,12 @@ fu_genesys_usbhub_device_setup(FuDevice *device, GError **error)
 	gsize bufsz;
 	guint32 block_size;
 	guint32 sector_size;
+	guint64 revision_tmp = 0;
 	guint16 version_raw;
 	guint8 static_idx = 0;
 	guint8 dynamic_idx = 0;
+	gchar rev[3] = {0};
+	gint tool_string_version = 0;
 	g_autoptr(FuFirmware) firmware = NULL;
 	g_autoptr(GBytes) static_buf = NULL;
 	g_autoptr(GBytes) dynamic_buf = NULL;
@@ -635,6 +756,7 @@ fu_genesys_usbhub_device_setup(FuDevice *device, GError **error)
 	g_autoptr(GError) error_local = NULL;
 	g_autoptr(GBytes) blob = NULL;
 	g_autofree guint8 *buf = NULL;
+	g_autofree gchar *ic_type = NULL;
 
 	/* FuUsbDevice->setup */
 	if (!FU_DEVICE_CLASS(fu_genesys_usbhub_device_parent_class)->setup(device, error)) {
@@ -677,30 +799,35 @@ fu_genesys_usbhub_device_setup(FuDevice *device, GError **error)
 		return FALSE;
 	}
 	if (g_getenv("FWUPD_GENESYS_USBHUB_VERBOSE") != NULL) {
-		fu_common_dump_raw(G_LOG_DOMAIN,
-				   "Static info",
-				   (guint8 *)&self->static_ts,
-				   sizeof(FuGenesysStaticToolString));
+		fu_dump_raw(G_LOG_DOMAIN,
+			    "Static info",
+			    (guint8 *)&self->static_ts,
+			    sizeof(FuGenesysStaticToolString));
 	}
-	if (self->static_ts.tool_string_version != 0xff) {
-		gchar rev[3] = {0};
-		guint64 tmp;
 
-		if (memcmp(self->static_ts.mask_project_ic_type, "3523", 4) == 0) {
-			self->isp_model = ISP_MODEL_HUB_GL3523;
-		} else if (memcmp(self->static_ts.mask_project_ic_type, "3590", 4) == 0) {
-			self->isp_model = ISP_MODEL_HUB_GL3590;
-		} else {
-			g_set_error_literal(error,
-					    FWUPD_ERROR,
-					    FWUPD_ERROR_INTERNAL,
-					    "Unknown ISP model");
-			return FALSE;
-		}
-		memcpy(rev, &self->static_ts.mask_project_ic_type[4], 2);
-		tmp = fu_common_strtoull(rev);
-		self->isp_revision = tmp;
+	if (memcmp(self->static_ts.mask_project_ic_type, "3521", 4) == 0) {
+		self->chip.model = ISP_MODEL_HUB_GL3521;
+	} else if (memcmp(self->static_ts.mask_project_ic_type, "3523", 4) == 0) {
+		self->chip.model = ISP_MODEL_HUB_GL3523;
+	} else if (memcmp(self->static_ts.mask_project_ic_type, "3590", 4) == 0) {
+		self->chip.model = ISP_MODEL_HUB_GL3590;
+	} else {
+		ic_type = fu_strsafe((const gchar *)&self->static_ts.mask_project_ic_type,
+				     sizeof(self->static_ts.mask_project_ic_type));
+		g_set_error(error,
+			    FWUPD_ERROR,
+			    FWUPD_ERROR_NOT_SUPPORTED,
+			    "IC type %s not supported",
+			    ic_type);
+		return FALSE;
 	}
+	memcpy(rev, &self->static_ts.mask_project_ic_type[4], 2);
+
+	if (!fu_strtoull(rev, &revision_tmp, 0, G_MAXINT32, error)) {
+		g_prefix_error(error, "failed to parse %s: ", rev);
+		return FALSE;
+	}
+	self->chip.revision = revision_tmp;
 
 	dynamic_buf =
 	    g_usb_device_get_string_descriptor_bytes_full(usb_device,
@@ -712,6 +839,19 @@ fu_genesys_usbhub_device_setup(FuDevice *device, GError **error)
 		g_prefix_error(error, "failed to get dynamic tool info from device: ");
 		return FALSE;
 	}
+	if (!fu_genesys_usbhub_device_get_descriptor_data(dynamic_buf,
+							  (guint8 *)&self->dynamic_ts,
+							  sizeof(FuGenesysDynamicToolString),
+							  error)) {
+		g_prefix_error(error, "failed to get dynamic tool info from device: ");
+		return FALSE;
+	}
+	if (g_getenv("FWUPD_GENESYS_USBHUB_VERBOSE") != NULL) {
+		fu_dump_raw(G_LOG_DOMAIN,
+			    "Dynamic info",
+			    (guint8 *)&self->dynamic_ts,
+			    sizeof(FuGenesysDynamicToolString));
+	}
 
 	fw_buf =
 	    g_usb_device_get_string_descriptor_bytes_full(usb_device,
@@ -731,13 +871,14 @@ fu_genesys_usbhub_device_setup(FuDevice *device, GError **error)
 		return FALSE;
 	}
 	if (g_getenv("FWUPD_GENESYS_USBHUB_VERBOSE") != NULL) {
-		fu_common_dump_raw(G_LOG_DOMAIN,
-				   "Fw info",
-				   (guint8 *)&self->fwinfo_ts,
-				   sizeof(FuGenesysFirmwareInfoToolString));
+		fu_dump_raw(G_LOG_DOMAIN,
+			    "Fw info",
+			    (guint8 *)&self->fwinfo_ts,
+			    sizeof(FuGenesysFirmwareInfoToolString));
 	}
 
-	if (self->static_ts.tool_string_version >= TOOL_STRING_VERSION_VENDOR_SUPPORT) {
+	tool_string_version = fu_genesys_tsdigit_value(self->static_ts.tool_string_version);
+	if (tool_string_version >= TOOL_STRING_VERSION_VENDOR_SUPPORT) {
 		g_autoptr(GBytes) vendor_buf = g_usb_device_get_string_descriptor_bytes_full(
 		    usb_device,
 		    GENESYS_USBHUB_VENDOR_SUPPORT_DESC_IDX,
@@ -748,12 +889,29 @@ fu_genesys_usbhub_device_setup(FuDevice *device, GError **error)
 			g_prefix_error(error, "failed to get vendor support info from device: ");
 			return FALSE;
 		}
+		if (!fu_genesys_usbhub_device_get_descriptor_data(
+			vendor_buf,
+			(guint8 *)&self->vs_ts,
+			sizeof(FuGenesysVendorSupportToolString),
+			error)) {
+			g_prefix_error(error, "failed to get vendor support info from device: ");
+			return FALSE;
+		}
+		if (g_getenv("FWUPD_GENESYS_USBHUB_VERBOSE") != NULL) {
+			fu_dump_raw(G_LOG_DOMAIN,
+				    "Vendor support",
+				    (guint8 *)&self->vs_ts,
+				    sizeof(FuGenesysVendorSupportToolString));
+		}
 	}
 
-	if (!fu_genesys_usbhub_device_authenticate(self, error))
-		return FALSE;
+	if (fu_device_has_private_flag(device, FU_GENESYS_USBHUB_FLAG_HAS_PUBLIC_KEY)) {
+		if (!fu_genesys_usbhub_device_authenticate(self, error))
+			return FALSE;
+	}
 	if (!fu_genesys_usbhub_device_set_isp_mode(self, ISP_ENTER, error))
 		return FALSE;
+	/* setup cfi device */
 	self->cfi_device = fu_genesys_usbhub_device_cfi_setup(self, error);
 	if (self->cfi_device == NULL)
 		return FALSE;
@@ -764,35 +922,54 @@ fu_genesys_usbhub_device_setup(FuDevice *device, GError **error)
 	if (sector_size != 0)
 		self->flash_sector_size = sector_size;
 
+	/* get bonding and flash dump location bit */
+	if (!fu_genesys_usbhub_device_get_bonding_and_flash_dump_location_bit(self, error))
+		return FALSE;
+	fu_device_add_instance_u8(device, "BONDING", self->bonding);
+
+	if (self->dynamic_ts.running_mode == 'M') {
+		self->running_bank = BANK_MASK_CODE;
+	} else if (self->flash_dump_location_bit) {
+		self->running_bank = BANK_SECOND;
+	} else {
+		self->running_bank = BANK_FIRST;
+	}
+
 	/* setup firmware parameters */
-	switch (self->isp_model) {
-	case ISP_MODEL_HUB_GL3523:
+	switch (self->chip.model) {
+	case ISP_MODEL_HUB_GL3521:
+		self->code_size = 0x5000;
+		self->fw_bank_addr[0] = 0x0000;
+		self->fw_data_total_count = 0x5000;
+		break;
+	case ISP_MODEL_HUB_GL3523: {
 		self->fw_bank_addr[0] = 0x0000;
 		self->fw_bank_addr[1] = 0x8000;
-		self->fw_data_total_count = 0x6000;
-		self->extend_size = GL3523_PUBLIC_KEY_LEN + GL3523_SIG_LEN;
-		if (self->isp_revision == 50) {
+
+		if (fu_device_has_private_flag(device, FU_GENESYS_USBHUB_FLAG_HAS_PUBLIC_KEY))
+			self->extend_size = GL3523_PUBLIC_KEY_LEN + GL3523_SIG_LEN;
+
+		if (self->chip.revision == 50) {
 			self->fw_data_total_count = 0x8000;
-			if (!fu_genesys_usbhub_device_get_fw_size(self, 0, error))
+			if (!fu_genesys_usbhub_device_get_code_size(self, 0, error))
 				return FALSE;
 		} else {
+			self->fw_data_total_count = 0x6000;
 			self->code_size = self->fw_data_total_count;
 		}
-		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_DUAL_IMAGE);
-		fu_device_set_firmware_size_max(device, 0x8000);
 		break;
+	}
 	case ISP_MODEL_HUB_GL3590:
-		if (!fu_genesys_usbhub_device_get_fw_size(self, 0, error))
+		if (!fu_genesys_usbhub_device_get_code_size(self, 0, error))
 			return FALSE;
 		self->fw_bank_addr[0] = 0x0000;
 		self->fw_bank_addr[1] = 0x10000;
-		self->fw_data_total_count = 0x8000;
-		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_DUAL_IMAGE);
-		fu_device_set_firmware_size_max(device, 0x10000);
+		self->fw_data_total_count = 0x10000;
 		break;
 	default:
 		break;
 	}
+	fu_device_set_firmware_size_max(device, self->fw_data_total_count + self->extend_size);
 
 	/* verify firmware integrity */
 	bufsz = self->fw_data_total_count + self->extend_size;
@@ -806,7 +983,7 @@ fu_genesys_usbhub_device_setup(FuDevice *device, GError **error)
 		return FALSE;
 	blob = g_bytes_new_take(g_steal_pointer(&buf), bufsz);
 	firmware = fu_genesys_usbhub_firmware_new();
-	if (!fu_firmware_parse(firmware, blob, FWUPD_INSTALL_FLAG_NONE, &error_local)) {
+	if (!fu_firmware_parse(firmware, blob, FWUPD_INSTALL_FLAG_NO_SEARCH, &error_local)) {
 		g_debug("ignoring firmware: %s", error_local->message);
 		self->fw_bank_vers[0] = 0;
 	} else {
@@ -837,7 +1014,7 @@ fu_genesys_usbhub_device_setup(FuDevice *device, GError **error)
 		firmware_dual = fu_genesys_usbhub_firmware_new();
 		if (!fu_firmware_parse(firmware_dual,
 				       blob_dual,
-				       FWUPD_INSTALL_FLAG_NONE,
+				       FWUPD_INSTALL_FLAG_NO_SEARCH,
 				       &error_local_dual)) {
 			g_debug("ignoring recovery firmware: %s", error_local_dual->message);
 			self->fw_bank_vers[1] = 0;
@@ -860,10 +1037,70 @@ fu_genesys_usbhub_device_setup(FuDevice *device, GError **error)
 		}
 
 		self->read_first_bank =
-		    (self->isp_model == ISP_MODEL_HUB_GL3523) && self->fw_bank_vers[0] != 0;
+		    (self->chip.model == ISP_MODEL_HUB_GL3523) && self->fw_bank_vers[0] != 0;
 		self->write_recovery_bank = address == self->fw_bank_addr[1];
 	}
 
+	/* has public key */
+	if (fu_device_has_private_flag(device, FU_GENESYS_USBHUB_FLAG_HAS_PUBLIC_KEY)) {
+		g_autofree gchar *guid = NULL;
+		if (!fu_memcpy_safe((guint8 *)&self->public_key,
+				    sizeof(self->public_key),
+				    0, /* dst */
+				    g_bytes_get_data(blob, NULL),
+				    g_bytes_get_size(blob),
+				    self->fw_data_total_count, /* src */
+				    sizeof(self->public_key),
+				    error))
+			return FALSE;
+		if (memcmp(&self->public_key.N, "N = ", 4) != 0 &&
+		    memcmp(&self->public_key.E, "E = ", 4) != 0) {
+			g_set_error_literal(error,
+					    FWUPD_ERROR,
+					    FWUPD_ERROR_SIGNATURE_INVALID,
+					    "invalid public-key");
+			return FALSE;
+		}
+		guid = fwupd_guid_hash_data((const guint8 *)&self->public_key,
+					    sizeof(self->public_key),
+					    FWUPD_GUID_FLAG_NONE);
+		fu_device_add_instance_strup(device, "PUBKEY", guid);
+	}
+
+	/* add specific product info */
+	ic_type = fu_strsafe((const gchar *)self->static_ts.mask_project_ic_type,
+			     sizeof(self->static_ts.mask_project_ic_type));
+	fu_device_add_instance_str(device, "IC", ic_type);
+
+	if (self->running_bank != BANK_MASK_CODE) {
+		const gchar *vendor = fwupd_device_get_vendor(FWUPD_DEVICE(device));
+		guint8 portnum = fu_genesys_tsdigit_value(self->dynamic_ts.ss_port_number) << 4 |
+				 fu_genesys_tsdigit_value(self->dynamic_ts.hs_port_number);
+		g_autofree gchar *guid = NULL;
+
+		guid = fwupd_guid_hash_data((const guint8 *)&self->vs_ts,
+					    sizeof(self->vs_ts),
+					    FWUPD_GUID_FLAG_NONE);
+		fu_device_add_instance_strup(device, "VENDOR", vendor);
+		fu_device_add_instance_u8(device, "PORTNUM", portnum);
+		fu_device_add_instance_strup(device, "VENDORSUP", guid);
+	}
+
+	fu_device_build_instance_id(device, NULL, "USB", "VID", "PID", "IC", NULL);
+	fu_device_build_instance_id(device, NULL, "USB", "VID", "PID", "IC", "BONDING", NULL);
+	fu_device_build_instance_id(device,
+				    NULL,
+				    "USB",
+				    "VID",
+				    "PID",
+				    "VENDOR",
+				    "IC",
+				    "BONDING",
+				    "PORTNUM",
+				    "VENDORSUP",
+				    NULL);
+	fu_device_build_instance_id(device, NULL, "USB", "VID", "PID", "PUBKEY", NULL);
+
 	/* have MStar scaler */
 	if (fu_device_has_private_flag(device, FU_GENESYS_USBHUB_FLAG_HAS_MSTAR_SCALER))
 		if (!fu_genesys_usbhub_device_mstar_scaler_setup(self, error))
@@ -872,6 +1109,7 @@ fu_genesys_usbhub_device_setup(FuDevice *device, GError **error)
 	/* success */
 	return TRUE;
 #else
+	/* failure */
 	g_set_error_literal(error,
 			    FWUPD_ERROR,
 			    FWUPD_ERROR_NOT_SUPPORTED,
@@ -885,20 +1123,20 @@ static void
 fu_genesys_usbhub_device_to_string(FuDevice *device, guint idt, GString *str)
 {
 	FuGenesysUsbhubDevice *self = FU_GENESYS_USBHUB_DEVICE(device);
-	fu_common_string_append_kx(str, idt, "FlashEraseDelay", self->flash_erase_delay);
-	fu_common_string_append_kx(str, idt, "FlashWriteDelay", self->flash_write_delay);
-	fu_common_string_append_kx(str, idt, "FlashBlockSize", self->flash_block_size);
-	fu_common_string_append_kx(str, idt, "FlashSectorSize", self->flash_sector_size);
-	fu_common_string_append_kx(str, idt, "FlashRwSize", self->flash_rw_size);
-	fu_common_string_append_kx(str, idt, "FwBank0Addr", self->fw_bank_addr[0]);
-	fu_common_string_append_kx(str, idt, "FwBank0Vers", self->fw_bank_vers[0]);
+	fu_string_append_kx(str, idt, "FlashEraseDelay", self->flash_erase_delay);
+	fu_string_append_kx(str, idt, "FlashWriteDelay", self->flash_write_delay);
+	fu_string_append_kx(str, idt, "FlashBlockSize", self->flash_block_size);
+	fu_string_append_kx(str, idt, "FlashSectorSize", self->flash_sector_size);
+	fu_string_append_kx(str, idt, "FlashRwSize", self->flash_rw_size);
+	fu_string_append_kx(str, idt, "FwBank0Addr", self->fw_bank_addr[0]);
+	fu_string_append_kx(str, idt, "FwBank0Vers", self->fw_bank_vers[0]);
 	if (fu_device_has_flag(device, FWUPD_DEVICE_FLAG_DUAL_IMAGE)) {
-		fu_common_string_append_kx(str, idt, "FwBank1Addr", self->fw_bank_addr[1]);
-		fu_common_string_append_kx(str, idt, "FwBank1Vers", self->fw_bank_vers[1]);
+		fu_string_append_kx(str, idt, "FwBank1Addr", self->fw_bank_addr[1]);
+		fu_string_append_kx(str, idt, "FwBank1Vers", self->fw_bank_vers[1]);
 	}
-	fu_common_string_append_kx(str, idt, "CodeSize", self->code_size);
-	fu_common_string_append_kx(str, idt, "FwDataTotalCount", self->fw_data_total_count);
-	fu_common_string_append_kx(str, idt, "ExtendSize", self->extend_size);
+	fu_string_append_kx(str, idt, "CodeSize", self->code_size);
+	fu_string_append_kx(str, idt, "FwDataTotalCount", self->fw_data_total_count);
+	fu_string_append_kx(str, idt, "ExtendSize", self->extend_size);
 }
 
 static FuFirmware *
@@ -907,12 +1145,32 @@ fu_genesys_usbhub_device_prepare_firmware(FuDevice *device,
 					  FwupdInstallFlags flags,
 					  GError **error)
 {
+	FuGenesysUsbhubDevice *self = FU_GENESYS_USBHUB_DEVICE(device);
 	g_autoptr(FuFirmware) firmware = fu_genesys_usbhub_firmware_new();
 
 	/* parse firmware */
 	if (!fu_firmware_parse(firmware, fw, flags, error))
 		return NULL;
 
+	/* has public-key */
+	if (g_bytes_get_size(fw) >= fu_firmware_get_size(firmware) + sizeof(self->public_key)) {
+		gsize bufsz = 0;
+		const guint8 *buf = g_bytes_get_data(fw, &bufsz);
+
+		if (g_getenv("FWUPD_GENESYS_USBHUB_VERBOSE") != NULL)
+			fu_dump_raw(G_LOG_DOMAIN, "PublicKey", buf, bufsz);
+		if (memcmp(buf + fu_firmware_get_size(firmware),
+			   &self->public_key,
+			   sizeof(self->public_key)) != 0 &&
+		    (flags & FWUPD_INSTALL_FLAG_FORCE) == 0) {
+			g_set_error_literal(error,
+					    FWUPD_ERROR,
+					    FWUPD_ERROR_SIGNATURE_INVALID,
+					    "mismatch public-key");
+			return NULL;
+		}
+	}
+
 	/* check size */
 	if (g_bytes_get_size(fw) > fu_device_get_firmware_size_max(device)) {
 		g_set_error(error,
@@ -924,6 +1182,7 @@ fu_genesys_usbhub_device_prepare_firmware(FuDevice *device,
 		return NULL;
 	}
 
+	/* success */
 	return fu_firmware_new_from_bytes(fw);
 }
 
@@ -971,6 +1230,7 @@ fu_genesys_usbhub_device_erase_flash(FuGenesysUsbhubDevice *self,
 			return FALSE;
 		}
 
+		/* 8s */
 		if (!fu_device_retry(FU_DEVICE(self),
 				     fu_genesys_usbhub_device_wait_flash_status_register_cb,
 				     self->flash_erase_delay / 30,
@@ -1031,6 +1291,7 @@ fu_genesys_usbhub_device_write_flash(FuGenesysUsbhubDevice *self,
 			return FALSE;
 		}
 
+		/* 5s */
 		if (!fu_device_retry(FU_DEVICE(self),
 				     fu_genesys_usbhub_device_wait_flash_status_register_cb,
 				     self->flash_write_delay / 30,
@@ -1059,10 +1320,10 @@ fu_genesys_usbhub_device_write_recovery(FuGenesysUsbhubDevice *self,
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
 	if (self->read_first_bank)
-		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 20);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 30);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 50);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 20);
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_READ, 20, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 30, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 50, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 20, NULL);
 
 	/* reuse fw on first bank for GL3523 */
 	if (self->read_first_bank) {
@@ -1119,7 +1380,7 @@ fu_genesys_usbhub_device_write_recovery(FuGenesysUsbhubDevice *self,
 						 fu_progress_get_child(progress),
 						 error))
 		return FALSE;
-	if (!fu_common_bytes_compare_raw(buf_verify, bufsz, buf, bufsz, error))
+	if (!fu_memcmp_safe(buf_verify, bufsz, buf, bufsz, error))
 		return FALSE;
 	fu_progress_step_done(progress);
 
@@ -1146,13 +1407,13 @@ fu_genesys_usbhub_device_write_firmware(FuDevice *device,
 	fu_progress_set_id(progress, G_STRLOC);
 	if (self->write_recovery_bank) {
 		if (self->read_first_bank)
-			fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 120);
+			fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 120, NULL);
 		else
-			fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 100);
+			fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 100, NULL);
 	}
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 30);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 50);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 20);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_ERASE, 30, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 50, NULL);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_VERIFY, 20, NULL);
 
 	/* write fw to recovery bank first? */
 	if (self->write_recovery_bank) {
@@ -1191,11 +1452,11 @@ fu_genesys_usbhub_device_write_firmware(FuDevice *device,
 						 fu_progress_get_child(progress),
 						 error))
 		return FALSE;
-	if (!fu_common_bytes_compare_raw(buf_verify,
-					 g_bytes_get_size(blob),
-					 g_bytes_get_data(blob, NULL),
-					 g_bytes_get_size(blob),
-					 error))
+	if (!fu_memcmp_safe(buf_verify,
+			    g_bytes_get_size(blob),
+			    g_bytes_get_data(blob, NULL),
+			    g_bytes_get_size(blob),
+			    error))
 		return FALSE;
 	fu_progress_step_done(progress);
 
@@ -1210,15 +1471,15 @@ fu_genesys_usbhub_device_set_progress(FuDevice *device, FuProgress *progress)
 
 	fu_progress_set_id(progress, G_STRLOC);
 	if (self->write_recovery_bank) {
-		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0); /* detach */
-		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 30);	/* write */
-		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0); /* attach */
-		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 70);	/* reload */
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "detach");
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 30, "write");
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "attach");
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 70, "reload");
 	} else {
-		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0); /* detach */
-		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 15);	/* write */
-		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0); /* attach */
-		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 85);	/* reload */
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "detach");
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 15, "write");
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "attach");
+		fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 85, "reload");
 	}
 }
 
@@ -1232,7 +1493,7 @@ fu_genesys_usbhub_device_set_quirk_kv(FuDevice *device,
 	guint64 tmp;
 
 	if (g_strcmp0(key, "GenesysUsbhubDeviceTransferSize") == 0) {
-		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT32, error))
+		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT32, error))
 			return FALSE;
 		self->flash_rw_size = tmp;
 
@@ -1240,7 +1501,7 @@ fu_genesys_usbhub_device_set_quirk_kv(FuDevice *device,
 		return TRUE;
 	}
 	if (g_strcmp0(key, "GenesysUsbhubSwitchRequest") == 0) {
-		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT8, error))
+		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT8, error))
 			return FALSE;
 		self->vcs.req_switch = tmp;
 
@@ -1248,7 +1509,7 @@ fu_genesys_usbhub_device_set_quirk_kv(FuDevice *device,
 		return TRUE;
 	}
 	if (g_strcmp0(key, "GenesysUsbhubReadRequest") == 0) {
-		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT8, error))
+		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT8, error))
 			return FALSE;
 		self->vcs.req_read = tmp;
 
@@ -1256,7 +1517,7 @@ fu_genesys_usbhub_device_set_quirk_kv(FuDevice *device,
 		return TRUE;
 	}
 	if (g_strcmp0(key, "GenesysUsbhubWriteRequest") == 0) {
-		if (!fu_common_strtoull_full(value, &tmp, 0, G_MAXUINT8, error))
+		if (!fu_strtoull(value, &tmp, 0, G_MAXUINT8, error))
 			return FALSE;
 		self->vcs.req_write = tmp;
 
@@ -1264,6 +1525,7 @@ fu_genesys_usbhub_device_set_quirk_kv(FuDevice *device,
 		return TRUE;
 	}
 
+	/* failure */
 	g_set_error_literal(error,
 			    FWUPD_ERROR,
 			    FWUPD_ERROR_NOT_SUPPORTED,
@@ -1276,17 +1538,23 @@ fu_genesys_usbhub_device_init(FuGenesysUsbhubDevice *self)
 {
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
+	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE);
 	fu_device_add_protocol(FU_DEVICE(self), "com.genesys.usbhub");
-	fu_device_retry_set_delay(FU_DEVICE(self), 30);	   /* ms */
-	fu_device_set_remove_delay(FU_DEVICE(self), 5000); /* ms */
+	fu_device_retry_set_delay(FU_DEVICE(self), 30);	   /* 30ms */
+	fu_device_set_remove_delay(FU_DEVICE(self), 5000); /* 5s */
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_GENESYS_USBHUB_FLAG_HAS_MSTAR_SCALER,
 					"has-mstar-scaler");
+	fu_device_register_private_flag(FU_DEVICE(self),
+					FU_GENESYS_USBHUB_FLAG_HAS_PUBLIC_KEY,
+					"has-public-key");
+	fu_device_set_install_duration(FU_DEVICE(self), 9); /* 9 s */
+
 	self->vcs.req_switch = GENESYS_USBHUB_GL_HUB_SWITCH;
 	self->vcs.req_read = GENESYS_USBHUB_GL_HUB_READ;
 	self->vcs.req_write = GENESYS_USBHUB_GL_HUB_WRITE;
-	self->flash_erase_delay = 8000;
-	self->flash_write_delay = 500;
+	self->flash_erase_delay = 8000;	  /* 8s */
+	self->flash_write_delay = 500;	  /* 500ms */
 	self->flash_block_size = 0x10000; /* 64KB */
 	self->flash_sector_size = 0x1000; /* 4KB */
 	self->flash_rw_size = 0x40;	  /* 64B */
