@@ -59,6 +59,8 @@
 /* Default length for NVM READ */
 #define NVM_READ_LENGTH 0x224
 
+#define FU_INTEL_USB4_DEVICE_REMOVE_DELAY 60000 /* ms */
+
 struct mbox_regx {
 	guint16 opcode;
 	guint8 rsvd;
@@ -276,7 +278,7 @@ fu_intel_usb4_device_operation(FuDevice *device, guint16 opcode, guint8 *metadat
 						   g_steal_pointer(&error_local),
 						   "maximum tries exceeded: ");
 		}
-		g_usleep((gulong)10000);
+		fu_device_sleep(device, 10); /* ms */
 	}
 	return FALSE;
 }
@@ -545,6 +547,16 @@ fu_intel_usb4_device_to_string(FuDevice *device, guint idt, GString *str)
 	fu_string_append_kx(str, idt, "NvmDeviceId", self->nvm_device_id);
 }
 
+static void
+fu_thunderbolt_device_set_progress(FuDevice *self, FuProgress *progress)
+{
+	fu_progress_set_id(progress, G_STRLOC);
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 0, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 78, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 22, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 0, "reload");
+}
+
 static void
 fu_intel_usb4_device_init(FuIntelUsb4Device *self)
 {
@@ -555,6 +567,9 @@ fu_intel_usb4_device_init(FuIntelUsb4Device *self)
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD);
 	fu_device_set_version_format(FU_DEVICE(self), FWUPD_VERSION_FORMAT_PAIR);
 	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_INHERIT_ACTIVATION);
+	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_MD_SET_NAME_CATEGORY);
+	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_ONLY_WAIT_FOR_REPLUG);
+	fu_device_set_remove_delay(FU_DEVICE(self), FU_INTEL_USB4_DEVICE_REMOVE_DELAY);
 }
 
 static void
@@ -566,4 +581,5 @@ fu_intel_usb4_device_class_init(FuIntelUsb4DeviceClass *klass)
 	klass_device->prepare_firmware = fu_intel_usb4_device_prepare_firmware;
 	klass_device->write_firmware = fu_intel_usb4_device_write_firmware;
 	klass_device->activate = fu_intel_usb4_device_activate;
+	klass_device->set_progress = fu_thunderbolt_device_set_progress;
 }
