@@ -321,7 +321,6 @@ fu_mbim_qdu_updater_file_open_ready(MbimDevice *device, GAsyncResult *res, gpoin
 {
 	WriteContext *ctx = user_data;
 	guint32 out_max_transfer_size;
-	guint32 total_sending_numbers = 0;
 	FuChunk *chk = NULL;
 	g_autoptr(MbimMessage) request = NULL;
 	g_autoptr(MbimMessage) response = NULL;
@@ -344,10 +343,6 @@ fu_mbim_qdu_updater_file_open_ready(MbimDevice *device, GAsyncResult *res, gpoin
 		return;
 	}
 
-	total_sending_numbers = g_bytes_get_size(ctx->blob) / out_max_transfer_size;
-	if (g_bytes_get_size(ctx->blob) % out_max_transfer_size != 0)
-		total_sending_numbers++;
-
 	ctx->chunks = fu_chunk_array_new_from_bytes(ctx->blob,
 						    0x00, /* start addr */
 						    0x00, /* page_sz */
@@ -510,10 +505,10 @@ fu_mbim_qdu_updater_class_init(FuMbimQduUpdaterClass *klass)
 }
 
 FuMbimQduUpdater *
-fu_mbim_qdu_updater_new(const gchar *path)
+fu_mbim_qdu_updater_new(const gchar *mbim_port)
 {
 	FuMbimQduUpdater *self = g_object_new(FU_TYPE_MBIM_QDU_UPDATER, NULL);
-	self->mbim_port = g_strdup(path);
+	self->mbim_port = g_strdup(mbim_port);
 	return self;
 }
 
