@@ -199,7 +199,7 @@ fu_nordic_hid_cfg_channel_receive(FuNordicHidCfgChannel *self,
 		    (recv_msg->recipient | recv_msg->event_id | recv_msg->status |
 		     recv_msg->data_len))
 			break;
-		g_usleep(i * 50);
+		fu_device_sleep(FU_DEVICE(self), 1); /* ms */
 	}
 	if (!fu_memcpy_safe(buf,
 			    bufsz,
@@ -464,7 +464,7 @@ fu_nordic_hid_cfg_channel_add_peers(FuNordicHidCfgChannel *self, GError **error)
 			g_debug("detected peer: 0x%02x", res->data[8]);
 
 		peer = fu_nordic_hid_cfg_channel_new(res->data[8]);
-		/* prohibit to close close parent's communication descriptor */
+		/* prohibit to close parent's communication descriptor */
 		fu_device_add_internal_flag(FU_DEVICE(peer),
 					    FU_DEVICE_INTERNAL_FLAG_USE_PARENT_FOR_OPEN);
 		/* probe&setup are the part of adding child */
@@ -522,7 +522,7 @@ fu_nordic_hid_cfg_channel_get_bl_name(FuNordicHidCfgChannel *self, GError **erro
 			    error,
 			    G_IO_ERROR,
 			    G_IO_ERROR_INVALID_DATA,
-			    "bootloader in qiurk file is '%s' while the board is supporting '%s'",
+			    "bootloader in quirk file is '%s' while the board is supporting '%s'",
 			    self->bl_name,
 			    g_strndup((const gchar *)res->data, res->data_len));
 			return FALSE;
@@ -780,7 +780,7 @@ fu_nordic_hid_cfg_channel_dfu_sync_cb(FuDevice *device, gpointer user_data, GErr
 			return FALSE;
 
 		recv_msg->report_id = HID_REPORT_ID;
-		g_usleep(i * 5000);
+		fu_device_sleep(device, 2); /* ms */
 		if (!fu_nordic_hid_cfg_channel_receive(self,
 						       (guint8 *)recv_msg,
 						       sizeof(*recv_msg),
