@@ -214,7 +214,7 @@ fu_nvme_device_parse_cns(FuNvmeDevice *self, const guint8 *buf, gsize sz, GError
 		return FALSE;
 	}
 
-	/* get sanitiezed string from CNS -- see the following doc for offsets:
+	/* get sanitized string from CNS -- see the following doc for offsets:
 	 * NVM-Express-1_3c-2018.05.24-Ratified.pdf */
 	sn = fu_nvme_device_get_string_safe(buf, 4, 23);
 	if (sn != NULL)
@@ -348,6 +348,10 @@ fu_nvme_device_setup(FuDevice *device, GError **error)
 	if (!fu_nvme_device_parse_cns(self, buf, sizeof(buf), error))
 		return FALSE;
 
+	/* add one extra instance ID so that we can match bad firmware */
+	fu_device_add_instance_strsafe(device, "VER", fu_device_get_version(device));
+	fu_device_build_instance_id_quirk(device, NULL, "NVME", "VEN", "DEV", "VER", NULL);
+
 	/* success */
 	return TRUE;
 }
