@@ -6,7 +6,7 @@
 
 #include "config.h"
 
-#include <fwupd.h>
+#include <fwupdplugin.h>
 
 #include "fu-context-private.h"
 #include "fu-device-private.h"
@@ -90,11 +90,15 @@ fu_nvme_cns_all_func(void)
 int
 main(int argc, char **argv)
 {
+	g_autofree gchar *testdatadir = NULL;
 	g_test_init(&argc, &argv, NULL);
 
 	/* only critical and error are fatal */
 	g_log_set_fatal_mask(NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
 
+	testdatadir = g_test_build_filename(G_TEST_DIST, "tests", NULL);
+	(void)g_setenv("FWUPD_SYSFSFWATTRIBDIR", testdatadir, TRUE);
+
 	/* tests go here */
 	g_test_add_func("/fwupd/cns", fu_nvme_cns_func);
 	g_test_add_func("/fwupd/cns{all}", fu_nvme_cns_all_func);
