@@ -19,10 +19,6 @@ fu_optionrom_device_probe(FuDevice *device, GError **error)
 {
 	g_autofree gchar *fn = NULL;
 
-	/* FuUdevDevice->probe */
-	if (!FU_DEVICE_CLASS(fu_optionrom_device_parent_class)->probe(device, error))
-		return FALSE;
-
 	/* does the device even have ROM? */
 	fn = g_build_filename(fu_udev_device_get_sysfs_path(FU_UDEV_DEVICE(device)), "rom", NULL);
 	if (!g_file_test(fn, G_FILE_TEST_EXISTS)) {
@@ -33,6 +29,10 @@ fu_optionrom_device_probe(FuDevice *device, GError **error)
 		return FALSE;
 	}
 
+	/* FuUdevDevice->probe -- needed by FU_UDEV_DEVICE_FLAG_VENDOR_FROM_PARENT */
+	if (!FU_DEVICE_CLASS(fu_optionrom_device_parent_class)->probe(device, error))
+		return FALSE;
+
 	/* set the physical ID */
 	return fu_udev_device_set_physical_id(FU_UDEV_DEVICE(device), "pci", error);
 }
@@ -117,7 +117,6 @@ static void
 fu_optionrom_device_init(FuOptionromDevice *self)
 {
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_INTERNAL);
-	fu_device_add_icon(FU_DEVICE(self), "audio-card");
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_CAN_VERIFY_IMAGE);
 	fu_device_set_logical_id(FU_DEVICE(self), "rom");
 	fu_udev_device_set_flags(FU_UDEV_DEVICE(self),
