@@ -391,7 +391,7 @@ fu_parade_lspcon_flash_wait_ready(FuParadeLspconDevice *self, GError **error)
 
 		/* flash operations generally take between 1ms and 4s; polling
 		 * at 1000 Hz is still quite responsive and not overly slow */
-		g_usleep(G_TIME_SPAN_MILLISECOND);
+		fu_device_sleep(FU_DEVICE(self), 1); /* ms */
 	} while (g_timer_elapsed(timer, NULL) <= 10.0);
 
 	g_set_error_literal(error,
@@ -431,7 +431,7 @@ fu_parade_lspcon_flash_write(FuParadeLspconDevice *self,
 	/* reset clt2SPI, required before write */
 	if (!fu_parade_lspcon_write_register(self, REG_ADDR_CLT2SPI, 0x20, error))
 		return FALSE;
-	g_usleep(100 * G_TIME_SPAN_MILLISECOND);
+	fu_device_sleep(FU_DEVICE(self), 100); /* ms */
 	if (!fu_parade_lspcon_write_register(self, REG_ADDR_CLT2SPI, 0, error))
 		return FALSE;
 
@@ -454,7 +454,6 @@ fu_parade_lspcon_flash_write(FuParadeLspconDevice *self,
 
 		/* page write is prefixed with an offset:
 		 * we always start from offset 0 */
-		write_data[0] = 0;
 		if (!fu_memcpy_safe(write_data,
 				    sizeof(write_data),
 				    1,
@@ -534,9 +533,9 @@ fu_parade_lspcon_device_reload(FuDevice *device, GError **error)
 	guint8 version_buf[2] = {0x0};
 	g_autofree gchar *version = NULL;
 	g_autofree gchar *oui_string = NULL;
+	g_autolist(GUdevDevice) aux_devices = NULL;
 	g_autoptr(FuDeviceLocker) aux_device_locker = NULL;
 	g_autoptr(FuUdevDevice) aux_device = NULL;
-	g_autoptr(GList) aux_devices = NULL;
 	g_autoptr(GUdevClient) udev_client = g_udev_client_new(NULL);
 	g_autoptr(GUdevEnumerator) enumerator = g_udev_enumerator_new(udev_client);
 
@@ -582,8 +581,7 @@ fu_parade_lspcon_device_reload(FuDevice *device, GError **error)
 			    self->aux_device_name);
 		return FALSE;
 	}
-	aux_device =
-	    fu_udev_device_new(fu_device_get_context(device), g_steal_pointer(&aux_devices->data));
+	aux_device = fu_udev_device_new(fu_device_get_context(device), aux_devices->data);
 	g_debug("using aux dev %s", fu_udev_device_get_sysfs_path(aux_device));
 
 	/* the following open() requires the device have IDs set */
