@@ -18,7 +18,7 @@
 #include "fu-pxi-receiver-device.h"
 #include "fu-pxi-wireless-device.h"
 
-#define FU_PXI_WIRELESS_DEV_DELAY_US 50000
+#define FU_PXI_WIRELESS_DEV_DELAY_MS 50
 
 struct _FuPxiWirelessDevice {
 	FuDevice parent_instance;
@@ -114,7 +114,7 @@ fu_pxi_wireless_device_get_cmd_response(FuPxiWirelessDevice *device,
 		memset(buf, 0, bufsz);
 		buf[0] = PXI_HID_WIRELESS_DEV_OTA_REPORT_ID;
 
-		g_usleep(5 * 1000);
+		fu_device_sleep(FU_DEVICE(device), 5); /* ms */
 
 		if (!fu_pxi_wireless_device_get_feature(FU_DEVICE(parent), buf, bufsz, error))
 			return FALSE;
@@ -253,7 +253,7 @@ fu_pxi_wireless_device_fw_object_create(FuDevice *device, FuChunk *chk, GError *
 		return FALSE;
 
 	/* delay for wireless module device get command response*/
-	g_usleep(FU_PXI_WIRELESS_DEV_DELAY_US);
+	fu_device_sleep(FU_DEVICE(self), FU_PXI_WIRELESS_DEV_DELAY_MS);
 
 	return fu_pxi_wireless_device_set_feature(FU_DEVICE(parent),
 						  receiver_cmd->data,
@@ -300,7 +300,7 @@ fu_pxi_wireless_device_write_payload(FuDevice *device, FuChunk *chk, GError **er
 		return FALSE;
 
 	/* delay for wireless module device get command response*/
-	g_usleep(FU_PXI_WIRELESS_DEV_DELAY_US);
+	fu_device_sleep(device, FU_PXI_WIRELESS_DEV_DELAY_MS);
 
 	if (!fu_pxi_wireless_device_get_cmd_response(self, buf, sizeof(buf), error))
 		return FALSE;
@@ -378,9 +378,8 @@ fu_pxi_wireless_device_fw_ota_init_new(FuDevice *device, gsize bufsz, GError **e
 		return FALSE;
 
 	fu_byte_array_append_uint8(ota_cmd, 0X06); /* ota init new command length */
-	fu_byte_array_append_uint8(
-	    ota_cmd,
-	    FU_PXI_DEVICE_CMD_FW_OTA_INIT_NEW);			      /* ota ota init new op code */
+	fu_byte_array_append_uint8(ota_cmd,
+				   FU_PXI_DEVICE_CMD_FW_OTA_INIT_NEW); /* ota init new op code */
 	fu_byte_array_append_uint32(ota_cmd, bufsz, G_LITTLE_ENDIAN); /* fw size */
 	fu_byte_array_append_uint8(ota_cmd, 0x0);		      /* ota setting */
 	g_byte_array_append(ota_cmd, fw_version, sizeof(fw_version)); /* ota version */
@@ -438,7 +437,7 @@ fu_pxi_wireless_device_fw_ota_ini_new_check(FuDevice *device, GError **error)
 		return FALSE;
 
 	/* delay for wireless module device get command response*/
-	g_usleep(FU_PXI_WIRELESS_DEV_DELAY_US);
+	fu_device_sleep(device, FU_PXI_WIRELESS_DEV_DELAY_MS);
 
 	if (!fu_pxi_wireless_device_get_cmd_response(self, buf, sizeof(buf), error))
 		return FALSE;
@@ -625,7 +624,7 @@ fu_pxi_wireless_device_write_firmware(FuDevice *device,
 	fu_progress_step_done(progress);
 
 	/* send device reset command */
-	g_usleep(FU_PXI_WIRELESS_DEV_DELAY_US);
+	fu_device_sleep(device, FU_PXI_WIRELESS_DEV_DELAY_MS);
 	if (!fu_pxi_wireless_device_reset(device, error))
 		return FALSE;
 	fu_progress_step_done(progress);
