@@ -37,20 +37,20 @@
 #define IPMI_PASSWORD_TEST_PASSWORD 0x03
 
 /* these are not provided in ipmi_msgdefs.h */
-#define IPMI_INVALID_COMMAND_ON_LUN_ERR	    0xC2
-#define IPMI_OUT_OF_SPACE_ERR		    0xC4
-#define IPMI_CANCELLED_OR_INVALID_ERR	    0xC5
-#define IPMI_OUT_OF_RANGE_ERR		    0xC9
-#define IPMI_CANNOT_RETURN_DATA_ERR	    0xCA
-#define IPMI_NOT_FOUND_ERR		    0xCB
-#define IPMI_INVALID_DATA_FIELD_ERR	    0xCC
-#define IPMI_COMMAND_ILLEGAL_ERR	    0xCD
-#define IPMI_RESPONSE_NOT_PROVIDED_ERR	    0xCE
-#define IPMI_DUPLICATED_REQUEST_ERR	    0xCF
-#define IPMI_SDR_IN_UPDATE_MODE_ERR	    0xD0
-#define IPMI_DESTINATION_UNAVAILABLE_ERR    0xD3
-#define IPMI_INSUFFICIENT_PRIVILEGE_ERR	    0xD4
-#define IPMI_COMMAND_DISABLED_ERR	    0xD6
+#define IPMI_INVALID_COMMAND_ON_LUN_ERR	 0xC2
+#define IPMI_OUT_OF_SPACE_ERR		 0xC4
+#define IPMI_CANCELLED_OR_INVALID_ERR	 0xC5
+#define IPMI_OUT_OF_RANGE_ERR		 0xC9
+#define IPMI_CANNOT_RETURN_DATA_ERR	 0xCA
+#define IPMI_NOT_FOUND_ERR		 0xCB
+#define IPMI_INVALID_DATA_FIELD_ERR	 0xCC
+#define IPMI_COMMAND_ILLEGAL_ERR	 0xCD
+#define IPMI_RESPONSE_NOT_PROVIDED_ERR	 0xCE
+#define IPMI_DUPLICATED_REQUEST_ERR	 0xCF
+#define IPMI_SDR_IN_UPDATE_MODE_ERR	 0xD0
+#define IPMI_DESTINATION_UNAVAILABLE_ERR 0xD3
+#define IPMI_INSUFFICIENT_PRIVILEGE_ERR	 0xD4
+#define IPMI_COMMAND_DISABLED_ERR	 0xD6
 
 #ifndef IPMI_DEVICE_IN_UPDATE_MODE_ERR
 #define IPMI_DEVICE_IN_UPDATE_MODE_ERR 0xD1
@@ -69,13 +69,15 @@ struct _FuIpmiDevice {
 
 G_DEFINE_TYPE(FuIpmiDevice, fu_ipmi_device, FU_TYPE_UDEV_DEVICE)
 
+#define FU_IPMI_DEVICE_IOCTL_TIMEOUT 5000 /* ms */
+
 static void
 fu_ipmi_device_to_string(FuDevice *device, guint idt, GString *str)
 {
 	FuIpmiDevice *self = FU_IPMI_DEVICE(device);
-	fu_common_string_append_kx(str, idt, "DeviceId", self->device_id);
-	fu_common_string_append_kx(str, idt, "DeviceRev", self->device_rev);
-	fu_common_string_append_kx(str, idt, "VersionIpmi", self->version_ipmi);
+	fu_string_append_kx(str, idt, "DeviceId", self->device_id);
+	fu_string_append_kx(str, idt, "DeviceRev", self->device_rev);
+	fu_string_append_kx(str, idt, "VersionIpmi", self->version_ipmi);
 }
 
 static gboolean
@@ -99,11 +101,12 @@ fu_ipmi_device_send(FuIpmiDevice *self,
 	    .msg.cmd = cmd,
 	};
 	if (g_getenv("FWUPD_REDFISH_VERBOSE") != NULL && buf2 != NULL)
-		fu_common_dump_raw(G_LOG_DOMAIN, "ipmi-send", buf2, bufsz);
+		fu_dump_raw(G_LOG_DOMAIN, "ipmi-send", buf2, bufsz);
 	return fu_udev_device_ioctl(FU_UDEV_DEVICE(self),
 				    IPMICTL_SEND_COMMAND,
 				    (guint8 *)&req,
 				    NULL,
+				    FU_IPMI_DEVICE_IOCTL_TIMEOUT,
 				    error);
 }
 
@@ -128,10 +131,11 @@ fu_ipmi_device_recv(FuIpmiDevice *self,
 				  IPMICTL_RECEIVE_MSG_TRUNC,
 				  (guint8 *)&recv,
 				  NULL,
+				  FU_IPMI_DEVICE_IOCTL_TIMEOUT,
 				  error))
 		return FALSE;
 	if (g_getenv("FWUPD_REDFISH_VERBOSE") != NULL && buf != NULL)
-		fu_common_dump_raw(G_LOG_DOMAIN, "ipmi-recv", buf, bufsz);
+		fu_dump_raw(G_LOG_DOMAIN, "ipmi-recv", buf, bufsz);
 	if (netfn != NULL)
 		*netfn = recv.msg.netfn;
 	if (cmd != NULL)
@@ -520,7 +524,7 @@ fu_ipmi_device_get_user_password(FuIpmiDevice *self, guint8 user_id, GError **er
 	}
 
 	/* success */
-	return fu_common_strsafe((const gchar *)resp, resp_len);
+	return fu_strsafe((const gchar *)resp, resp_len);
 }
 
 gboolean
