@@ -16,6 +16,7 @@
 #include "fu-redfish-multipart-device.h"
 #include "fu-redfish-request.h"
 #include "fu-redfish-smbios.h"
+#include "fu-redfish-smc-device.h"
 
 struct _FuRedfishBackend {
 	FuBackend parent_instance;
@@ -23,6 +24,9 @@ struct _FuRedfishBackend {
 	gchar *username;
 	gchar *password;
 	guint port;
+	gchar *vendor;
+	gchar *version;
+	gchar *uuid;
 	gchar *update_uri_path;
 	gchar *push_uri_path;
 	gboolean use_https;
@@ -36,6 +40,24 @@ struct _FuRedfishBackend {
 
 G_DEFINE_TYPE(FuRedfishBackend, fu_redfish_backend, FU_TYPE_BACKEND)
 
+const gchar *
+fu_redfish_backend_get_vendor(FuRedfishBackend *self)
+{
+	return self->vendor;
+}
+
+const gchar *
+fu_redfish_backend_get_version(FuRedfishBackend *self)
+{
+	return self->version;
+}
+
+const gchar *
+fu_redfish_backend_get_uuid(FuRedfishBackend *self)
+{
+	return self->uuid;
+}
+
 FuRedfishRequest *
 fu_redfish_backend_request_new(FuRedfishBackend *self)
 {
@@ -221,6 +243,24 @@ fu_redfish_backend_set_push_uri_path(FuRedfishBackend *self, const gchar *push_u
 	self->push_uri_path = g_strdup(push_uri_path);
 }
 
+static gboolean
+fu_redfish_backend_has_smc_update_path(JsonObject *update_svc)
+{
+	JsonObject *tmp_obj;
+	const gchar *tmp_str;
+
+	if (!json_object_has_member(update_svc, "Actions"))
+		return FALSE;
+	tmp_obj = json_object_get_object_member(update_svc, "Actions");
+	if (tmp_obj == NULL || !json_object_has_member(tmp_obj, "#UpdateService.StartUpdate"))
+		return FALSE;
+	tmp_obj = json_object_get_object_member(tmp_obj, "#UpdateService.StartUpdate");
+	if (tmp_obj == NULL || !json_object_has_member(tmp_obj, "target"))
+		return FALSE;
+	tmp_str = json_object_get_string_member(tmp_obj, "target");
+	return g_str_equal(tmp_str, "/redfish/v1/UpdateService/Actions/UpdateService.StartUpdate");
+}
+
 static gboolean
 fu_redfish_backend_coldplug(FuBackend *backend, FuProgress *progress, GError **error)
 {
@@ -250,10 +290,15 @@ fu_redfish_backend_coldplug(FuBackend *backend, FuProgress *progress, GError **e
 			return FALSE;
 		}
 	}
-	if (json_object_has_member(json_obj, "MultipartHttpPushUri")) {
+	if (self->push_uri_path == NULL &&
+	    json_object_has_member(json_obj, "MultipartHttpPushUri")) {
 		const gchar *tmp = json_object_get_string_member(json_obj, "MultipartHttpPushUri");
 		if (tmp != NULL) {
-			self->device_gtype = FU_TYPE_REDFISH_MULTIPART_DEVICE;
+			if (fu_redfish_backend_has_smc_update_path(json_obj)) {
+				self->device_gtype = FU_TYPE_REDFISH_SMC_DEVICE;
+			} else {
+				self->device_gtype = FU_TYPE_REDFISH_MULTIPART_DEVICE;
+			}
 			fu_redfish_backend_set_push_uri_path(self, tmp);
 		}
 	}
@@ -310,7 +355,6 @@ fu_redfish_backend_setup(FuBackend *backend, FuProgress *progress, GError **erro
 	JsonObject *json_update_service = NULL;
 	const gchar *data_id;
 	const gchar *version = NULL;
-	const gchar *uuid = NULL;
 	g_autoptr(FuRedfishRequest) request = fu_redfish_backend_request_new(self);
 
 	/* sanity check */
@@ -335,10 +379,18 @@ fu_redfish_backend_setup(FuBackend *backend, FuProgress *progress, GError **erro
 	} else if (json_object_has_member(json_obj, "RedfishVersion")) {
 		version = json_object_get_string_member(json_obj, "RedfishVersion");
 	}
-	if (json_object_has_member(json_obj, "UUID"))
-		uuid = json_object_get_string_member(json_obj, "UUID");
-	g_debug("Version: %s", version);
-	g_debug("UUID: %s", uuid);
+	if (version != NULL) {
+		g_free(self->version);
+		self->version = g_strdup(version);
+	}
+	if (json_object_has_member(json_obj, "UUID")) {
+		g_free(self->uuid);
+		self->uuid = g_strdup(json_object_get_string_member(json_obj, "UUID"));
+	}
+	if (json_object_has_member(json_obj, "Vendor")) {
+		g_free(self->vendor);
+		self->vendor = g_strdup(json_object_get_string_member(json_obj, "Vendor"));
+	}
 
 	if (json_object_has_member(json_obj, "UpdateService"))
 		json_update_service = json_object_get_object_member(json_obj, "UpdateService");
@@ -453,6 +505,9 @@ fu_redfish_backend_finalize(GObject *object)
 	g_free(self->hostname);
 	g_free(self->username);
 	g_free(self->password);
+	g_free(self->vendor);
+	g_free(self->version);
+	g_free(self->uuid);
 	G_OBJECT_CLASS(fu_redfish_backend_parent_class)->finalize(object);
 }
 
