@@ -360,6 +360,26 @@ fu_redfish_device_set_vendor(FuRedfishDevice *self, const gchar *vendor)
 	fu_device_add_vendor_id(FU_DEVICE(self), vendor_id);
 }
 
+static void
+fu_redfish_backend_smc_license_check(FuDevice *device)
+{
+	FuRedfishDevice *self = FU_REDFISH_DEVICE(device);
+	FuRedfishBackend *backend = fu_redfish_device_get_backend(self);
+	g_autoptr(FuRedfishRequest) request = fu_redfish_backend_request_new(backend);
+	g_autoptr(GError) error_local = NULL;
+
+	/* see if we don't get an license error */
+	if (!fu_redfish_request_perform(request,
+					fu_redfish_backend_get_push_uri_path(backend),
+					FU_REDFISH_REQUEST_PERFORM_FLAG_LOAD_JSON,
+					&error_local)) {
+		if (g_error_matches(error_local, FWUPD_ERROR, FWUPD_ERROR_NOT_SUPPORTED))
+			fu_device_add_problem(device, FWUPD_DEVICE_PROBLEM_MISSING_LICENSE);
+		else
+			g_debug("supermicro license check returned %s\n", error_local->message);
+	}
+}
+
 static gboolean
 fu_redfish_device_probe(FuDevice *dev, GError **error)
 {
@@ -504,6 +524,10 @@ fu_redfish_device_probe(FuDevice *dev, GError **error)
 		}
 	}
 
+	/* for Supermicro check whether we have a proper Redfish license installed */
+	if (g_strcmp0("SMCI", fu_device_get_vendor(dev)) == 0)
+		fu_redfish_backend_smc_license_check(dev);
+
 	/* success */
 	return TRUE;
 }
@@ -727,7 +751,7 @@ fu_redfish_device_poll_task(FuRedfishDevice *self,
 
 	/* sleep and then reprobe hardware */
 	do {
-		g_usleep(G_USEC_PER_SEC);
+		fu_device_sleep(FU_DEVICE(self), 1000); /* ms */
 		if (!fu_redfish_device_poll_task_once(self, ctx, error))
 			return FALSE;
 		if (ctx->completed)
