@@ -31,6 +31,13 @@ struct _FuRedfishDeviceClass {
  */
 #define FU_REDFISH_DEVICE_FLAG_UNSIGNED_BUILD (1 << 1)
 
+/**
+ * FU_REDFISH_DEVICE_FLAG_MANAGER_RESET:
+ *
+ * Reset the manager (typically the BMC) after updating this device.
+ */
+#define FU_REDFISH_DEVICE_FLAG_MANAGER_RESET (1 << 2)
+
 /**
  * FU_REDFISH_DEVICE_FLAG_WILDCARD_TARGETS:
  *
@@ -40,7 +47,7 @@ struct _FuRedfishDeviceClass {
  * To use this option the payload must contain metadata that restricts it to a
  * specific SoftwareId.
  */
-#define FU_REDFISH_DEVICE_FLAG_WILDCARD_TARGETS (1 << 2)
+#define FU_REDFISH_DEVICE_FLAG_WILDCARD_TARGETS (1 << 3)
 
 FuRedfishBackend *
 fu_redfish_device_get_backend(FuRedfishDevice *self);
@@ -49,3 +56,7 @@ fu_redfish_device_poll_task(FuRedfishDevice *self,
 			    const gchar *location,
 			    FuProgress *progress,
 			    GError **error);
+guint
+fu_redfish_device_get_reset_pre_delay(FuRedfishDevice *self);
+guint
+fu_redfish_device_get_reset_post_delay(FuRedfishDevice *self);
