@@ -140,6 +140,11 @@ fu_redfish_request_load_json(FuRedfishRequest *self, GByteArray *buf, GError **e
 			error_code = FWUPD_ERROR_AUTH_FAILED;
 		else if (g_strcmp0(id, "Base.1.8.PasswordChangeRequired") == 0)
 			error_code = FWUPD_ERROR_AUTH_EXPIRED;
+		else if (g_strcmp0(id, "SMC.1.0.OemLicenseNotPassed") == 0)
+			error_code = FWUPD_ERROR_NOT_SUPPORTED;
+		else if (g_strcmp0(id, "SMC.1.0.OemFirmwareAlreadyInUpdateMode") == 0 ||
+			 g_strcmp0(id, "SMC.1.0.OemBiosUpdateIsInProgress") == 0)
+			error_code = FWUPD_ERROR_ALREADY_PENDING;
 		g_set_error_literal(error, FWUPD_ERROR, error_code, msg);
 		return FALSE;
 	}
@@ -220,9 +225,8 @@ fu_redfish_request_perform(FuRedfishRequest *self,
 	}
 
 	/* save to cache */
-	if (self->cache != NULL && path != NULL) {
+	if (self->cache != NULL)
 		g_hash_table_insert(self->cache, g_strdup(path), g_byte_array_ref(self->buf));
-	}
 
 	/* success */
 	return TRUE;
