@@ -121,7 +121,7 @@ fu_steelseries_fizz_tunnel_attach(FuDevice *device, FuProgress *progress, GError
 	fu_progress_step_done(progress);
 
 	/* wait for receiver to reset the connection status to 0 */
-	fu_progress_sleep(fu_progress_get_child(progress), 2000); /* 2 s */
+	fu_device_sleep_full(device, 2000, fu_progress_get_child(progress)); /* ms */
 	remove_delay -= 2000;
 	fu_progress_step_done(progress);
 
@@ -146,10 +146,8 @@ fu_steelseries_fizz_tunnel_probe(FuDevice *device, GError **error)
 	release = g_usb_device_get_release(usb_device);
 	if (release != 0x0 &&
 	    fu_device_get_version_format(device) == FWUPD_VERSION_FORMAT_UNKNOWN) {
-		g_autofree gchar *version = NULL;
-		version = fu_version_from_uint16(release, FWUPD_VERSION_FORMAT_BCD);
 		fu_device_set_version_format(device, FWUPD_VERSION_FORMAT_BCD);
-		fu_device_set_version(device, version);
+		fu_device_set_version_from_uint16(device, release);
 	}
 
 	/* add GUIDs in order of priority */
