@@ -9,7 +9,6 @@
 
 #include <fwupdplugin.h>
 
-#include <gio/gio.h>
 #include <string.h>
 
 #include "fu-synaprom-common.h"
@@ -42,7 +41,7 @@ GByteArray *
 fu_synaprom_reply_new(gsize cmdlen)
 {
 	GByteArray *blob = g_byte_array_new();
-	fu_byte_array_set_size(blob, cmdlen);
+	fu_byte_array_set_size(blob, cmdlen, 0x00);
 	return blob;
 }
 
