@@ -57,10 +57,7 @@ typedef struct __attribute__((packed)) {
 	guint16 container_id;
 	guint8 minor_version;
 	guint8 major_version;
-	guint8 reserved_08;
-	guint8 reserved_09;
-	guint8 reserved_0a;
-	guint8 reserved_0b;
+	guint32 signature_size;
 	guint32 container_option_flags;
 	guint32 content_options_length;
 	guint32 content_options_address;
@@ -93,6 +90,7 @@ typedef enum {
 	RMI_FIRMWARE_CONTAINER_ID_EXTERNAL_TOUCH_AFE_CONFIG,
 	RMI_FIRMWARE_CONTAINER_ID_UTILITY,
 	RMI_FIRMWARE_CONTAINER_ID_UTILITY_PARAMETER,
+	RMI_FIRMWARE_CONTAINER_ID_FIXED_LOCATION_DATA = 27,
 } RmiFirmwareContainerId;
 
 static const gchar *
@@ -146,6 +144,8 @@ rmi_firmware_container_id_to_string(RmiFirmwareContainerId container_id)
 		return "utility";
 	if (container_id == RMI_FIRMWARE_CONTAINER_ID_UTILITY_PARAMETER)
 		return "utility-parameter";
+	if (container_id == RMI_FIRMWARE_CONTAINER_ID_FIXED_LOCATION_DATA)
+		return "fixed-location-data";
 	return NULL;
 }
 
@@ -160,7 +160,7 @@ fu_synaptics_rmi_firmware_add_image(FuFirmware *firmware,
 	g_autoptr(GBytes) bytes = NULL;
 	g_autoptr(FuFirmware) img = NULL;
 
-	bytes = fu_common_bytes_new_offset(fw, offset, sz, error);
+	bytes = fu_bytes_new_offset(fw, offset, sz, error);
 	if (bytes == NULL)
 		return FALSE;
 	img = fu_firmware_new_from_bytes(bytes);
@@ -169,6 +169,33 @@ fu_synaptics_rmi_firmware_add_image(FuFirmware *firmware,
 	return TRUE;
 }
 
+static gboolean
+fu_synaptics_rmi_firmware_add_image_v10(FuFirmware *firmware,
+					const gchar *id,
+					GBytes *fw,
+					gsize offset,
+					gsize sz,
+					gsize sig_sz,
+					GError **error)
+{
+	g_autoptr(GBytes) bytes = NULL;
+	g_autoptr(FuFirmware) img = NULL;
+	g_autofree gchar *sig_id = NULL;
+
+	if (!fu_synaptics_rmi_firmware_add_image(firmware, id, fw, offset, sz, error))
+		return FALSE;
+	if (sig_sz != 0) {
+		bytes = fu_bytes_new_offset(fw, offset + sz, sig_sz, error);
+		if (bytes == NULL)
+			return FALSE;
+		img = fu_firmware_new_from_bytes(bytes);
+		sig_id = g_strdup_printf("%s-signature", id);
+		fu_firmware_set_id(img, sig_id);
+		fu_firmware_add_image(firmware, img);
+	}
+	return TRUE;
+}
+
 static void
 fu_synaptics_rmi_firmware_export(FuFirmware *firmware,
 				 FuFirmwareExportFlags flags,
@@ -200,13 +227,14 @@ fu_synaptics_rmi_firmware_parse_v10(FuFirmware *firmware, GBytes *fw, GError **e
 	guint8 product_id[RMI_PRODUCT_ID_LENGTH] = {0x0};
 	gsize sz = 0;
 	const guint8 *data = g_bytes_get_data(fw, &sz);
+	guint32 signature_size;
 
-	if (!fu_common_read_uint32_safe(data,
-					sz,
-					RMI_IMG_V10_CNTR_ADDR_OFFSET,
-					&cntr_addr,
-					G_LITTLE_ENDIAN,
-					error))
+	if (!fu_memread_uint32_safe(data,
+				    sz,
+				    RMI_IMG_V10_CNTR_ADDR_OFFSET,
+				    &cntr_addr,
+				    G_LITTLE_ENDIAN,
+				    error))
 		return FALSE;
 	g_debug("v10 RmiFirmwareContainerDescriptor at 0x%x", cntr_addr);
 	if (!fu_memcpy_safe((guint8 *)&desc,
@@ -256,7 +284,7 @@ fu_synaptics_rmi_firmware_parse_v10(FuFirmware *firmware, GBytes *fw, GError **e
 		guint32 content_addr;
 		guint32 addr;
 		guint32 length;
-		if (!fu_common_read_uint32_safe(data, sz, offset, &addr, G_LITTLE_ENDIAN, error))
+		if (!fu_memread_uint32_safe(data, sz, offset, &addr, G_LITTLE_ENDIAN, error))
 			return FALSE;
 		g_debug("parsing RmiFirmwareContainerDescriptor at 0x%x", addr);
 		if (!fu_memcpy_safe((guint8 *)&desc,
@@ -271,10 +299,12 @@ fu_synaptics_rmi_firmware_parse_v10(FuFirmware *firmware, GBytes *fw, GError **e
 		container_id = GUINT16_FROM_LE(desc.container_id);
 		content_addr = GUINT32_FROM_LE(desc.content_address);
 		length = GUINT32_FROM_LE(desc.content_length);
-		g_debug("RmiFirmwareContainerDescriptor 0x%02x @ 0x%x (len 0x%x)",
+		signature_size = GUINT32_FROM_LE(desc.signature_size);
+		g_debug("RmiFirmwareContainerDescriptor 0x%02x @ 0x%x (len 0x%x) sig_size 0x%x",
 			container_id,
 			content_addr,
-			length);
+			length,
+			signature_size);
 		if (length == 0 || length > sz) {
 			g_set_error(error,
 				    FWUPD_ERROR,
@@ -296,40 +326,73 @@ fu_synaptics_rmi_firmware_parse_v10(FuFirmware *firmware, GBytes *fw, GError **e
 		}
 		switch (container_id) {
 		case RMI_FIRMWARE_CONTAINER_ID_BL:
-			if (!fu_common_read_uint8_safe(data,
-						       sz,
-						       content_addr,
-						       &self->bootloader_version,
-						       error))
+			if (!fu_memread_uint8_safe(data,
+						   sz,
+						   content_addr,
+						   &self->bootloader_version,
+						   error))
 				return FALSE;
 			break;
 		case RMI_FIRMWARE_CONTAINER_ID_UI:
 		case RMI_FIRMWARE_CONTAINER_ID_CORE_CODE:
-			if (!fu_synaptics_rmi_firmware_add_image(firmware,
-								 "ui",
-								 fw,
-								 content_addr,
-								 length,
-								 error))
+			if (!fu_synaptics_rmi_firmware_add_image_v10(firmware,
+								     "ui",
+								     fw,
+								     content_addr,
+								     length,
+								     signature_size,
+								     error))
 				return FALSE;
 			break;
 		case RMI_FIRMWARE_CONTAINER_ID_FLASH_CONFIG:
-			if (!fu_synaptics_rmi_firmware_add_image(firmware,
-								 "flash-config",
-								 fw,
-								 content_addr,
-								 length,
-								 error))
+			if (!fu_synaptics_rmi_firmware_add_image_v10(firmware,
+								     "flash-config",
+								     fw,
+								     content_addr,
+								     length,
+								     signature_size,
+								     error))
 				return FALSE;
 			break;
 		case RMI_FIRMWARE_CONTAINER_ID_UI_CONFIG:
 		case RMI_FIRMWARE_CONTAINER_ID_CORE_CONFIG:
-			if (!fu_synaptics_rmi_firmware_add_image(firmware,
-								 "config",
-								 fw,
-								 content_addr,
-								 length,
-								 error))
+			if (!fu_synaptics_rmi_firmware_add_image_v10(firmware,
+								     "config",
+								     fw,
+								     content_addr,
+								     length,
+								     signature_size,
+								     error))
+				return FALSE;
+			break;
+		case RMI_FIRMWARE_CONTAINER_ID_FIXED_LOCATION_DATA:
+			if (!fu_synaptics_rmi_firmware_add_image_v10(firmware,
+								     "fixed-location-data",
+								     fw,
+								     content_addr,
+								     length,
+								     signature_size,
+								     error))
+				return FALSE;
+			break;
+		case RMI_FIRMWARE_CONTAINER_ID_EXTERNAL_TOUCH_AFE_CONFIG:
+			if (!fu_synaptics_rmi_firmware_add_image_v10(firmware,
+								     "afe-config",
+								     fw,
+								     content_addr,
+								     length,
+								     signature_size,
+								     error))
+				return FALSE;
+			break;
+		case RMI_FIRMWARE_CONTAINER_ID_DISPLAY_CONFIG:
+			if (!fu_synaptics_rmi_firmware_add_image_v10(firmware,
+								     "display-config",
+								     fw,
+								     content_addr,
+								     length,
+								     signature_size,
+								     error))
 				return FALSE;
 			break;
 		case RMI_FIRMWARE_CONTAINER_ID_GENERAL_INFORMATION:
@@ -344,19 +407,19 @@ fu_synaptics_rmi_firmware_parse_v10(FuFirmware *firmware, GBytes *fw, GError **e
 			}
 			g_clear_pointer(&self->product_id, g_free);
 			self->io = 1;
-			if (!fu_common_read_uint32_safe(data,
-							sz,
-							content_addr,
-							&self->package_id,
-							G_LITTLE_ENDIAN,
-							error))
+			if (!fu_memread_uint32_safe(data,
+						    sz,
+						    content_addr,
+						    &self->package_id,
+						    G_LITTLE_ENDIAN,
+						    error))
 				return FALSE;
-			if (!fu_common_read_uint32_safe(data,
-							sz,
-							content_addr + 0x04,
-							&self->build_id,
-							G_LITTLE_ENDIAN,
-							error))
+			if (!fu_memread_uint32_safe(data,
+						    sz,
+						    content_addr + 0x04,
+						    &self->build_id,
+						    G_LITTLE_ENDIAN,
+						    error))
 				return FALSE;
 			if (!fu_memcpy_safe(product_id,
 					    sizeof(product_id),
@@ -394,12 +457,12 @@ fu_synaptics_rmi_firmware_parse_v0x(FuFirmware *firmware, GBytes *fw, GError **e
 	const guint8 *data = g_bytes_get_data(fw, &sz);
 
 	/* main firmware */
-	if (!fu_common_read_uint32_safe(data,
-					sz,
-					RMI_IMG_IMAGE_SIZE_OFFSET,
-					&img_sz,
-					G_LITTLE_ENDIAN,
-					error))
+	if (!fu_memread_uint32_safe(data,
+				    sz,
+				    RMI_IMG_IMAGE_SIZE_OFFSET,
+				    &img_sz,
+				    G_LITTLE_ENDIAN,
+				    error))
 		return FALSE;
 	if (img_sz > 0) {
 		/* payload, then signature appended */
@@ -423,12 +486,12 @@ fu_synaptics_rmi_firmware_parse_v0x(FuFirmware *firmware, GBytes *fw, GError **e
 	}
 
 	/* config */
-	if (!fu_common_read_uint32_safe(data,
-					sz,
-					RMI_IMG_CONFIG_SIZE_OFFSET,
-					&cfg_sz,
-					G_LITTLE_ENDIAN,
-					error))
+	if (!fu_memread_uint32_safe(data,
+				    sz,
+				    RMI_IMG_CONFIG_SIZE_OFFSET,
+				    &cfg_sz,
+				    G_LITTLE_ENDIAN,
+				    error))
 		return FALSE;
 	if (cfg_sz > 0) {
 		if (!fu_synaptics_rmi_firmware_add_image(firmware,
@@ -445,8 +508,7 @@ fu_synaptics_rmi_firmware_parse_v0x(FuFirmware *firmware, GBytes *fw, GError **e
 static gboolean
 fu_synaptics_rmi_firmware_parse(FuFirmware *firmware,
 				GBytes *fw,
-				guint64 addr_start,
-				guint64 addr_end,
+				gsize offset,
 				FwupdInstallFlags flags,
 				GError **error)
 {
@@ -473,12 +535,12 @@ fu_synaptics_rmi_firmware_parse(FuFirmware *firmware,
 	}
 
 	/* verify checksum */
-	if (!fu_common_read_uint32_safe(data,
-					sz,
-					RMI_IMG_CHECKSUM_OFFSET,
-					&self->checksum,
-					G_LITTLE_ENDIAN,
-					error))
+	if (!fu_memread_uint32_safe(data,
+				    sz,
+				    RMI_IMG_CHECKSUM_OFFSET,
+				    &self->checksum,
+				    G_LITTLE_ENDIAN,
+				    error))
 		return FALSE;
 	checksum_calculated = fu_synaptics_rmi_generate_checksum(data + 4, sz - 4);
 	if ((flags & FWUPD_INSTALL_FLAG_IGNORE_CHECKSUM) == 0) {
@@ -498,36 +560,36 @@ fu_synaptics_rmi_firmware_parse(FuFirmware *firmware,
 	self->io = data[RMI_IMG_IO_OFFSET];
 	self->bootloader_version = data[RMI_IMG_BOOTLOADER_VERSION_OFFSET];
 	if (self->io == 1) {
-		if (!fu_common_read_uint32_safe(data,
-						sz,
-						RMI_IMG_FW_BUILD_ID_OFFSET,
-						&self->build_id,
-						G_LITTLE_ENDIAN,
-						error))
+		if (!fu_memread_uint32_safe(data,
+					    sz,
+					    RMI_IMG_FW_BUILD_ID_OFFSET,
+					    &self->build_id,
+					    G_LITTLE_ENDIAN,
+					    error))
 			return FALSE;
-		if (!fu_common_read_uint32_safe(data,
-						sz,
-						RMI_IMG_PACKAGE_ID_OFFSET,
-						&self->package_id,
-						G_LITTLE_ENDIAN,
-						error))
+		if (!fu_memread_uint32_safe(data,
+					    sz,
+					    RMI_IMG_PACKAGE_ID_OFFSET,
+					    &self->package_id,
+					    G_LITTLE_ENDIAN,
+					    error))
 			return FALSE;
 	}
 	self->product_id =
 	    g_strndup((const gchar *)data + RMI_IMG_PRODUCT_ID_OFFSET, RMI_PRODUCT_ID_LENGTH);
-	if (!fu_common_read_uint16_safe(data,
-					sz,
-					RMI_IMG_PRODUCT_INFO_OFFSET,
-					&self->product_info,
-					G_LITTLE_ENDIAN,
-					error))
+	if (!fu_memread_uint16_safe(data,
+				    sz,
+				    RMI_IMG_PRODUCT_INFO_OFFSET,
+				    &self->product_info,
+				    G_LITTLE_ENDIAN,
+				    error))
 		return FALSE;
-	if (!fu_common_read_uint32_safe(data,
-					sz,
-					RMI_IMG_IMAGE_SIZE_OFFSET,
-					&firmware_size,
-					G_LITTLE_ENDIAN,
-					error))
+	if (!fu_memread_uint32_safe(data,
+				    sz,
+				    RMI_IMG_IMAGE_SIZE_OFFSET,
+				    &firmware_size,
+				    G_LITTLE_ENDIAN,
+				    error))
 		return FALSE;
 	fu_firmware_set_size(firmware, firmware_size);
 
@@ -539,12 +601,12 @@ fu_synaptics_rmi_firmware_parse(FuFirmware *firmware,
 	case 5:
 	case 6:
 		if ((self->io & 0x10) >> 1) {
-			if (!fu_common_read_uint32_safe(data,
-							sz,
-							RMI_IMG_SIGNATURE_SIZE_OFFSET,
-							&self->sig_size,
-							G_LITTLE_ENDIAN,
-							error))
+			if (!fu_memread_uint32_safe(data,
+						    sz,
+						    RMI_IMG_SIGNATURE_SIZE_OFFSET,
+						    &self->sig_size,
+						    G_LITTLE_ENDIAN,
+						    error))
 				return FALSE;
 		}
 		if (!fu_synaptics_rmi_firmware_parse_v0x(firmware, fw, error))
@@ -552,6 +614,7 @@ fu_synaptics_rmi_firmware_parse(FuFirmware *firmware,
 		self->kind = RMI_FIRMWARE_KIND_0X;
 		break;
 	case 16:
+	case 17:
 		if (!fu_synaptics_rmi_firmware_parse_v10(firmware, fw, error))
 			return FALSE;
 		self->kind = RMI_FIRMWARE_KIND_10;
@@ -595,7 +658,7 @@ fu_synaptics_rmi_firmware_write_v0x(FuFirmware *firmware, GError **error)
 	bufsz = g_bytes_get_size(buf_blob);
 
 	/* create empty block */
-	fu_byte_array_set_size(buf, RMI_IMG_FW_OFFSET + 0x4 + bufsz);
+	fu_byte_array_set_size(buf, RMI_IMG_FW_OFFSET + 0x4 + bufsz, 0x00);
 	buf->data[RMI_IMG_IO_OFFSET] = 0x0;		    /* no build_id or package_id */
 	buf->data[RMI_IMG_BOOTLOADER_VERSION_OFFSET] = 0x2; /* not hierarchical */
 	if (self->product_id != NULL) {
@@ -610,19 +673,17 @@ fu_synaptics_rmi_firmware_write_v0x(FuFirmware *firmware, GError **error)
 				    error))
 			return NULL;
 	}
-	fu_common_write_uint16(buf->data + RMI_IMG_PRODUCT_INFO_OFFSET, 0x1234, G_LITTLE_ENDIAN);
-	fu_common_write_uint32(buf->data + RMI_IMG_IMAGE_SIZE_OFFSET, bufsz, G_LITTLE_ENDIAN);
-	fu_common_write_uint32(buf->data + RMI_IMG_CONFIG_SIZE_OFFSET, bufsz, G_LITTLE_ENDIAN);
-	fu_common_write_uint32(buf->data + RMI_IMG_FW_OFFSET + 0x0,
-			       0xdead,
-			       G_LITTLE_ENDIAN); /* img */
-	fu_common_write_uint32(buf->data + RMI_IMG_FW_OFFSET + bufsz,
-			       0xbeef,
-			       G_LITTLE_ENDIAN); /* config */
+	fu_memwrite_uint16(buf->data + RMI_IMG_PRODUCT_INFO_OFFSET, 0x1234, G_LITTLE_ENDIAN);
+	fu_memwrite_uint32(buf->data + RMI_IMG_IMAGE_SIZE_OFFSET, bufsz, G_LITTLE_ENDIAN);
+	fu_memwrite_uint32(buf->data + RMI_IMG_CONFIG_SIZE_OFFSET, bufsz, G_LITTLE_ENDIAN);
+	fu_memwrite_uint32(buf->data + RMI_IMG_FW_OFFSET + 0x0, 0xdead, G_LITTLE_ENDIAN); /* img */
+	fu_memwrite_uint32(buf->data + RMI_IMG_FW_OFFSET + bufsz,
+			   0xbeef,
+			   G_LITTLE_ENDIAN); /* config */
 
 	/* fixup checksum */
 	csum = fu_synaptics_rmi_generate_checksum(buf->data + 4, buf->len - 4);
-	fu_common_write_uint32(buf->data + RMI_IMG_CHECKSUM_OFFSET, csum, G_LITTLE_ENDIAN);
+	fu_memwrite_uint32(buf->data + RMI_IMG_CHECKSUM_OFFSET, csum, G_LITTLE_ENDIAN);
 
 	/* success */
 	return g_byte_array_free_to_bytes(g_steal_pointer(&buf));
@@ -664,7 +725,7 @@ fu_synaptics_rmi_firmware_write_v10(FuFirmware *firmware, GError **error)
 	desc.content_length = GUINT32_TO_LE(bufsz);
 
 	/* create empty block */
-	fu_byte_array_set_size(buf, RMI_IMG_FW_OFFSET + 0x48);
+	fu_byte_array_set_size(buf, RMI_IMG_FW_OFFSET + 0x48, 0x00);
 	buf->data[RMI_IMG_IO_OFFSET] = 0x1;
 	buf->data[RMI_IMG_BOOTLOADER_VERSION_OFFSET] = 16; /* hierarchical */
 	if (self->product_id != NULL) {
@@ -679,26 +740,26 @@ fu_synaptics_rmi_firmware_write_v10(FuFirmware *firmware, GError **error)
 				    error))
 			return NULL;
 	}
-	fu_common_write_uint32(buf->data + RMI_IMG_FW_BUILD_ID_OFFSET, 0x1234, G_LITTLE_ENDIAN);
-	fu_common_write_uint32(buf->data + RMI_IMG_PACKAGE_ID_OFFSET, 0x4321, G_LITTLE_ENDIAN);
-	fu_common_write_uint16(buf->data + RMI_IMG_PRODUCT_INFO_OFFSET, 0x3456, G_LITTLE_ENDIAN);
-	fu_common_write_uint32(buf->data + RMI_IMG_IMAGE_SIZE_OFFSET, bufsz, G_LITTLE_ENDIAN);
-	fu_common_write_uint32(buf->data + RMI_IMG_CONFIG_SIZE_OFFSET, bufsz, G_LITTLE_ENDIAN);
-	fu_common_write_uint32(buf->data + RMI_IMG_V10_CNTR_ADDR_OFFSET,
-			       RMI_IMG_FW_OFFSET,
-			       G_LITTLE_ENDIAN);
+	fu_memwrite_uint32(buf->data + RMI_IMG_FW_BUILD_ID_OFFSET, 0x1234, G_LITTLE_ENDIAN);
+	fu_memwrite_uint32(buf->data + RMI_IMG_PACKAGE_ID_OFFSET, 0x4321, G_LITTLE_ENDIAN);
+	fu_memwrite_uint16(buf->data + RMI_IMG_PRODUCT_INFO_OFFSET, 0x3456, G_LITTLE_ENDIAN);
+	fu_memwrite_uint32(buf->data + RMI_IMG_IMAGE_SIZE_OFFSET, bufsz, G_LITTLE_ENDIAN);
+	fu_memwrite_uint32(buf->data + RMI_IMG_CONFIG_SIZE_OFFSET, bufsz, G_LITTLE_ENDIAN);
+	fu_memwrite_uint32(buf->data + RMI_IMG_V10_CNTR_ADDR_OFFSET,
+			   RMI_IMG_FW_OFFSET,
+			   G_LITTLE_ENDIAN);
 
 	/* hierarchical section */
 	memcpy(buf->data + RMI_IMG_FW_OFFSET + 0x00, &desc_hdr, sizeof(desc_hdr));
 	memcpy(buf->data + RMI_IMG_FW_OFFSET + 0x20, offset_table, sizeof(offset_table));
 	memcpy(buf->data + RMI_IMG_FW_OFFSET + 0x24, &desc, sizeof(desc));
-	fu_common_write_uint32(buf->data + RMI_IMG_FW_OFFSET + 0x44,
-			       0xfeed,
-			       G_LITTLE_ENDIAN); /* flash_config */
+	fu_memwrite_uint32(buf->data + RMI_IMG_FW_OFFSET + 0x44,
+			   0xfeed,
+			   G_LITTLE_ENDIAN); /* flash_config */
 
 	/* fixup checksum */
 	csum = fu_synaptics_rmi_generate_checksum(buf->data + 4, buf->len - 4);
-	fu_common_write_uint32(buf->data + RMI_IMG_CHECKSUM_OFFSET, csum, G_LITTLE_ENDIAN);
+	fu_memwrite_uint32(buf->data + RMI_IMG_CHECKSUM_OFFSET, csum, G_LITTLE_ENDIAN);
 
 	/* success */
 	return g_byte_array_free_to_bytes(g_steal_pointer(&buf));
