@@ -32,17 +32,17 @@ G_DEFINE_TYPE(FuSynapticsRmiHidDevice, fu_synaptics_rmi_hid_device, FU_TYPE_SYNA
 
 #define RMI_DEVICE_DEFAULT_TIMEOUT 2000
 
-#define HID_RMI4_REPORT_ID	       0
-#define HID_RMI4_READ_INPUT_COUNT      1
-#define HID_RMI4_READ_INPUT_DATA       2
-#define HID_RMI4_READ_OUTPUT_ADDR      2
-#define HID_RMI4_READ_OUTPUT_COUNT     4
-#define HID_RMI4_WRITE_OUTPUT_COUNT    1
-#define HID_RMI4_WRITE_OUTPUT_ADDR     2
-#define HID_RMI4_WRITE_OUTPUT_DATA     4
-#define HID_RMI4_FEATURE_MODE	       1
-#define HID_RMI4_ATTN_INTERUPT_SOURCES 1
-#define HID_RMI4_ATTN_DATA	       2
+#define HID_RMI4_REPORT_ID		0
+#define HID_RMI4_READ_INPUT_COUNT	1
+#define HID_RMI4_READ_INPUT_DATA	2
+#define HID_RMI4_READ_OUTPUT_ADDR	2
+#define HID_RMI4_READ_OUTPUT_COUNT	4
+#define HID_RMI4_WRITE_OUTPUT_COUNT	1
+#define HID_RMI4_WRITE_OUTPUT_ADDR	2
+#define HID_RMI4_WRITE_OUTPUT_DATA	4
+#define HID_RMI4_FEATURE_MODE		1
+#define HID_RMI4_ATTN_INTERRUPT_SOURCES 1
+#define HID_RMI4_ATTN_DATA		2
 
 /*
  * This bit disables whatever sleep mode may be selected by the sleep_mode
@@ -261,7 +261,7 @@ fu_synaptics_rmi_hid_device_wait_for_attr(FuSynapticsRmiDevice *rmi_device,
 
 		/* read from fd */
 		res = fu_io_channel_read_byte_array(self->io_channel,
-						    HID_RMI4_ATTN_INTERUPT_SOURCES + 1,
+						    HID_RMI4_ATTN_INTERRUPT_SOURCES + 1,
 						    timeout_ms,
 						    FU_IO_CHANNEL_FLAG_NONE,
 						    &error_local);
@@ -279,7 +279,7 @@ fu_synaptics_rmi_hid_device_wait_for_attr(FuSynapticsRmiDevice *rmi_device,
 				     80,
 				     FU_DUMP_FLAGS_NONE);
 		}
-		if (res->len < HID_RMI4_ATTN_INTERUPT_SOURCES + 1) {
+		if (res->len < HID_RMI4_ATTN_INTERRUPT_SOURCES + 1) {
 			g_debug("attr: ignoring small read of %u", res->len);
 			continue;
 		}
@@ -290,12 +290,12 @@ fu_synaptics_rmi_hid_device_wait_for_attr(FuSynapticsRmiDevice *rmi_device,
 		}
 
 		/* success */
-		if (source_mask & res->data[HID_RMI4_ATTN_INTERUPT_SOURCES])
+		if (source_mask & res->data[HID_RMI4_ATTN_INTERRUPT_SOURCES])
 			return TRUE;
 
 		/* wrong mask */
 		g_debug("source mask did not match: 0x%x",
-			res->data[HID_RMI4_ATTN_INTERUPT_SOURCES]);
+			res->data[HID_RMI4_ATTN_INTERRUPT_SOURCES]);
 	}
 
 	/* urgh */
@@ -379,7 +379,8 @@ fu_synaptics_rmi_hid_device_rebind_driver(FuSynapticsRmiDevice *self, GError **e
 	g_autofree gchar *fn_rebind = NULL;
 	g_autofree gchar *fn_unbind = NULL;
 	g_autoptr(GUdevDevice) parent_hid = NULL;
-	g_autoptr(GUdevDevice) parent_i2c = NULL;
+	g_autoptr(GUdevDevice) parent_phys = NULL;
+	g_auto(GStrv) hid_strs = NULL;
 
 	/* get actual HID node */
 	parent_hid = g_udev_device_get_parent_with_subsystem(udev_device, "hid", NULL);
@@ -392,30 +393,36 @@ fu_synaptics_rmi_hid_device_rebind_driver(FuSynapticsRmiDevice *self, GError **e
 		return FALSE;
 	}
 
+	/* build paths */
+	parent_phys = g_udev_device_get_parent_with_subsystem(udev_device, "i2c", NULL);
+	if (parent_phys == NULL) {
+		parent_phys = g_udev_device_get_parent_with_subsystem(udev_device, "usb", NULL);
+		if (parent_phys == NULL) {
+			g_set_error(error,
+				    FWUPD_ERROR,
+				    FWUPD_ERROR_INVALID_FILE,
+				    "no parent device for %s",
+				    g_udev_device_get_sysfs_path(parent_hid));
+			return FALSE;
+		}
+	}
+
 	/* find the physical ID to use for the rebind */
-	hid_id = g_udev_device_get_property(parent_hid, "HID_PHYS");
+	hid_strs = g_strsplit(g_udev_device_get_sysfs_path(parent_phys), "/", -1);
+	hid_id = hid_strs[g_strv_length(hid_strs) - 1];
 	if (hid_id == NULL) {
 		g_set_error(error,
 			    FWUPD_ERROR,
 			    FWUPD_ERROR_INVALID_FILE,
 			    "no HID_PHYS in %s",
-			    g_udev_device_get_sysfs_path(parent_hid));
+			    g_udev_device_get_sysfs_path(parent_phys));
 		return FALSE;
 	}
+
 	g_debug("HID_PHYS: %s", hid_id);
 
-	/* build paths */
-	parent_i2c = g_udev_device_get_parent_with_subsystem(udev_device, "i2c", NULL);
-	if (parent_i2c == NULL) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_INVALID_FILE,
-			    "no I2C parent device for %s",
-			    g_udev_device_get_sysfs_path(udev_device));
-		return FALSE;
-	}
-	driver = g_udev_device_get_driver(parent_i2c);
-	subsystem = g_udev_device_get_subsystem(parent_i2c);
+	driver = g_udev_device_get_driver(parent_phys);
+	subsystem = g_udev_device_get_subsystem(parent_phys);
 	fn_rebind = g_build_filename("/sys/bus/", subsystem, "drivers", driver, "bind", NULL);
 	fn_unbind = g_build_filename("/sys/bus/", subsystem, "drivers", driver, "unbind", NULL);
 
@@ -552,10 +559,9 @@ static void
 fu_synaptics_rmi_hid_device_set_progress(FuDevice *self, FuProgress *progress)
 {
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_add_flag(progress, FU_PROGRESS_FLAG_GUESSED);
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "detach");
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 94, "write");
-	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 2, "attach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 3, "detach");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_WRITE, 88, "write");
+	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_RESTART, 7, "attach");
 	fu_progress_add_step(progress, FWUPD_STATUS_DEVICE_BUSY, 2, "reload");
 }
 
@@ -564,6 +570,7 @@ fu_synaptics_rmi_hid_device_init(FuSynapticsRmiHidDevice *self)
 {
 	fu_device_set_name(FU_DEVICE(self), "Touchpad");
 	fu_device_set_remove_delay(FU_DEVICE(self), FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE);
+	fu_device_add_internal_flag(FU_DEVICE(self), FU_DEVICE_INTERNAL_FLAG_NO_PROBE_COMPLETE);
 	fu_synaptics_rmi_device_set_max_page(FU_SYNAPTICS_RMI_DEVICE(self), 0xff);
 }
 
