@@ -6,8 +6,6 @@
 
 #pragma once
 
-#include <glib-object.h>
-
 #include "fu-synaptics-rmi-device.h"
 
 gboolean
@@ -22,3 +20,9 @@ gboolean
 fu_synaptics_rmi_v7_device_setup(FuSynapticsRmiDevice *self, GError **error);
 gboolean
 fu_synaptics_rmi_v7_device_query_status(FuSynapticsRmiDevice *self, GError **error);
+gboolean
+fu_synaptics_rmi_v7_device_secure_check(FuSynapticsRmiDevice *self,
+					FuFirmware *firmware,
+					GError **error);
+GBytes *
+fu_synaptics_rmi_v7_device_get_pubkey(FuSynapticsRmiDevice *self, GError **error);
