@@ -22,8 +22,7 @@
 
 #include "fu-context-private.h"
 #include "fu-plugin-private.h"
-#include "fu-thunderbolt-firmware-update.h"
-#include "fu-thunderbolt-firmware.h"
+#include "fu-thunderbolt-plugin.h"
 #include "fu-udev-device-private.h"
 
 static gchar *
@@ -489,7 +488,8 @@ sync_device_removed(FuPlugin *plugin, FuDevice *device, gpointer user_data)
 	if (target == NULL) {
 		g_warning("Got device that could not be matched: %s", uuid);
 		return;
-	} else if (target->fu_device == NULL) {
+	}
+	if (target->fu_device == NULL) {
 		g_warning("Got remove event for out-of-tree device %s", uuid);
 		return;
 	}
@@ -888,6 +888,7 @@ fu_thunderbolt_gudev_uevent_cb(GUdevClient *gudev_client,
 	if (g_strcmp0(action, "add") == 0) {
 		g_autoptr(FuUdevDevice) device = NULL;
 		g_autoptr(GError) error_local = NULL;
+		g_autoptr(FuProgress) progress = fu_progress_new(G_STRLOC);
 
 		device = fu_udev_device_new(tt->ctx, udev_device);
 		if (!fu_device_probe(FU_DEVICE(device), &error_local)) {
@@ -896,6 +897,7 @@ fu_thunderbolt_gudev_uevent_cb(GUdevClient *gudev_client,
 		}
 		if (!fu_plugin_runner_backend_device_added(tt->plugin,
 							   FU_DEVICE(device),
+							   progress,
 							   &error_local))
 			g_debug("failed to add: %s", error_local->message);
 		return;
@@ -918,7 +920,6 @@ test_set_up(ThunderboltTest *tt, gconstpointer params)
 {
 	TestFlags flags = GPOINTER_TO_UINT(params);
 	gboolean ret;
-	g_autofree gchar *pluginfn = NULL;
 	g_autofree gchar *sysfs = NULL;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(FuProgress) progress = fu_progress_new(G_STRLOC);
@@ -937,16 +938,10 @@ test_set_up(ThunderboltTest *tt, gconstpointer params)
 	sysfs = umockdev_testbed_get_sys_dir(tt->bed);
 	g_debug("mock sysfs at %s", sysfs);
 
-	tt->plugin = fu_plugin_new(tt->ctx);
+	tt->plugin = fu_plugin_new_from_gtype(fu_thunderbolt_plugin_get_type(), tt->ctx);
+
 	g_assert_nonnull(tt->plugin);
 
-	pluginfn =
-	    g_test_build_filename(G_TEST_BUILT, "libfu_plugin_thunderbolt." G_MODULE_SUFFIX, NULL);
-	ret = fu_plugin_open(tt->plugin, pluginfn, &error);
-
-	g_assert_no_error(error);
-	g_assert_true(ret);
-
 	ret = fu_plugin_runner_startup(tt->plugin, progress, &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
@@ -1051,70 +1046,6 @@ test_tree(ThunderboltTest *tt, gconstpointer user_data)
 	g_assert_true(ret);
 }
 
-static gboolean
-_compare_images(FuThunderboltFirmware *firmware_old,
-		FuThunderboltFirmware *firmware,
-		GError **error)
-{
-	if (fu_thunderbolt_firmware_is_host(firmware) !=
-	    fu_thunderbolt_firmware_is_host(firmware_old)) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_INVALID_FILE,
-			    "incorrect firmware mode, got %s, expected %s",
-			    fu_thunderbolt_firmware_is_host(firmware) ? "host" : "device",
-			    fu_thunderbolt_firmware_is_host(firmware_old) ? "host" : "device");
-		return FALSE;
-	}
-	if (fu_thunderbolt_firmware_get_vendor_id(firmware) !=
-	    fu_thunderbolt_firmware_get_vendor_id(firmware_old)) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_INVALID_FILE,
-			    "incorrect device vendor, got 0x%04x, expected 0x%04x",
-			    fu_thunderbolt_firmware_get_vendor_id(firmware),
-			    fu_thunderbolt_firmware_get_vendor_id(firmware_old));
-		return FALSE;
-	}
-	if (fu_thunderbolt_firmware_get_device_id(firmware) !=
-	    fu_thunderbolt_firmware_get_device_id(firmware_old)) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_INVALID_FILE,
-			    "incorrect device type, got 0x%04x, expected 0x%04x",
-			    fu_thunderbolt_firmware_get_device_id(firmware),
-			    fu_thunderbolt_firmware_get_device_id(firmware_old));
-		return FALSE;
-	}
-	if (fu_thunderbolt_firmware_get_model_id(firmware) !=
-	    fu_thunderbolt_firmware_get_model_id(firmware_old)) {
-		g_set_error(error,
-			    FWUPD_ERROR,
-			    FWUPD_ERROR_INVALID_FILE,
-			    "incorrect device model, got 0x%04x, expected 0x%04x",
-			    fu_thunderbolt_firmware_get_model_id(firmware),
-			    fu_thunderbolt_firmware_get_model_id(firmware_old));
-		return FALSE;
-	}
-	if (fu_thunderbolt_firmware_get_has_pd(firmware_old) &&
-	    !fu_thunderbolt_firmware_get_has_pd(firmware)) {
-		g_set_error_literal(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_INVALID_FILE,
-				    "new firmware is missing PD");
-		return FALSE;
-	}
-	if (fu_thunderbolt_firmware_get_flash_size(firmware) !=
-	    fu_thunderbolt_firmware_get_flash_size(firmware_old)) {
-		g_set_error_literal(error,
-				    FWUPD_ERROR,
-				    FWUPD_ERROR_INVALID_FILE,
-				    "incorrect flash size");
-		return FALSE;
-	}
-	return TRUE;
-}
-
 static void
 test_image_validation(ThunderboltTest *tt, gconstpointer user_data)
 {
@@ -1129,9 +1060,9 @@ test_image_validation(ThunderboltTest *tt, gconstpointer user_data)
 	g_autoptr(GBytes) ctl_data = NULL;
 	g_autoptr(GBytes) bad_data = NULL;
 	g_autoptr(GError) error = NULL;
-	g_autoptr(FuThunderboltFirmwareUpdate) firmware_fwi = fu_thunderbolt_firmware_update_new();
-	g_autoptr(FuThunderboltFirmware) firmware_ctl = fu_thunderbolt_firmware_new();
-	g_autoptr(FuThunderboltFirmware) firmware_bad = fu_thunderbolt_firmware_new();
+	g_autoptr(FuFirmware) firmware_fwi = fu_intel_thunderbolt_firmware_new();
+	g_autoptr(FuFirmware) firmware_ctl = fu_intel_thunderbolt_nvm_new();
+	g_autoptr(FuFirmware) firmware_bad = fu_intel_thunderbolt_nvm_new();
 
 	/* image as if read from the controller (i.e. no headers) */
 	ctl_path = g_test_build_filename(G_TEST_DIST, "tests", "minimal-fw-controller.bin", NULL);
@@ -1143,12 +1074,9 @@ test_image_validation(ThunderboltTest *tt, gconstpointer user_data)
 	g_assert_nonnull(ctl_data);
 
 	/* parse controller image */
-	ret = fu_firmware_parse(FU_FIRMWARE(firmware_ctl),
-				ctl_data,
-				FWUPD_INSTALL_FLAG_NO_SEARCH,
-				&error);
-	g_assert_true(ret);
+	ret = fu_firmware_parse(firmware_ctl, ctl_data, FWUPD_INSTALL_FLAG_NO_SEARCH, &error);
 	g_assert_no_error(error);
+	g_assert_true(ret);
 
 	/* valid firmware update image */
 	fwi_path = g_test_build_filename(G_TEST_DIST, "tests", "minimal-fw.bin", NULL);
@@ -1160,12 +1088,9 @@ test_image_validation(ThunderboltTest *tt, gconstpointer user_data)
 	g_assert_nonnull(fwi_data);
 
 	/* parse */
-	ret = fu_firmware_parse(FU_FIRMWARE(firmware_fwi),
-				fwi_data,
-				FWUPD_INSTALL_FLAG_NO_SEARCH,
-				&error);
-	g_assert_true(ret);
+	ret = fu_firmware_parse(firmware_fwi, fwi_data, FWUPD_INSTALL_FLAG_NO_SEARCH, &error);
 	g_assert_no_error(error);
+	g_assert_true(ret);
 
 	/* a wrong/bad firmware update image */
 	bad_path = g_test_build_filename(G_TEST_DIST, "tests", "colorhug.bin", NULL);
@@ -1177,17 +1102,17 @@ test_image_validation(ThunderboltTest *tt, gconstpointer user_data)
 	g_assert_nonnull(bad_data);
 
 	/* parse; should fail, bad image */
-	ret = fu_firmware_parse(FU_FIRMWARE(firmware_bad),
-				bad_data,
-				FWUPD_INSTALL_FLAG_NO_SEARCH,
-				&error);
+	ret = fu_firmware_parse(firmware_bad, bad_data, FWUPD_INSTALL_FLAG_NO_SEARCH, &error);
 	g_assert_false(ret);
 	g_assert_error(error, FWUPD_ERROR, FWUPD_ERROR_READ);
 	g_debug("expected image validation error [ctl]: %s", error->message);
 	g_clear_error(&error);
 
 	/* now for some testing ... this should work */
-	ret = _compare_images(firmware_ctl, FU_THUNDERBOLT_FIRMWARE(firmware_fwi), &error);
+	ret = fu_firmware_check_compatible(firmware_ctl,
+					   firmware_fwi,
+					   FWUPD_INSTALL_FLAG_NONE,
+					   &error);
 	g_assert_no_error(error);
 	g_assert_true(ret);
 }
