@@ -64,7 +64,7 @@ fu_tmp_eventlog_process(const gchar *fn, gint pcr, GError **error)
 			    pcr);
 		return FALSE;
 	}
-	fu_common_string_append_kv(str, 0, "Reconstructed PCRs", NULL);
+	fu_string_append(str, 0, "Reconstructed PCRs", NULL);
 	for (guint8 i = 0; i <= max_pcr; i++) {
 		g_autoptr(GPtrArray) pcrs = fu_tpm_eventlog_calc_checksums(items, i, NULL);
 		if (pcrs == NULL)
@@ -77,7 +77,7 @@ fu_tmp_eventlog_process(const gchar *fn, gint pcr, GError **error)
 				continue;
 			title = g_strdup_printf("PCR %x", i);
 			pretty = fwupd_checksum_format_for_display(csum);
-			fu_common_string_append_kv(str, 1, title, pretty);
+			fu_string_append(str, 1, title, pretty);
 		}
 	}
 
@@ -140,8 +140,8 @@ main(int argc, char *argv[])
 
 	/* set verbose? */
 	if (verbose) {
-		g_setenv("G_MESSAGES_DEBUG", "all", FALSE);
-		g_setenv("FWUPD_TPM_EVENTLOG_VERBOSE", "1", FALSE);
+		(void)g_setenv("G_MESSAGES_DEBUG", "all", FALSE);
+		(void)g_setenv("FWUPD_TPM_EVENTLOG_VERBOSE", "1", FALSE);
 	}
 
 	/* allow user to chose a local file */
