@@ -90,6 +90,10 @@ fu_tpm_plugin_device_added(FuPlugin *plugin, FuDevice *dev)
 			fu_plugin_add_report_metadata(plugin, "Pcr0_SHA256", csum);
 			continue;
 		}
+		if (csum_type == G_CHECKSUM_SHA384) {
+			fu_plugin_add_report_metadata(plugin, "Pcr0_SHA384", csum);
+			continue;
+		}
 	}
 }
 
@@ -156,11 +160,11 @@ fu_tpm_plugin_add_security_attr_eventlog(FuPlugin *plugin, FuSecurityAttrs *attr
 
 	/* compare against the real PCR0s */
 	pcr0s_real = fu_tpm_device_get_checksums(self->tpm_device, 0);
-	for (guint i = 0; i < pcr0s_real->len; i++) {
-		const gchar *checksum = g_ptr_array_index(pcr0s_real, i);
+	for (guint i = 0; i < pcr0s_calc->len; i++) {
+		const gchar *checksum = g_ptr_array_index(pcr0s_calc, i);
 		reconstructed = FALSE;
-		for (guint j = 0; j < pcr0s_calc->len; j++) {
-			const gchar *checksum_tmp = g_ptr_array_index(pcr0s_calc, j);
+		for (guint j = 0; j < pcr0s_real->len; j++) {
+			const gchar *checksum_tmp = g_ptr_array_index(pcr0s_real, j);
 			/* skip unless same algorithm */
 			if (strlen(checksum) != strlen(checksum_tmp))
 				continue;
@@ -256,6 +260,8 @@ fu_tpm_plugin_eventlog_report_metadata(FuPlugin *plugin)
 			checksum = fu_tpm_eventlog_strhex(item->checksum_sha1);
 		else if (item->checksum_sha256 != NULL)
 			checksum = fu_tpm_eventlog_strhex(item->checksum_sha256);
+		else if (item->checksum_sha384 != NULL)
+			checksum = fu_tpm_eventlog_strhex(item->checksum_sha384);
 		else
 			continue;
 		g_string_append_printf(str, "0x%08x %s", item->kind, checksum);
