@@ -10,6 +10,7 @@
 #include <fcntl.h>
 #include <glib/gi18n.h>
 
+#include "fu-acpi-uefi.h"
 #include "fu-uefi-backend.h"
 #include "fu-uefi-bgrt.h"
 #include "fu-uefi-bootmgr.h"
@@ -111,7 +112,7 @@ fu_uefi_capsule_plugin_fwupd_efi_probe(FuUefiCapsulePlugin *self, GError **error
 	g_autofree gchar *fn = NULL;
 
 	/* find the app binary */
-	fn = fu_uefi_get_built_app_path(error);
+	fn = fu_uefi_get_built_app_path("fwupd", error);
 	if (fn == NULL)
 		return FALSE;
 	self->fwupd_efi_file = g_file_new_for_path(fn);
@@ -247,7 +248,7 @@ fu_uefi_capsule_plugin_write_splash_data(FuUefiCapsulePlugin *self,
 		return FALSE;
 	}
 
-	/* save to a predicatable filename */
+	/* save to a predictable filename */
 	esp_path = fu_volume_get_mount_point(self->esp);
 	directory = fu_uefi_get_esp_path_for_os(device, esp_path);
 	basename = g_strdup_printf("fwupd-%s.cap", FU_EFIVAR_GUID_UX_CAPSULE);
@@ -436,8 +437,8 @@ static void
 fu_uefi_capsule_plugin_load_config(FuPlugin *plugin, FuDevice *device)
 {
 	gboolean disable_shim;
-	gboolean fallback_removable_path;
-	guint64 sz_reqd = FU_UEFI_COMMON_REQUIRED_ESP_FREE_SPACE;
+	gboolean enable_efi_debugging;
+	guint64 sz_reqd = 0;
 	g_autofree gchar *require_esp_free_space = NULL;
 	g_autoptr(GError) error_local = NULL;
 
@@ -448,18 +449,17 @@ fu_uefi_capsule_plugin_load_config(FuPlugin *plugin, FuDevice *device)
 			g_warning("invalid ESP free space specified: %s", error_local->message);
 		}
 	}
-	fu_device_set_metadata_integer(device, "RequireESPFreeSpace", sz_reqd);
+	fu_uefi_device_set_require_esp_free_space(FU_UEFI_DEVICE(device), sz_reqd);
 
 	/* shim used for SB or not? */
 	disable_shim = fu_plugin_get_config_value_boolean(plugin, "DisableShimForSecureBoot");
 	if (!disable_shim)
 		fu_device_add_private_flag(device, FU_UEFI_DEVICE_FLAG_USE_SHIM_FOR_SB);
 
-	/* check if using UEFI removable path */
-	fallback_removable_path =
-	    fu_plugin_get_config_value_boolean(plugin, "FallbacktoRemovablePath");
-	if (fallback_removable_path)
-		fu_device_add_private_flag(device, FU_UEFI_DEVICE_FLAG_FALLBACK_TO_REMOVABLE_PATH);
+	/* enable the fwupd.efi debug log? */
+	enable_efi_debugging = fu_plugin_get_config_value_boolean(plugin, "EnableEfiDebugging");
+	if (enable_efi_debugging)
+		fu_device_add_private_flag(device, FU_UEFI_DEVICE_FLAG_ENABLE_EFI_DEBUGGING);
 }
 
 static gboolean
@@ -850,10 +850,11 @@ fu_uefi_capsule_plugin_check_cod_support(FuPlugin *plugin, GError **error)
 {
 	gsize bufsz = 0;
 	guint64 value = 0;
+	g_autofree gchar *fn = NULL;
+	g_autofree gchar *path = NULL;
 	g_autofree guint8 *buf = NULL;
-#ifndef __aarch64__
-	FuContext *ctx = fu_plugin_get_context(plugin);
-#endif
+	g_autoptr(FuFirmware) acpi_uefi = NULL;
+	g_autoptr(GBytes) blob = NULL;
 
 	if (!fu_efivar_get_data(FU_EFIVAR_GUID_EFI_GLOBAL,
 				"OsIndicationsSupported",
@@ -874,21 +875,20 @@ fu_uefi_capsule_plugin_check_cod_support(FuPlugin *plugin, GError **error)
 		return FALSE;
 	}
 
-#ifndef __aarch64__
-	/* several models with Insyde firmware have been released where OsIndications advertises
-	 * support for CoD, but it simply does not work */
-	if (!fu_context_has_hwid_flag(ctx, "uefi-allow-cod")) {
-		g_set_error_literal(error,
-				    G_IO_ERROR,
-				    G_IO_ERROR_NOT_SUPPORTED,
-				    "Capsule-on-Disk is supported, but non-aarch64 platforms "
-				    "require the 'uefi-allow-cod' quirk for it to be used");
-		return FALSE;
-	}
-#endif
+	/* no table, nothing to check */
+	path = fu_path_from_kind(FU_PATH_KIND_ACPI_TABLES);
+	fn = g_build_filename(path, "UEFI", NULL);
+	if (!g_file_test(fn, G_FILE_TEST_EXISTS))
+		return TRUE;
 
-	/* success */
-	return TRUE;
+	/* if we have a table, parse it and validate it */
+	blob = fu_bytes_get_contents(fn, error);
+	if (blob == NULL)
+		return FALSE;
+	acpi_uefi = fu_acpi_uefi_new();
+	if (!fu_firmware_parse(acpi_uefi, blob, FWUPD_INSTALL_FLAG_NONE, error))
+		return FALSE;
+	return fu_acpi_uefi_cod_functional(FU_ACPI_UEFI(acpi_uefi), error);
 }
 
 static gboolean
@@ -1015,6 +1015,7 @@ fu_uefi_capsule_plugin_constructed(GObject *obj)
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_METADATA_SOURCE, "linux_lockdown");
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_METADATA_SOURCE, "acpi_phat");
 	fu_plugin_add_rule(plugin, FU_PLUGIN_RULE_CONFLICTS, "uefi"); /* old name */
+	fu_plugin_add_firmware_gtype(FU_PLUGIN(self), NULL, FU_TYPE_ACPI_UEFI);
 
 	/* add a requirement on the fwupd-efi version -- which can change  */
 	if (!fu_uefi_capsule_plugin_fwupd_efi_probe(self, &error_local))
