@@ -61,9 +61,6 @@ typedef struct __attribute__((__packed__)) {
 	guint32 status;
 } efi_update_info_t;
 
-/* the biggest size SPI part currently seen */
-#define FU_UEFI_COMMON_REQUIRED_ESP_FREE_SPACE (32 * 1024 * 1024)
-
 gchar *
 fu_uefi_get_fallback_app_path(FuDevice *device,
 			      const gchar *esp_path,
@@ -72,7 +69,7 @@ fu_uefi_get_fallback_app_path(FuDevice *device,
 gchar *
 fu_uefi_get_esp_app_path(FuDevice *device, const gchar *esp_path, const gchar *cmd, GError **error);
 gchar *
-fu_uefi_get_built_app_path(GError **error);
+fu_uefi_get_built_app_path(const gchar *binary, GError **error);
 gboolean
 fu_uefi_get_bitmap_size(const guint8 *buf,
 			gsize bufsz,
@@ -82,7 +79,7 @@ fu_uefi_get_bitmap_size(const guint8 *buf,
 gboolean
 fu_uefi_get_framebuffer_size(guint32 *width, guint32 *height, GError **error);
 gchar *
-fu_uefi_get_esp_path_for_os(FuDevice *device, const gchar *esp_path);
+fu_uefi_get_esp_path_for_os(FuDevice *device, const gchar *base);
 guint64
 fu_uefi_read_file_as_uint64(const gchar *path, const gchar *attr_name);
 gboolean
