@@ -30,6 +30,7 @@ typedef struct {
 	guint64 fmp_hardware_instance;
 	gboolean missing_header;
 	gboolean automounted_esp;
+	gsize require_esp_free_space;
 } FuUefiDevicePrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE(FuUefiDevice, fu_uefi_device, FU_TYPE_DEVICE)
@@ -134,10 +135,7 @@ fu_uefi_device_to_string(FuDevice *device, guint idt, GString *str)
 	if (priv->esp != NULL) {
 		fu_string_append(str, idt, "EspId", fu_volume_get_id(priv->esp));
 	}
-	fu_string_append_ku(str,
-			    idt,
-			    "RequireESPFreeSpace",
-			    fu_device_get_metadata_integer(device, "RequireESPFreeSpace"));
+	fu_string_append_ku(str, idt, "RequireESPFreeSpace", priv->require_esp_free_space);
 }
 
 static void
@@ -254,6 +252,14 @@ fu_uefi_device_set_status(FuUefiDevice *self, FuUefiDeviceStatus status)
 	fu_device_set_update_error(FU_DEVICE(self), err_msg);
 }
 
+void
+fu_uefi_device_set_require_esp_free_space(FuUefiDevice *self, gsize require_esp_free_space)
+{
+	FuUefiDevicePrivate *priv = GET_PRIVATE(self);
+	g_return_if_fail(FU_IS_UEFI_DEVICE(self));
+	priv->require_esp_free_space = require_esp_free_space;
+}
+
 guint32
 fu_uefi_device_get_capsule_flags(FuUefiDevice *self)
 {
@@ -397,9 +403,13 @@ GBytes *
 fu_uefi_device_fixup_firmware(FuUefiDevice *self, GBytes *fw, GError **error)
 {
 	FuUefiDevicePrivate *priv = GET_PRIVATE(self);
+	efi_capsule_header_t header = {0x0};
+	fwupd_guid_t esrt_guid = {0x0};
+	guint hdrsize = getpagesize();
 	gsize bufsz;
 	const guint8 *buf = g_bytes_get_data(fw, &bufsz);
 	g_autofree gchar *guid_new = NULL;
+	g_autoptr(GByteArray) buf_hdr = g_byte_array_new();
 
 	priv->missing_header = FALSE;
 
@@ -417,38 +427,33 @@ fu_uefi_device_fixup_firmware(FuUefiDevice *self, GBytes *fw, GError **error)
 	if (g_strcmp0(fu_uefi_device_get_guid(self), guid_new) == 0) {
 		g_debug("ESRT matches payload GUID");
 		return g_bytes_ref(fw);
-	} else if (g_strcmp0(guid_new, FU_EFI_FMP_CAPSULE_GUID) == 0 ||
-		   fu_device_has_private_flag(FU_DEVICE(self),
-					      FU_UEFI_DEVICE_FLAG_NO_CAPSULE_HEADER_FIXUP)) {
-		return g_bytes_ref(fw);
-	} else {
-		guint hdrsize = getpagesize();
-		fwupd_guid_t esrt_guid = {0x0};
-		efi_capsule_header_t header = {0x0};
-		g_autoptr(GByteArray) buf_hdr = g_byte_array_new();
-
-		g_warning("missing or invalid embedded capsule header");
-		priv->missing_header = TRUE;
-
-		/* create a fake header with plausible contents */
-		header.flags = priv->capsule_flags;
-		header.header_size = hdrsize;
-		header.capsule_image_size = bufsz + hdrsize;
-		if (!fwupd_guid_from_string(fu_uefi_device_get_guid(self),
-					    &esrt_guid,
-					    FWUPD_GUID_FLAG_MIXED_ENDIAN,
-					    error)) {
-			g_prefix_error(error, "Invalid ESRT GUID: ");
-			return NULL;
-		}
-		memcpy(&header.guid, &esrt_guid, sizeof(fwupd_guid_t));
-
-		/* prepend the header to the payload */
-		g_byte_array_append(buf_hdr, (const guint8 *)&header, sizeof(header));
-		fu_byte_array_set_size(buf_hdr, hdrsize, 0x00);
-		g_byte_array_append(buf_hdr, buf, bufsz);
-		return g_byte_array_free_to_bytes(g_steal_pointer(&buf_hdr));
 	}
+	if (g_strcmp0(guid_new, FU_EFI_FMP_CAPSULE_GUID) == 0 ||
+	    fu_device_has_private_flag(FU_DEVICE(self),
+				       FU_UEFI_DEVICE_FLAG_NO_CAPSULE_HEADER_FIXUP)) {
+		return g_bytes_ref(fw);
+	}
+
+	/* create a fake header with plausible contents */
+	g_debug("missing or invalid embedded capsule header");
+	priv->missing_header = TRUE;
+	header.flags = priv->capsule_flags;
+	header.header_size = hdrsize;
+	header.capsule_image_size = bufsz + hdrsize;
+	if (!fwupd_guid_from_string(fu_uefi_device_get_guid(self),
+				    &esrt_guid,
+				    FWUPD_GUID_FLAG_MIXED_ENDIAN,
+				    error)) {
+		g_prefix_error(error, "Invalid ESRT GUID: ");
+		return NULL;
+	}
+	memcpy(&header.guid, &esrt_guid, sizeof(fwupd_guid_t));
+
+	/* prepend the header to the payload */
+	g_byte_array_append(buf_hdr, (const guint8 *)&header, sizeof(header));
+	fu_byte_array_set_size(buf_hdr, hdrsize, 0x00);
+	g_byte_array_append(buf_hdr, buf, bufsz);
+	return g_byte_array_free_to_bytes(g_steal_pointer(&buf_hdr));
 }
 
 gboolean
@@ -496,23 +501,10 @@ fu_uefi_device_write_update_info(FuUefiDevice *self,
 				  error);
 }
 
-static gboolean
-fu_uefi_device_check_esp_free(FuDevice *device, GError **error)
-{
-	FuUefiDevice *self = FU_UEFI_DEVICE(device);
-	FuUefiDevicePrivate *priv = GET_PRIVATE(self);
-	guint64 sz_reqd = fu_device_get_metadata_integer(device, "RequireESPFreeSpace");
-	if (sz_reqd == G_MAXUINT) {
-		g_debug("maximum size is not configured");
-		return TRUE;
-	}
-	return fu_volume_check_free_space(priv->esp, sz_reqd, error);
-}
-
 static gboolean
 fu_uefi_check_asset(FuDevice *device, GError **error)
 {
-	g_autofree gchar *source_app = fu_uefi_get_built_app_path(error);
+	g_autofree gchar *source_app = fu_uefi_get_built_app_path("fwupd", error);
 	if (source_app == NULL) {
 		if (fu_efivar_secure_boot_enabled(NULL))
 			g_prefix_error(error, "missing signed bootloader for secure boot: ");
@@ -574,8 +566,6 @@ fu_uefi_device_prepare(FuDevice *device,
 	/* sanity checks */
 	if (!fu_uefi_device_cleanup_esp(device, error))
 		return FALSE;
-	if (!fu_uefi_device_check_esp_free(device, error))
-		return FALSE;
 	if (!fu_uefi_check_asset(device, error))
 		return FALSE;
 
@@ -604,9 +594,6 @@ fu_uefi_device_probe(FuDevice *device, GError **error)
 {
 	FuUefiDevice *self = FU_UEFI_DEVICE(device);
 	FuUefiDevicePrivate *priv = GET_PRIVATE(self);
-	FwupdVersionFormat version_format;
-	g_autofree gchar *version_lowest = NULL;
-	g_autofree gchar *version = NULL;
 
 	/* broken sysfs? */
 	if (priv->fw_class == NULL) {
@@ -631,13 +618,11 @@ fu_uefi_device_probe(FuDevice *device, GError **error)
 	fu_device_add_guid(device, priv->fw_class);
 
 	/* set versions */
-	version_format = fu_device_get_version_format(device);
-	version = fu_version_from_uint32(priv->fw_version, version_format);
-	fu_device_set_version_format(device, version_format);
-	fu_device_set_version_raw(device, priv->fw_version);
-	fu_device_set_version(device, version);
+	fu_device_set_version_from_uint32(device, priv->fw_version);
 	if (priv->fw_version_lowest != 0) {
-		version_lowest = fu_version_from_uint32(priv->fw_version_lowest, version_format);
+		g_autofree gchar *version_lowest =
+		    fu_version_from_uint32(priv->fw_version_lowest,
+					   fu_device_get_version_format(self));
 		fu_device_set_version_lowest_raw(device, priv->fw_version_lowest);
 		fu_device_set_version_lowest(device, version_lowest);
 	}
@@ -665,12 +650,78 @@ fu_uefi_device_probe(FuDevice *device, GError **error)
 	return TRUE;
 }
 
+static void
+fu_uefi_device_capture_efi_debugging(FuDevice *device)
+{
+	gsize sz = 0;
+	g_autofree gchar *str = NULL;
+	g_autofree guint16 *buf_ucs2 = NULL;
+	g_autofree guint8 *buf = NULL;
+	g_autoptr(GError) error_local = NULL;
+
+	/* get the EFI variable contents */
+	if (!fu_efivar_get_data(FU_EFIVAR_GUID_FWUPDATE,
+				"FWUPDATE_DEBUG_LOG",
+				&buf,
+				&sz,
+				NULL,
+				&error_local)) {
+		fu_device_set_update_error(device, error_local->message);
+		return;
+	}
+
+	/* convert from UCS-2 to UTF-8, carefully */
+	buf_ucs2 = g_new0(guint16, (sz / 2) + 1);
+	memcpy(buf_ucs2, buf, sz);
+	str = g_utf16_to_utf8(buf_ucs2, sz / 2, NULL, NULL, &error_local);
+	if (str == NULL) {
+		fu_device_set_update_error(device, error_local->message);
+		return;
+	}
+
+	/* success */
+	fu_device_set_update_error(device, str);
+}
+
+gboolean
+fu_uefi_device_perhaps_enable_debugging(FuUefiDevice *self, GError **error)
+{
+	if (fu_device_has_private_flag(FU_DEVICE(self), FU_UEFI_DEVICE_FLAG_ENABLE_EFI_DEBUGGING)) {
+		const guint8 data = 1;
+		if (!fu_efivar_set_data(FU_EFIVAR_GUID_FWUPDATE,
+					"FWUPDATE_VERBOSE",
+					&data,
+					sizeof(data),
+					FU_EFIVAR_ATTR_NON_VOLATILE |
+					    FU_EFIVAR_ATTR_BOOTSERVICE_ACCESS |
+					    FU_EFIVAR_ATTR_RUNTIME_ACCESS,
+					error)) {
+			g_prefix_error(error, "failed to enable debugging: ");
+			return FALSE;
+		}
+		return TRUE;
+	}
+
+	/* unset this */
+	if (fu_efivar_exists(FU_EFIVAR_GUID_FWUPDATE, "FWUPDATE_VERBOSE")) {
+		if (!fu_efivar_delete(FU_EFIVAR_GUID_FWUPDATE, "FWUPDATE_VERBOSE", error))
+			return FALSE;
+	}
+
+	/* success */
+	return TRUE;
+}
+
 static gboolean
 fu_uefi_device_get_results(FuDevice *device, GError **error)
 {
 	FuUefiDevice *self = FU_UEFI_DEVICE(device);
 	FuUefiDevicePrivate *priv = GET_PRIVATE(self);
 
+	/* capture EFI binary debug output */
+	if (fu_device_has_private_flag(device, FU_UEFI_DEVICE_FLAG_ENABLE_EFI_DEBUGGING))
+		fu_uefi_device_capture_efi_debugging(device);
+
 	/* just set the update error */
 	fu_uefi_device_set_status(self, priv->last_attempt_status);
 	return TRUE;
@@ -683,6 +734,29 @@ fu_uefi_device_get_esp_path(FuUefiDevice *self)
 	return fu_volume_get_mount_point(priv->esp);
 }
 
+static FuFirmware *
+fu_uefi_device_prepare_firmware(FuDevice *device,
+				GBytes *fw,
+				FwupdInstallFlags flags,
+				GError **error)
+{
+	FuUefiDevice *self = FU_UEFI_DEVICE(device);
+	FuUefiDevicePrivate *priv = GET_PRIVATE(self);
+	gsize sz_reqd = priv->require_esp_free_space;
+
+	/* check there is enough space in the ESP */
+	if (sz_reqd == 0) {
+		g_debug("required ESP free space is not configured, using 2 x %uMB + 20MB",
+			(guint)g_bytes_get_size(fw) / (1024 * 1024));
+		sz_reqd = g_bytes_get_size(fw) * 2 + (20u * 1024 * 1024);
+	}
+	if (!fu_volume_check_free_space(priv->esp, sz_reqd, error))
+		return NULL;
+
+	/* success */
+	return fu_firmware_new_from_bytes(fw);
+}
+
 static void
 fu_uefi_device_set_property(GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
@@ -750,15 +824,15 @@ fu_uefi_device_init(FuUefiDevice *self)
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_UEFI_DEVICE_FLAG_USE_SHIM_FOR_SB,
 					"use-shim-for-sb");
-	fu_device_register_private_flag(FU_DEVICE(self),
-					FU_UEFI_DEVICE_FLAG_FALLBACK_TO_REMOVABLE_PATH,
-					"fallback-to-removable-path");
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_UEFI_DEVICE_FLAG_NO_RT_SET_VARIABLE,
 					"no-rt-set-variable");
 	fu_device_register_private_flag(FU_DEVICE(self),
 					FU_UEFI_DEVICE_FLAG_NO_CAPSULE_HEADER_FIXUP,
 					"no-capsule-header-fixup");
+	fu_device_register_private_flag(FU_DEVICE(self),
+					FU_UEFI_DEVICE_FLAG_ENABLE_EFI_DEBUGGING,
+					"enable-debugging");
 }
 
 static void
@@ -787,6 +861,7 @@ fu_uefi_device_class_init(FuUefiDeviceClass *klass)
 	object_class->finalize = fu_uefi_device_finalize;
 	klass_device->to_string = fu_uefi_device_to_string;
 	klass_device->probe = fu_uefi_device_probe;
+	klass_device->prepare_firmware = fu_uefi_device_prepare_firmware;
 	klass_device->prepare = fu_uefi_device_prepare;
 	klass_device->cleanup = fu_uefi_device_cleanup;
 	klass_device->report_metadata_pre = fu_uefi_device_report_metadata_pre;
