@@ -91,7 +91,7 @@ def _cairo_surface_write_to_bmp(img: cairo.ImageSurface) -> bytes:
 def main(args) -> int:
 
     # open output archive
-    with tarfile.open(args.out, "w:xz") as tar:
+    with tarfile.open(args.out, "w:xz", preset=8) as tar:
 
         for lang in languages(args.podir):
             # these are the 1.6:1 of some common(ish) screen widths
@@ -144,6 +144,8 @@ def main(args) -> int:
                 attrs = Pango.AttrList()
                 length = len(bytes(label_translated, "utf8"))
                 items = Pango.itemize(pctx, label_translated, 0, length, attrs, None)
+                if not items:
+                    continue
                 gs = Pango.GlyphString()
                 Pango.shape(label_translated, length, items[0].analysis, gs)
                 del img, cctx, pctx, layout
