@@ -27,7 +27,7 @@ fu_efi_image_func(void)
 		return;
 	}
 	g_assert_nonnull(fn);
-	bytes = fu_common_get_contents_bytes(fn, &error);
+	bytes = fu_bytes_get_contents(fn, &error);
 	g_assert_no_error(error);
 	g_assert_nonnull(bytes);
 
@@ -47,7 +47,7 @@ main(int argc, char **argv)
 
 	/* only critical and error are fatal */
 	g_log_set_fatal_mask(NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
-	g_setenv("G_MESSAGES_DEBUG", "all", TRUE);
+	(void)g_setenv("G_MESSAGES_DEBUG", "all", TRUE);
 
 	/* tests go here */
 	g_test_add_func("/uefi-dbx/image", fu_efi_image_func);
