@@ -149,6 +149,29 @@ fu_wacom_aes_device_setup(FuDevice *device, GError **error)
 	return TRUE;
 }
 
+static gboolean
+fu_wacom_aes_device_attach(FuDevice *device, FuProgress *progress, GError **error)
+{
+	FuWacomDevice *self = FU_WACOM_DEVICE(device);
+	FuWacomRawRequest req = {.report_id = FU_WACOM_RAW_BL_REPORT_ID_TYPE,
+				 .cmd = FU_WACOM_RAW_BL_TYPE_FINALIZER,
+				 0x00};
+
+	if (!fu_device_has_flag(device, FWUPD_DEVICE_FLAG_IS_BOOTLOADER)) {
+		g_debug("already in runtime mode, skipping");
+		return TRUE;
+	}
+	if (!fu_wacom_device_set_feature(self, (const guint8 *)&req, sizeof(req), error)) {
+		g_prefix_error(error, "failed to finalize the device: ");
+		return FALSE;
+	}
+
+	/* wait for device back to runtime mode */
+	fu_device_sleep(device, 500); /* ms */
+	fu_device_remove_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_IS_BOOTLOADER);
+	return TRUE;
+}
+
 static gboolean
 fu_wacom_aes_device_erase_all(FuWacomAesDevice *self, FuProgress *progress, GError **error)
 {
@@ -159,13 +182,13 @@ fu_wacom_aes_device_erase_all(FuWacomAesDevice *self, FuProgress *progress, GErr
 	if (!fu_wacom_device_cmd(FU_WACOM_DEVICE(self),
 				 &req,
 				 &rsp,
-				 2000 * 1000, /* this takes a long time */
+				 2000, /* this takes a long time */
 				 FU_WACOM_DEVICE_CMD_FLAG_POLL_ON_WAITING,
 				 error)) {
 		g_prefix_error(error, "failed to send eraseall command: ");
 		return FALSE;
 	}
-	fu_progress_sleep(progress, 2000);
+	fu_device_sleep_full(FU_DEVICE(self), 2000, progress);
 	return TRUE;
 }
 
@@ -211,7 +234,7 @@ fu_wacom_aes_device_write_block(FuWacomAesDevice *self,
 	if (!fu_wacom_device_cmd(FU_WACOM_DEVICE(self),
 				 &req,
 				 &rsp,
-				 1000,
+				 1, /* ms */
 				 FU_WACOM_DEVICE_CMD_FLAG_NONE,
 				 error)) {
 		g_prefix_error(error, "failed to write block %u: ", idx);
@@ -270,6 +293,7 @@ fu_wacom_aes_device_class_init(FuWacomAesDeviceClass *klass)
 	FuDeviceClass *klass_device = FU_DEVICE_CLASS(klass);
 	FuWacomDeviceClass *klass_wac_device = FU_WACOM_DEVICE_CLASS(klass);
 	klass_device->setup = fu_wacom_aes_device_setup;
+	klass_device->attach = fu_wacom_aes_device_attach;
 	klass_wac_device->write_firmware = fu_wacom_aes_device_write_firmware;
 }
 
