@@ -34,7 +34,6 @@ fu_wacom_emr_device_setup(FuDevice *device, GError **error)
 	} else {
 		guint16 fw_ver;
 		guint8 data[19] = {0x03, 0x0}; /* 0x03 is an unknown ReportID */
-		g_autofree gchar *version = NULL;
 		if (!fu_wacom_device_get_feature(FU_WACOM_DEVICE(self), data, sizeof(data), error))
 			return FALSE;
 		if (!fu_memread_uint16_safe(data,
@@ -45,9 +44,7 @@ fu_wacom_emr_device_setup(FuDevice *device, GError **error)
 					    error))
 			return FALSE;
 		fu_device_remove_flag(device, FWUPD_DEVICE_FLAG_IS_BOOTLOADER);
-		version = fu_version_from_uint16(fw_ver, FWUPD_VERSION_FORMAT_PAIR);
-		fu_device_set_version(device, version);
-		fu_device_set_version_raw(device, fw_ver);
+		fu_device_set_version_from_uint32(device, fw_ver);
 	}
 
 	/* success */
@@ -74,7 +71,7 @@ fu_wacom_emr_device_w9013_erase_data(FuWacomEmrDevice *self, GError **error)
 	if (!fu_wacom_device_cmd(FU_WACOM_DEVICE(self),
 				 &req,
 				 &rsp,
-				 50,
+				 1, /* ms */
 				 FU_WACOM_DEVICE_CMD_FLAG_POLL_ON_WAITING,
 				 error)) {
 		g_prefix_error(error, "failed to erase datamem: ");
@@ -99,7 +96,7 @@ fu_wacom_emr_device_w9013_erase_code(FuWacomEmrDevice *self,
 	if (!fu_wacom_device_cmd(FU_WACOM_DEVICE(self),
 				 &req,
 				 &rsp,
-				 50,
+				 1, /* ms */
 				 FU_WACOM_DEVICE_CMD_FLAG_POLL_ON_WAITING,
 				 error)) {
 		g_prefix_error(error, "failed to erase codemem: ");
@@ -121,7 +118,7 @@ fu_wacom_device_w9021_erase_all(FuWacomEmrDevice *self, GError **error)
 	if (!fu_wacom_device_cmd(FU_WACOM_DEVICE(self),
 				 &req,
 				 &rsp,
-				 2000 * 1000, /* this takes a long time */
+				 2000, /* this takes a long time */
 				 FU_WACOM_DEVICE_CMD_FLAG_POLL_ON_WAITING,
 				 error)) {
 		g_prefix_error(error, "failed to send eraseall command: ");
@@ -135,6 +132,28 @@ fu_wacom_device_w9021_erase_all(FuWacomEmrDevice *self, GError **error)
 	return TRUE;
 }
 
+static gboolean
+fu_wacom_emr_device_attach(FuDevice *device, FuProgress *progress, GError **error)
+{
+	FuWacomDevice *self = FU_WACOM_DEVICE(device);
+	FuWacomRawRequest req = {.report_id = FU_WACOM_RAW_BL_REPORT_ID_SET,
+				 .cmd = FU_WACOM_RAW_BL_CMD_ATTACH,
+				 .echo = FU_WACOM_RAW_ECHO_DEFAULT,
+				 0x00};
+
+	if (!fu_device_has_flag(device, FWUPD_DEVICE_FLAG_IS_BOOTLOADER)) {
+		g_debug("already in runtime mode, skipping");
+		return TRUE;
+	}
+	if (!fu_wacom_device_set_feature(self, (const guint8 *)&req, sizeof(req), error)) {
+		g_prefix_error(error, "failed to switch to runtime mode: ");
+		return FALSE;
+	}
+
+	fu_device_remove_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_IS_BOOTLOADER);
+	return TRUE;
+}
+
 static gboolean
 fu_wacom_emr_device_write_block(FuWacomEmrDevice *self,
 				guint32 idx,
@@ -182,7 +201,7 @@ fu_wacom_emr_device_write_block(FuWacomEmrDevice *self,
 	if (!fu_wacom_device_cmd(FU_WACOM_DEVICE(self),
 				 &req,
 				 &rsp,
-				 50,
+				 1,
 				 FU_WACOM_DEVICE_CMD_FLAG_NONE,
 				 error)) {
 		g_prefix_error(error, "failed to write at 0x%x: ", address);
@@ -249,6 +268,7 @@ static void
 fu_wacom_emr_device_init(FuWacomEmrDevice *self)
 {
 	fu_device_set_name(FU_DEVICE(self), "Wacom EMR Device");
+	fu_device_set_version_format(FU_DEVICE(self), FWUPD_VERSION_FORMAT_PAIR);
 }
 
 static void
@@ -257,6 +277,7 @@ fu_wacom_emr_device_class_init(FuWacomEmrDeviceClass *klass)
 	FuDeviceClass *klass_device = FU_DEVICE_CLASS(klass);
 	FuWacomDeviceClass *klass_wac_device = FU_WACOM_DEVICE_CLASS(klass);
 	klass_device->setup = fu_wacom_emr_device_setup;
+	klass_device->attach = fu_wacom_emr_device_attach;
 	klass_wac_device->write_firmware = fu_wacom_emr_device_write_firmware;
 }
 
