@@ -15,6 +15,7 @@
 #include "fu-wac-firmware.h"
 #include "fu-wac-module-bluetooth-id6.h"
 #include "fu-wac-module-bluetooth.h"
+#include "fu-wac-module-scaler.h"
 #include "fu-wac-module-touch.h"
 
 typedef struct {
@@ -173,15 +174,13 @@ fu_wac_device_set_feature_report(FuWacDevice *self,
 				 FuHidDeviceFlags flags,
 				 GError **error)
 {
-	/* hit hardware */
-	if (g_getenv("FWUPD_WAC_EMULATE") != NULL)
-		return TRUE;
 	return fu_hid_device_set_report(FU_HID_DEVICE(self),
 					buf[0],
 					buf,
 					bufsz,
 					FU_WAC_DEVICE_TIMEOUT,
-					flags | FU_HID_DEVICE_FLAG_IS_FEATURE,
+					flags | FU_HID_DEVICE_FLAG_IS_FEATURE |
+					    FU_HID_DEVICE_FLAG_RETRY_FAILURE,
 					error);
 }
 
@@ -669,10 +668,8 @@ fu_wac_device_write_firmware(FuDevice *device,
 static gboolean
 fu_wac_device_add_modules_bluetooth(FuWacDevice *self, GError **error)
 {
-	GUsbDevice *usb_device = fu_usb_device_get_dev(FU_USB_DEVICE(self));
 	g_autofree gchar *name = NULL;
 	g_autofree gchar *name_id6 = NULL;
-	g_autofree gchar *version = NULL;
 	g_autoptr(FuWacModule) module = NULL;
 	g_autoptr(FuWacModule) module_id6 = NULL;
 	guint16 fw_ver;
@@ -693,29 +690,25 @@ fu_wac_device_add_modules_bluetooth(FuWacDevice *self, GError **error)
 			return FALSE;
 		if (fw_ver != 0)
 			break;
-		g_usleep(G_USEC_PER_SEC);
+		fu_device_sleep(FU_DEVICE(self), 1000); /* ms */
 	}
-	version = fu_version_from_uint16(fw_ver, FWUPD_VERSION_FORMAT_BCD);
 
 	/* Success! But legacy bluetooth can't tell us which module the device needs.
 	 * Initialize both and rely on the firmware update containing the appropriate
 	 * package.
 	 */
 	name = g_strdup_printf("%s [Legacy Bluetooth Module]", fu_device_get_name(FU_DEVICE(self)));
-	module = fu_wac_module_bluetooth_new(fu_device_get_context(FU_DEVICE(self)), usb_device);
+	module = fu_wac_module_bluetooth_new(FU_DEVICE(self));
 	fu_device_add_child(FU_DEVICE(self), FU_DEVICE(module));
 	fu_device_set_name(FU_DEVICE(module), name);
-	fu_device_set_version(FU_DEVICE(module), version);
-	fu_device_set_version_raw(FU_DEVICE(module), fw_ver);
+	fu_device_set_version_from_uint16(FU_DEVICE(module), fw_ver);
 
 	name_id6 = g_strdup_printf("%s [Legacy Bluetooth Module (ID6)]",
 				   fu_device_get_name(FU_DEVICE(self)));
-	module_id6 =
-	    fu_wac_module_bluetooth_id6_new(fu_device_get_context(FU_DEVICE(self)), usb_device);
+	module_id6 = fu_wac_module_bluetooth_id6_new(FU_DEVICE(self));
 	fu_device_add_child(FU_DEVICE(self), FU_DEVICE(module_id6));
 	fu_device_set_name(FU_DEVICE(module_id6), name_id6);
-	fu_device_set_version(FU_DEVICE(module_id6), version);
-	fu_device_set_version_raw(FU_DEVICE(module_id6), fw_ver);
+	fu_device_set_version_from_uint16(FU_DEVICE(module_id6), fw_ver);
 	return TRUE;
 }
 
@@ -734,7 +727,6 @@ fu_wac_device_add_modules_legacy(FuWacDevice *self, GError **error)
 static gboolean
 fu_wac_device_add_modules(FuWacDevice *self, GError **error)
 {
-	GUsbDevice *usb_device = fu_usb_device_get_dev(FU_USB_DEVICE(self));
 	g_autofree gchar *version_bootloader = NULL;
 	guint8 buf[] = {[0] = FU_WAC_REPORT_ID_FW_DESCRIPTOR, [1 ... 31] = 0xff};
 	guint16 boot_ver;
@@ -777,7 +769,6 @@ fu_wac_device_add_modules(FuWacDevice *self, GError **error)
 	for (guint8 i = 0; i < buf[3]; i++) {
 		guint8 fw_type = buf[(i * 4) + 4] & ~0x80;
 		g_autofree gchar *name = NULL;
-		g_autofree gchar *version = NULL;
 		g_autoptr(FuWacModule) module = NULL;
 		guint16 ver;
 
@@ -788,43 +779,42 @@ fu_wac_device_add_modules(FuWacDevice *self, GError **error)
 					    G_BIG_ENDIAN,
 					    error))
 			return FALSE;
-		version = fu_version_from_uint16(ver, FWUPD_VERSION_FORMAT_BCD);
 
 		switch (fw_type) {
 		case FU_WAC_MODULE_FW_TYPE_TOUCH:
-			module = fu_wac_module_touch_new(fu_device_get_context(FU_DEVICE(self)),
-							 usb_device);
+			module = fu_wac_module_touch_new(FU_DEVICE(self));
 			name = g_strdup_printf("%s [Touch Module]",
 					       fu_device_get_name(FU_DEVICE(self)));
 			fu_device_add_child(FU_DEVICE(self), FU_DEVICE(module));
 			fu_device_set_name(FU_DEVICE(module), name);
-			fu_device_set_version(FU_DEVICE(module), version);
-			fu_device_set_version_raw(FU_DEVICE(module), ver);
+			fu_device_set_version_from_uint16(FU_DEVICE(module), ver);
 			break;
 		case FU_WAC_MODULE_FW_TYPE_BLUETOOTH:
-			module = fu_wac_module_bluetooth_new(fu_device_get_context(FU_DEVICE(self)),
-							     usb_device);
+			module = fu_wac_module_bluetooth_new(FU_DEVICE(self));
 			name = g_strdup_printf("%s [Bluetooth Module]",
 					       fu_device_get_name(FU_DEVICE(self)));
 			fu_device_add_child(FU_DEVICE(self), FU_DEVICE(module));
 			fu_device_set_name(FU_DEVICE(module), name);
-			fu_device_set_version(FU_DEVICE(module), version);
-			fu_device_set_version_raw(FU_DEVICE(module), ver);
+			fu_device_set_version_from_uint16(FU_DEVICE(module), ver);
 			break;
 		case FU_WAC_MODULE_FW_TYPE_BLUETOOTH_ID6:
-			module =
-			    fu_wac_module_bluetooth_id6_new(fu_device_get_context(FU_DEVICE(self)),
-							    usb_device);
+			module = fu_wac_module_bluetooth_id6_new(FU_DEVICE(self));
 			name = g_strdup_printf("%s [Bluetooth Module (ID6)]",
 					       fu_device_get_name(FU_DEVICE(self)));
 			fu_device_add_child(FU_DEVICE(self), FU_DEVICE(module));
 			fu_device_set_name(FU_DEVICE(module), name);
-			fu_device_set_version(FU_DEVICE(module), version);
-			fu_device_set_version_raw(FU_DEVICE(module), ver);
+			fu_device_set_version_from_uint16(FU_DEVICE(module), ver);
+			break;
+		case FU_WAC_MODULE_FW_TYPE_SCALER:
+			module = fu_wac_module_scaler_new(FU_DEVICE(self));
+			name = g_strdup_printf("%s [Scaler Module]",
+					       fu_device_get_name(FU_DEVICE(self)));
+			fu_device_add_child(FU_DEVICE(self), FU_DEVICE(module));
+			fu_device_set_name(FU_DEVICE(module), name);
+			fu_device_set_version_from_uint16(FU_DEVICE(module), ver);
 			break;
 		case FU_WAC_MODULE_FW_TYPE_MAIN:
-			fu_device_set_version(FU_DEVICE(self), version);
-			fu_device_set_version_raw(FU_DEVICE(self), ver);
+			fu_device_set_version_from_uint16(FU_DEVICE(self), ver);
 			break;
 		default:
 			g_warning("unknown submodule type 0x%0x", fw_type);
@@ -879,7 +869,7 @@ fu_wac_device_close(FuDevice *device, GError **error)
 	 * we take the lock, then cancel the work item which needs to take the
 	 * lock too. This needs to be fixed in the kernel, but for the moment
 	 * this should let the kernel unstick itself. */
-	g_usleep(20 * 1000);
+	fu_device_sleep(device, 20); /* ms */
 
 	/* FuUsbDevice->close */
 	return FU_DEVICE_CLASS(fu_wac_device_parent_class)->close(device, error);
@@ -920,6 +910,7 @@ fu_wac_device_init(FuWacDevice *self)
 	fu_device_set_install_duration(FU_DEVICE(self), 10);
 	fu_device_set_remove_delay(FU_DEVICE(self), FU_DEVICE_REMOVE_DELAY_RE_ENUMERATE);
 	fu_device_set_firmware_gtype(FU_DEVICE(self), FU_TYPE_WAC_FIRMWARE);
+	fu_device_retry_set_delay(FU_DEVICE(self), 30); /* ms */
 }
 
 static void
