@@ -38,6 +38,7 @@ struct _FuConfig {
 	gboolean ignore_power;
 	gboolean only_trusted;
 	gboolean show_device_private;
+	gboolean allow_emulation;
 };
 
 G_DEFINE_TYPE(FuConfig, fu_config, G_TYPE_OBJECT)
@@ -64,10 +65,13 @@ fu_config_reload(FuConfig *self, GError **error)
 	g_autofree gchar *host_bkc = NULL;
 	g_autofree gchar *esp_location = NULL;
 	g_autoptr(GKeyFile) keyfile = g_key_file_new();
+	g_autoptr(GError) error_disabled_plugins = NULL;
+	g_autoptr(GError) error_timeout = NULL;
 	g_autoptr(GError) error_update_motd = NULL;
 	g_autoptr(GError) error_ignore_power = NULL;
 	g_autoptr(GError) error_only_trusted = NULL;
 	g_autoptr(GError) error_show_device_private = NULL;
+	g_autoptr(GError) error_allow_emulation = NULL;
 	g_autoptr(GError) error_enumerate_all = NULL;
 	g_autoptr(GByteArray) buf = g_byte_array_new();
 
@@ -114,11 +118,16 @@ fu_config_reload(FuConfig *self, GError **error)
 					     "fwupd",
 					     "DisabledPlugins",
 					     NULL, /* length */
-					     NULL);
+					     &error_disabled_plugins);
 	if (plugins != NULL) {
 		for (guint i = 0; plugins[i] != NULL; i++) {
 			g_ptr_array_add(self->disabled_plugins, g_strdup(plugins[i]));
 		}
+	} else {
+		if (error_disabled_plugins != NULL) {
+			g_ptr_array_add(self->disabled_plugins, g_strdup("test"));
+			g_ptr_array_add(self->disabled_plugins, g_strdup("test_ble"));
+		}
 	}
 
 	/* get approved firmware */
@@ -185,9 +194,11 @@ fu_config_reload(FuConfig *self, GError **error)
 	}
 
 	/* get idle timeout */
-	idle_timeout = g_key_file_get_uint64(keyfile, "fwupd", "IdleTimeout", NULL);
+	idle_timeout = g_key_file_get_uint64(keyfile, "fwupd", "IdleTimeout", &error_timeout);
 	if (idle_timeout > 0)
 		self->idle_timeout = idle_timeout;
+	else if (error_timeout != NULL)
+		self->idle_timeout = 7200;
 
 	/* get the domains to run in verbose */
 	domains = g_key_file_get_string(keyfile, "fwupd", "VerboseDomains", NULL);
@@ -208,7 +219,7 @@ fu_config_reload(FuConfig *self, GError **error)
 	/* if error parsing or missing, we want to default to true */
 	if (!self->enumerate_all_devices && error_enumerate_all != NULL) {
 		g_debug("failed to read EnumerateAllDevices key: %s", error_enumerate_all->message);
-		self->enumerate_all_devices = TRUE;
+		self->enumerate_all_devices = FALSE;
 	}
 
 	/* whether to ignore power levels for updates */
@@ -238,6 +249,14 @@ fu_config_reload(FuConfig *self, GError **error)
 		self->show_device_private = TRUE;
 	}
 
+	/* whether to allow emulation to work */
+	self->allow_emulation =
+	    g_key_file_get_boolean(keyfile, "fwupd", "AllowEmulation", &error_allow_emulation);
+	if (!self->allow_emulation && error_allow_emulation != NULL) {
+		g_debug("failed to read AllowEmulation key: %s", error_allow_emulation->message);
+		self->allow_emulation = FALSE;
+	}
+
 	/* fetch host best known configuration */
 	host_bkc = g_key_file_get_string(keyfile, "fwupd", "HostBkc", NULL);
 	if (host_bkc != NULL && host_bkc[0] != '\0')
@@ -437,6 +456,13 @@ fu_config_get_show_device_private(FuConfig *self)
 	return self->show_device_private;
 }
 
+gboolean
+fu_config_get_allow_emulation(FuConfig *self)
+{
+	g_return_val_if_fail(FU_IS_CONFIG(self), FALSE);
+	return self->allow_emulation;
+}
+
 gboolean
 fu_config_get_enumerate_all_devices(FuConfig *self)
 {
