@@ -51,6 +51,7 @@ struct _FuDaemon {
 	gboolean update_in_progress;
 	gboolean pending_stop;
 	FuDaemonMachineKind machine_kind;
+	GPtrArray *system_inhibits;
 };
 
 G_DEFINE_TYPE(FuDaemon, fu_daemon, G_TYPE_OBJECT)
@@ -234,7 +235,7 @@ fu_daemon_create_request(FuDaemon *self, const gchar *sender, GError **error)
 {
 	FuDaemonSenderItem *sender_item;
 	FwupdDeviceFlags device_flags = FWUPD_DEVICE_FLAG_NONE;
-	guint64 calling_uid = 0;
+	guint calling_uid = 0;
 	g_autoptr(FuEngineRequest) request = fu_engine_request_new(FU_ENGINE_REQUEST_KIND_ACTIVE);
 	g_autoptr(GVariant) value = NULL;
 
@@ -786,7 +787,6 @@ fu_daemon_install_with_helper_device(FuMainAuthHelper *helper,
 				     GError **error)
 {
 	FuDaemon *self = helper->self;
-	const gchar *action_id;
 	g_autoptr(FuRelease) release = fu_release_new();
 	g_autoptr(GError) error_local = NULL;
 	g_autoptr(GPtrArray) releases = NULL;
@@ -843,7 +843,7 @@ fu_daemon_install_with_helper_device(FuMainAuthHelper *helper,
 #else
 		rels = xb_node_query(component, "releases/release", 0, NULL);
 #endif
-		/* add all but the the first entry */
+		/* add all but the first entry */
 		for (guint i = 1; i < rels->len; i++) {
 			XbNode *rel = g_ptr_array_index(rels, i);
 			g_autoptr(FuRelease) release2 = fu_release_new();
@@ -884,9 +884,11 @@ fu_daemon_install_with_helper_device(FuMainAuthHelper *helper,
 		}
 
 		/* get the action IDs for the valid device */
-		action_id = fu_release_get_action_id(release_tmp);
-		if (!g_ptr_array_find(helper->action_ids, action_id, NULL))
-			g_ptr_array_add(helper->action_ids, g_strdup(action_id));
+		if (!fu_device_has_flag(device, FWUPD_DEVICE_FLAG_EMULATED)) {
+			const gchar *action_id = fu_release_get_action_id(release_tmp);
+			if (!g_ptr_array_find(helper->action_ids, action_id, NULL))
+				g_ptr_array_add(helper->action_ids, g_strdup(action_id));
+		}
 		g_ptr_array_add(helper->releases, g_object_ref(release_tmp));
 	}
 
@@ -1015,6 +1017,51 @@ fu_daemon_schedule_process_quit(FuDaemon *self)
 	self->process_quit_id = g_idle_add(fu_daemon_schedule_process_quit_cb, self);
 }
 
+typedef struct {
+	gchar *id;
+	gchar *sender;
+	guint watcher_id;
+} FuDaemonSystemInhibit;
+
+static void
+fu_daemon_system_inhibit_free(FuDaemonSystemInhibit *inhibit)
+{
+	g_bus_unwatch_name(inhibit->watcher_id);
+	g_free(inhibit->id);
+	g_free(inhibit->sender);
+	g_free(inhibit);
+}
+
+static void
+fu_daemon_ensure_system_inhibit(FuDaemon *self)
+{
+	FuContext *ctx = fu_engine_get_context(self->engine);
+	if (self->system_inhibits->len > 0) {
+		fu_context_add_flag(ctx, FU_CONTEXT_FLAG_SYSTEM_INHIBIT);
+		return;
+	}
+	fu_context_remove_flag(ctx, FU_CONTEXT_FLAG_SYSTEM_INHIBIT);
+}
+
+static void
+fu_daemon_inhibit_name_vanished_cb(GDBusConnection *connection,
+				   const gchar *name,
+				   gpointer user_data)
+{
+	FuDaemon *self = FU_DAEMON(user_data);
+	for (guint i = 0; i < self->system_inhibits->len; i++) {
+		FuDaemonSystemInhibit *inhibit = g_ptr_array_index(self->system_inhibits, i);
+		if (g_strcmp0(inhibit->sender, name) == 0) {
+			g_debug("removing %s as %s vanished without calling Uninhibit",
+				inhibit->id,
+				name);
+			g_ptr_array_remove_index(self->system_inhibits, i);
+			fu_daemon_ensure_system_inhibit(self);
+			break;
+		}
+	}
+}
+
 static void
 fu_daemon_daemon_method_call(GDBusConnection *connection,
 			     const gchar *sender,
@@ -1352,6 +1399,45 @@ fu_daemon_daemon_method_call(GDBusConnection *connection,
 		g_dbus_method_invocation_return_value(invocation, NULL);
 		return;
 	}
+	if (g_strcmp0(method_name, "EmulationLoad") == 0) {
+		g_autoptr(GBytes) data = NULL;
+
+		g_debug("Called %s()", method_name);
+
+		/* load data into engine */
+		data = g_variant_get_data_as_bytes(g_variant_get_child_value(parameters, 0));
+		if (!fu_engine_emulation_load(self->engine, data, &error)) {
+			g_dbus_method_invocation_return_error(invocation,
+							      FWUPD_ERROR,
+							      FWUPD_ERROR_NOT_SUPPORTED,
+							      "failed to load emulation data: %s",
+							      error->message);
+			return;
+		}
+
+		/* success */
+		g_dbus_method_invocation_return_value(invocation, NULL);
+		return;
+	}
+	if (g_strcmp0(method_name, "EmulationSave") == 0) {
+		g_autoptr(GBytes) data = NULL;
+
+		g_debug("Called %s()", method_name);
+
+		/* save data from engine */
+		data = fu_engine_emulation_save(self->engine, &error);
+		if (data == NULL) {
+			g_dbus_method_invocation_return_error(invocation,
+							      FWUPD_ERROR,
+							      FWUPD_ERROR_NOT_SUPPORTED,
+							      "failed to save emulation data: %s",
+							      error->message);
+			return;
+		}
+		val = g_variant_new_from_bytes(G_VARIANT_TYPE_BYTESTRING, data, FALSE);
+		g_dbus_method_invocation_return_value(invocation, g_variant_new_tuple(&val, 1));
+		return;
+	}
 	if (g_strcmp0(method_name, "ModifyDevice") == 0) {
 		const gchar *device_id;
 		const gchar *key = NULL;
@@ -1626,6 +1712,59 @@ fu_daemon_daemon_method_call(GDBusConnection *connection,
 		g_dbus_method_invocation_return_value(invocation, NULL);
 		return;
 	}
+	if (g_strcmp0(method_name, "Inhibit") == 0) {
+		FuDaemonSystemInhibit *inhibit;
+		const gchar *reason = NULL;
+
+		g_variant_get(parameters, "(&s)", &reason);
+		g_debug("Called %s(%s)", method_name, reason);
+
+		/* watch */
+		inhibit = g_new0(FuDaemonSystemInhibit, 1);
+		inhibit->sender = g_strdup(sender);
+		inhibit->id = g_strdup_printf("dbus-%i", g_random_int_range(1, G_MAXINT - 1));
+		inhibit->watcher_id =
+		    g_bus_watch_name_on_connection(self->connection,
+						   sender,
+						   G_BUS_NAME_WATCHER_FLAGS_NONE,
+						   NULL,
+						   fu_daemon_inhibit_name_vanished_cb,
+						   self,
+						   NULL);
+		g_ptr_array_add(self->system_inhibits, inhibit);
+		fu_daemon_ensure_system_inhibit(self);
+		g_dbus_method_invocation_return_value(invocation,
+						      g_variant_new("(s)", inhibit->id));
+		return;
+	}
+	if (g_strcmp0(method_name, "Uninhibit") == 0) {
+		const gchar *inhibit_id = NULL;
+		gboolean found = FALSE;
+
+		g_variant_get(parameters, "(&s)", &inhibit_id);
+		g_debug("Called %s(%s)", method_name, inhibit_id);
+
+		/* find by id, then uninhibit device */
+		for (guint i = 0; i < self->system_inhibits->len; i++) {
+			FuDaemonSystemInhibit *inhibit =
+			    g_ptr_array_index(self->system_inhibits, i);
+			if (g_strcmp0(inhibit->id, inhibit_id) == 0) {
+				g_ptr_array_remove_index(self->system_inhibits, i);
+				fu_daemon_ensure_system_inhibit(self);
+				found = TRUE;
+				break;
+			}
+		}
+		if (!found) {
+			g_dbus_method_invocation_return_error_literal(invocation,
+								      FWUPD_ERROR,
+								      FWUPD_ERROR_NOT_FOUND,
+								      "Cannot find inhibit ID");
+			return;
+		}
+		g_dbus_method_invocation_return_value(invocation, NULL);
+		return;
+	}
 
 	if (g_strcmp0(method_name, "Install") == 0) {
 #ifdef HAVE_GIO_UNIX
@@ -2175,6 +2314,8 @@ fu_daemon_init(FuDaemon *self)
 						   g_free,
 						   (GDestroyNotify)fu_daemon_sender_item_free);
 	self->loop = g_main_loop_new(NULL, FALSE);
+	self->system_inhibits =
+	    g_ptr_array_new_with_free_func((GDestroyNotify)fu_daemon_system_inhibit_free);
 }
 
 static void
@@ -2182,6 +2323,7 @@ fu_daemon_finalize(GObject *obj)
 {
 	FuDaemon *self = FU_DAEMON(obj);
 
+	g_ptr_array_unref(self->system_inhibits);
 	g_hash_table_unref(self->sender_items);
 	if (self->process_quit_id != 0)
 		g_source_remove(self->process_quit_id);
