@@ -12,6 +12,7 @@
 
 #include "fu-device-list.h"
 #include "fu-device-private.h"
+#include "fu-engine.h"
 #include "fu-mutex.h"
 
 /**
@@ -605,6 +606,16 @@ fu_device_list_clear_wait_for_replug(FuDeviceList *self, FuDeviceItem *item)
 	}
 }
 
+static void
+fu_device_incorporate_problem_update_in_progress(FuDevice *self, FuDevice *donor)
+{
+	if (fu_device_has_problem(donor, FWUPD_DEVICE_PROBLEM_UPDATE_IN_PROGRESS)) {
+		g_debug("moving inhibit update-in-progress to active device");
+		fu_device_add_problem(self, FWUPD_DEVICE_PROBLEM_UPDATE_IN_PROGRESS);
+		fu_device_remove_problem(donor, FWUPD_DEVICE_PROBLEM_UPDATE_IN_PROGRESS);
+	}
+}
+
 static void
 fu_device_incorporate_update_state(FuDevice *self, FuDevice *donor)
 {
@@ -646,6 +657,9 @@ fu_device_list_replace(FuDeviceList *self, FuDeviceItem *item, FuDevice *device)
 		fu_device_set_private_flags(device, private_flags);
 	}
 
+	/* copy inhibit */
+	fu_device_incorporate_problem_update_in_progress(item->device, device);
+
 	/* copy over the version strings if not set */
 	if (fu_device_get_version(item->device) != NULL && fu_device_get_version(device) == NULL) {
 		const gchar *version = fu_device_get_version(item->device);
@@ -674,6 +688,8 @@ fu_device_list_replace(FuDeviceList *self, FuDeviceItem *item, FuDevice *device)
 		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD);
 	if (fu_device_has_flag(item->device, FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD))
 		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD);
+	if (fu_device_has_flag(item->device, FWUPD_DEVICE_FLAG_EMULATION_TAG))
+		fu_device_add_flag(device, FWUPD_DEVICE_FLAG_EMULATION_TAG);
 
 	/* device won't come back in right mode */
 	if (fu_device_has_flag(item->device, FWUPD_DEVICE_FLAG_WILL_DISAPPEAR)) {
@@ -744,6 +760,8 @@ fu_device_list_add(FuDeviceList *self, FuDevice *device)
 			g_debug("found existing device %s", fu_device_get_id(device));
 			if (device != item->device) {
 				fu_device_uninhibit(item->device, "unconnected");
+				fu_device_incorporate_problem_update_in_progress(device,
+										 item->device);
 				fu_device_incorporate_update_state(device, item->device);
 				fu_device_list_item_set_device(item, device);
 			}
@@ -757,6 +775,7 @@ fu_device_list_add(FuDeviceList *self, FuDevice *device)
 		    g_strcmp0(fu_device_get_id(device), fu_device_get_id(item->device_old)) == 0) {
 			g_debug("found old device %s, swapping", fu_device_get_id(device));
 			fu_device_uninhibit(item->device, "unconnected");
+			fu_device_incorporate_problem_update_in_progress(device, item->device);
 			fu_device_incorporate_update_state(device, item->device);
 			g_set_object(&item->device_old, item->device);
 			fu_device_list_item_set_device(item, device);
@@ -800,11 +819,10 @@ fu_device_list_add(FuDeviceList *self, FuDevice *device)
 			fu_device_list_replace(self, item, device);
 			fu_device_uninhibit(device, "unconnected");
 			return;
-		} else {
-			g_debug("not adding matching %s for device add, use "
-				"FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID if required",
-				fu_device_get_id(item->device));
 		}
+		g_debug("not adding matching %s for device add, use "
+			"FU_DEVICE_INTERNAL_FLAG_REPLUG_MATCH_GUID if required",
+			fu_device_get_id(item->device));
 	}
 
 	/* add helper */
@@ -849,7 +867,8 @@ fu_device_list_get_wait_for_replug(FuDeviceList *self)
 	GPtrArray *devices = g_ptr_array_new_with_free_func((GDestroyNotify)g_object_unref);
 	for (guint i = 0; i < self->devices->len; i++) {
 		FuDeviceItem *item_tmp = g_ptr_array_index(self->devices, i);
-		if (fu_device_has_flag(item_tmp->device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG))
+		if (fu_device_has_flag(item_tmp->device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG) &&
+		    !fu_device_has_flag(item_tmp->device, FWUPD_DEVICE_FLAG_EMULATED))
 			g_ptr_array_add(devices, g_object_ref(item_tmp->device));
 	}
 	return devices;
