@@ -27,6 +27,8 @@ G_DECLARE_FINAL_TYPE(FuEngine, fu_engine, FU, ENGINE, GObject)
  * @FU_ENGINE_LOAD_FLAG_REMOTES:	Enumerate remotes
  * @FU_ENGINE_LOAD_FLAG_HWINFO:		Load details about the hardware
  * @FU_ENGINE_LOAD_FLAG_NO_CACHE:	Do not save persistent xmlb silos
+ * @FU_ENGINE_LOAD_FLAG_NO_IDLE_SOURCES:Do not load idle sources
+ * @FU_ENGINE_LOAD_FLAG_BUILTIN_PLUGINS:	Load built-in plugins
  *
  * The flags to use when loading the engine.
  **/
@@ -38,6 +40,7 @@ typedef enum {
 	FU_ENGINE_LOAD_FLAG_HWINFO = 1 << 3,
 	FU_ENGINE_LOAD_FLAG_NO_CACHE = 1 << 4,
 	FU_ENGINE_LOAD_FLAG_NO_IDLE_SOURCES = 1 << 5,
+	FU_ENGINE_LOAD_FLAG_BUILTIN_PLUGINS = 1 << 6,
 	/*< private >*/
 	FU_ENGINE_LOAD_FLAG_LAST
 } FuEngineLoadFlags;
@@ -50,8 +53,6 @@ void
 fu_engine_idle_reset(FuEngine *self);
 gboolean
 fu_engine_load(FuEngine *self, FuEngineLoadFlags flags, FuProgress *progress, GError **error);
-gboolean
-fu_engine_get_tainted(FuEngine *self);
 const gchar *
 fu_engine_get_host_vendor(FuEngine *self);
 const gchar *
@@ -160,7 +161,7 @@ gboolean
 fu_engine_composite_cleanup(FuEngine *self, GPtrArray *devices, GError **error);
 gboolean
 fu_engine_install_release(FuEngine *self,
-			  FuRelease *task,
+			  FuRelease *release,
 			  GBytes *blob_cab,
 			  FuProgress *progress,
 			  FwupdInstallFlags flags,
@@ -202,7 +203,7 @@ fu_engine_self_sign(FuEngine *self, const gchar *value, JcatSignFlags flags, GEr
 gboolean
 fu_engine_modify_config(FuEngine *self, const gchar *key, const gchar *value, GError **error);
 FuContext *
-fu_engine_get_context(FuEngine *engine);
+fu_engine_get_context(FuEngine *self);
 void
 fu_engine_md_refresh_device_from_component(FuEngine *self, FuDevice *device, XbNode *component);
 GPtrArray *
@@ -224,7 +225,7 @@ fu_engine_get_details_for_bytes(FuEngine *self,
 				GBytes *blob,
 				GError **error);
 gboolean
-fu_engine_check_trust(FuEngine *self, FuRelease *task, GError **error);
+fu_engine_check_trust(FuEngine *self, FuRelease *release, GError **error);
 gboolean
 fu_engine_check_requirements(FuEngine *self,
 			     FuRelease *release,
@@ -248,3 +249,7 @@ fu_engine_modify_bios_settings(FuEngine *self,
 			       GHashTable *settings,
 			       gboolean force_ro,
 			       GError **error);
+gboolean
+fu_engine_emulation_load(FuEngine *self, GBytes *data, GError **error);
+GBytes *
+fu_engine_emulation_save(FuEngine *self, GError **error);
