@@ -6,10 +6,7 @@
 
 #pragma once
 
-#include <fwupd.h>
-#include <glib-object.h>
-
-#include "fu-device.h"
+#include <fwupdplugin.h>
 
 #define FU_TYPE_IDLE (fu_idle_get_type())
 G_DECLARE_FINAL_TYPE(FuIdle, fu_idle, FU, IDLE, GObject)
@@ -18,6 +15,8 @@ FuIdle *
 fu_idle_new(void);
 guint32
 fu_idle_inhibit(FuIdle *self, const gchar *reason);
+gboolean
+fu_idle_has_inhibit(FuIdle *self, const gchar *reason);
 void
 fu_idle_uninhibit(FuIdle *self, guint32 token);
 void
