@@ -248,10 +248,11 @@ fu_release_get_release_version(FuRelease *self, const gchar *version, GError **e
 static gboolean
 fu_release_load_test_result(FuRelease *self, XbNode *n, GError **error)
 {
-	XbNode *c;
 	const gchar *tmp;
 	g_autoptr(FwupdReport) report = fwupd_report_new();
 	g_autoptr(GPtrArray) custom = NULL;
+	g_autoptr(XbNode) os = NULL;
+	g_autoptr(XbNode) vendor_name = NULL;
 
 	tmp = xb_node_get_attr(n, "date");
 	if (tmp != NULL) {
@@ -267,27 +268,27 @@ fu_release_load_test_result(FuRelease *self, XbNode *n, GError **error)
 	tmp = xb_node_query_text(n, "previous_version", NULL);
 	if (tmp != NULL)
 		fwupd_report_set_version_old(report, tmp);
-	c = xb_node_query_first(n, "vendor_name", NULL);
-	if (c != NULL) {
-		guint64 vendor_id = xb_node_get_attr_as_uint(c, "id");
-		fwupd_report_set_vendor(report, xb_node_get_text(c));
+	vendor_name = xb_node_query_first(n, "vendor_name", NULL);
+	if (vendor_name != NULL) {
+		guint64 vendor_id = xb_node_get_attr_as_uint(vendor_name, "id");
+		fwupd_report_set_vendor(report, xb_node_get_text(vendor_name));
 		if (vendor_id != G_MAXUINT64)
 			fwupd_report_set_vendor_id(report, vendor_id);
 	}
-	c = xb_node_query_first(n, "os", NULL);
-	if (c != NULL) {
-		tmp = xb_node_get_attr(c, "version");
+	os = xb_node_query_first(n, "os", NULL);
+	if (os != NULL) {
+		tmp = xb_node_get_attr(os, "version");
 		if (tmp != NULL)
 			fwupd_report_set_distro_version(report, tmp);
-		tmp = xb_node_get_attr(c, "variant");
+		tmp = xb_node_get_attr(os, "variant");
 		if (tmp != NULL)
 			fwupd_report_set_distro_variant(report, tmp);
-		fwupd_report_set_distro_id(report, xb_node_get_text(c));
+		fwupd_report_set_distro_id(report, xb_node_get_text(os));
 	}
 	custom = xb_node_query(n, "custom/value", 0, NULL);
 	if (custom != NULL) {
 		for (guint i = 0; i < custom->len; i++) {
-			c = g_ptr_array_index(custom, i);
+			XbNode *c = g_ptr_array_index(custom, i);
 			fwupd_report_add_metadata_item(report,
 						       xb_node_get_attr(c, "key"),
 						       xb_node_get_text(c));
@@ -643,7 +644,7 @@ fu_release_check_requirements(FuRelease *self,
 				    fu_release_get_version(self),
 				    fu_device_get_version_format(self->device));
 	if (fu_device_has_flag(self->device, FWUPD_DEVICE_FLAG_ONLY_VERSION_UPGRADE) &&
-	    vercmp >= 0) {
+	    vercmp > 0) {
 		g_set_error(error,
 			    FWUPD_ERROR,
 			    FWUPD_ERROR_NOT_SUPPORTED,
@@ -857,7 +858,7 @@ fu_release_load(FuRelease *self,
 		if (str->len > 0)
 			fwupd_release_set_description(FWUPD_RELEASE(self), str->str);
 	}
-	if (artifact == NULL) {
+	if (fwupd_release_get_locations(FWUPD_RELEASE(self))->len == 0) {
 		tmp = xb_node_query_text(rel, "location", NULL);
 		if (tmp != NULL) {
 			g_autofree gchar *uri = NULL;
@@ -878,7 +879,7 @@ fu_release_load(FuRelease *self,
 			fwupd_release_add_location(FWUPD_RELEASE(self), uri);
 		}
 	}
-	if (artifact == NULL) {
+	if (fwupd_release_get_filename(FWUPD_RELEASE(self)) == NULL) {
 		tmp = xb_node_query_text(rel, "checksum[@target='content']", NULL);
 		if (tmp != NULL)
 			fwupd_release_set_filename(FWUPD_RELEASE(self), tmp);
@@ -889,7 +890,7 @@ fu_release_load(FuRelease *self,
 	tmp = xb_node_query_text(rel, "url[@type='source']", NULL);
 	if (tmp != NULL)
 		fwupd_release_set_source_url(FWUPD_RELEASE(self), tmp);
-	if (artifact == NULL) {
+	if (fwupd_release_get_checksums(FWUPD_RELEASE(self))->len == 0) {
 		g_autoptr(GPtrArray) checksums = NULL;
 		checksums = xb_node_query(rel, "checksum[@target='container']", 0, NULL);
 		if (checksums != NULL) {
@@ -902,7 +903,7 @@ fu_release_load(FuRelease *self,
 			}
 		}
 	}
-	if (artifact == NULL) {
+	if (fwupd_release_get_size(FWUPD_RELEASE(self)) == 0) {
 		tmp64 = xb_node_query_text_as_uint(rel, "size[@type='installed']", NULL);
 		if (tmp64 != G_MAXUINT64)
 			fwupd_release_set_size(FWUPD_RELEASE(self), tmp64);
