@@ -11,7 +11,7 @@
 #include <gusb.h>
 
 #include "fu-usb-backend.h"
-#include "fu-usb-device.h"
+#include "fu-usb-device-private.h"
 
 struct _FuUsbBackend {
 	FuBackend parent_instance;
@@ -50,24 +50,18 @@ fu_usb_backend_device_notify_flags_cb(FuDevice *device, GParamSpec *pspec, FuBac
 static void
 fu_usb_backend_device_added_cb(GUsbContext *ctx, GUsbDevice *usb_device, FuBackend *backend)
 {
-	g_autoptr(FuUsbDevice) device = NULL;
-
-	/* success */
-	device = fu_usb_device_new(fu_backend_get_context(backend), usb_device);
+	g_autoptr(FuUsbDevice) device =
+	    fu_usb_device_new(fu_backend_get_context(backend), usb_device);
 	fu_backend_device_added(backend, FU_DEVICE(device));
 }
 
 static void
 fu_usb_backend_device_removed_cb(GUsbContext *ctx, GUsbDevice *usb_device, FuBackend *backend)
 {
-	FuUsbBackend *self = FU_USB_BACKEND(backend);
-	FuDevice *device_tmp;
-
-	/* find the device we enumerated */
-	device_tmp =
-	    fu_backend_lookup_by_id(FU_BACKEND(self), g_usb_device_get_platform_id(usb_device));
-	if (device_tmp != NULL)
-		fu_backend_device_removed(backend, device_tmp);
+	FuDevice *device =
+	    fu_backend_lookup_by_id(backend, g_usb_device_get_platform_id(usb_device));
+	if (device != NULL)
+		fu_backend_device_removed(backend, device);
 }
 
 static void
@@ -76,6 +70,28 @@ fu_usb_backend_context_finalized_cb(gpointer data, GObject *where_the_object_was
 	g_critical("GUsbContext %p was finalized from under our feet!", where_the_object_was);
 }
 
+static void
+fu_usb_backend_context_flags_check(FuUsbBackend *self)
+{
+#if G_USB_CHECK_VERSION(0, 4, 5)
+	FuContext *ctx = fu_backend_get_context(FU_BACKEND(self));
+	GUsbContextFlags usb_flags = G_USB_CONTEXT_FLAGS_NONE;
+	if (g_getenv("FWUPD_BACKEND_VERBOSE") != NULL)
+		usb_flags |= G_USB_CONTEXT_FLAGS_DEBUG;
+	if (fu_context_has_flag(ctx, FU_CONTEXT_FLAG_SAVE_EVENTS)) {
+		g_debug("saving FuUsbBackend events");
+		usb_flags |= G_USB_CONTEXT_FLAGS_SAVE_EVENTS;
+	}
+	g_usb_context_set_flags(self->usb_ctx, usb_flags);
+#endif
+}
+
+static void
+fu_usb_backend_context_flags_notify_cb(FuContext *ctx, GParamSpec *pspec, FuUsbBackend *self)
+{
+	fu_usb_backend_context_flags_check(self);
+}
+
 static gboolean
 fu_usb_backend_setup(FuBackend *backend, FuProgress *progress, GError **error)
 {
@@ -87,6 +103,11 @@ fu_usb_backend_setup(FuBackend *backend, FuProgress *progress, GError **error)
 		return FALSE;
 	}
 	g_object_weak_ref(G_OBJECT(self->usb_ctx), fu_usb_backend_context_finalized_cb, self);
+	g_signal_connect(fu_backend_get_context(backend),
+			 "notify::flags",
+			 G_CALLBACK(fu_usb_backend_context_flags_notify_cb),
+			 self);
+	fu_usb_backend_context_flags_check(self);
 	return TRUE;
 }
 
@@ -120,6 +141,7 @@ static gboolean
 fu_usb_backend_coldplug(FuBackend *backend, FuProgress *progress, GError **error)
 {
 	FuUsbBackend *self = FU_USB_BACKEND(backend);
+
 	g_autoptr(GPtrArray) usb_devices = NULL;
 
 	/* progress */
@@ -148,6 +170,65 @@ fu_usb_backend_coldplug(FuBackend *backend, FuProgress *progress, GError **error
 	return TRUE;
 }
 
+static gboolean
+fu_usb_backend_load(FuBackend *backend,
+		    JsonObject *json_object,
+		    const gchar *tag,
+		    FuBackendLoadFlags flags,
+		    GError **error)
+{
+#if G_USB_CHECK_VERSION(0, 4, 5)
+	FuUsbBackend *self = FU_USB_BACKEND(backend);
+	return g_usb_context_load_with_tag(self->usb_ctx, json_object, tag, error);
+#else
+	g_set_error_literal(error,
+			    G_IO_ERROR,
+			    G_IO_ERROR_NOT_SUPPORTED,
+			    "GUsb version too old to load backends");
+	return FALSE;
+#endif
+}
+
+static gboolean
+fu_usb_backend_save(FuBackend *backend,
+		    JsonBuilder *json_builder,
+		    const gchar *tag,
+		    FuBackendSaveFlags flags,
+		    GError **error)
+{
+#if G_USB_CHECK_VERSION(0, 4, 5)
+	FuUsbBackend *self = FU_USB_BACKEND(backend);
+	guint usb_events_cnt = 0;
+	g_autoptr(GPtrArray) devices = g_usb_context_get_devices(self->usb_ctx);
+
+	for (guint i = 0; i < devices->len; i++) {
+		GUsbDevice *usb_device = g_ptr_array_index(devices, i);
+		g_autoptr(GPtrArray) usb_events = g_usb_device_get_events(usb_device);
+		if (usb_events->len > 0 || g_usb_device_has_tag(usb_device, tag)) {
+			g_debug("%u USB events to save for %s",
+				usb_events->len,
+				g_usb_device_get_platform_id(usb_device));
+		}
+		usb_events_cnt += usb_events->len;
+	}
+	if (usb_events_cnt == 0)
+		return TRUE;
+	if (!g_usb_context_save_with_tag(self->usb_ctx, json_builder, tag, error))
+		return FALSE;
+	for (guint i = 0; i < devices->len; i++) {
+		GUsbDevice *usb_device = g_ptr_array_index(devices, i);
+		g_usb_device_clear_events(usb_device);
+	}
+	return TRUE;
+#else
+	g_set_error_literal(error,
+			    G_IO_ERROR,
+			    G_IO_ERROR_NOT_SUPPORTED,
+			    "GUsb version too old to save backends");
+	return FALSE;
+#endif
+}
+
 static void
 fu_usb_backend_registered(FuBackend *backend, FuDevice *device)
 {
@@ -170,6 +251,7 @@ fu_usb_backend_finalize(GObject *object)
 	FuUsbBackend *self = FU_USB_BACKEND(object);
 
 	if (self->usb_ctx != NULL) {
+		g_signal_handlers_disconnect_by_data(G_USB_CONTEXT(self->usb_ctx), self);
 		g_object_weak_unref(G_OBJECT(self->usb_ctx),
 				    fu_usb_backend_context_finalized_cb,
 				    self);
@@ -191,11 +273,13 @@ fu_usb_backend_class_init(FuUsbBackendClass *klass)
 	object_class->finalize = fu_usb_backend_finalize;
 	klass_backend->setup = fu_usb_backend_setup;
 	klass_backend->coldplug = fu_usb_backend_coldplug;
+	klass_backend->load = fu_usb_backend_load;
+	klass_backend->save = fu_usb_backend_save;
 	klass_backend->registered = fu_usb_backend_registered;
 }
 
 FuBackend *
-fu_usb_backend_new(void)
+fu_usb_backend_new(FuContext *ctx)
 {
-	return FU_BACKEND(g_object_new(FU_TYPE_USB_BACKEND, "name", "usb", NULL));
+	return FU_BACKEND(g_object_new(FU_TYPE_USB_BACKEND, "name", "usb", "context", ctx, NULL));
 }
